<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @category    Ecart
 * @package     Ecart_Account
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 * 
 * @category    Ecart
 * @package     Ecart_Account
 * @subpackage  Model
 * @author      Ecart Core Team <core@ecartcommerce.com>
 */
class Ecart_Account_Model_Customer_ValueSet_Value extends Ecart_Db_Table 
{
    protected $_name = 'account_customer_valueset_value';
    protected $_dependentTables = array(
        'Ecart_Account_Model_Customer_ValueSet_Value_Label'
    );

    /**
     *
     * @param int $valuesetId
     * @return array
     */
    public function getValues($valuesetId)
    {
        $list = array();
        
        $i = 0;
        $rowset = $this->fetchAll('customer_valueset_id = ' . $valuesetId);
        foreach ($rowset as $row) {
            $list[$i] = $row->toArray();
            $labels = $row->findDependentRowset(
                'Ecart_Account_Model_Customer_ValueSet_Value_Label'
            );
            foreach ($labels as $label) {
                $list[$i]['label' . $label->language_id] = $label->label;
            }
            ++$i;
        }
        return $list;
    }

    /**
     *
     * @param array $data
     * @param int $valueset
     * @return void
     */
    public function save($data, $valueset)
    {
        $db = $this->getAdapter();
        if (!sizeof($data))
            return;
        $label = Ecart::single('account/Customer_ValueSet_Value_Label');
        $langIds = array_keys(Ecart_Collect_Language::collect());
        foreach ($data as $id => $values) {
            $row = array(
                'customer_valueset_id' => $valueset,
                'sort_order' => $values['sort_order'],
                'is_active' => $values['is_active'] ? 1 : 0,
            );
            
            if (!isset($values['new'])) {
                $this->update($row, $db->quoteInto('id = ?', $id));
                //labels update at n_customer_valueset_value_label
                foreach ($langIds as $langId) {
                    if (!$record = $label->find($id, $langId)->current()) {
                        $record = $label->createRow(array(
                            'valueset_value_id' => $id,
                            'language_id' => $langId,
                            'label' => $values['label' . $langId]
                        ));
                    } else {
                        $record->setFromArray(array(
                            'label' => $values['label' . $langId]
                        ));
                    }
                    $record->save();
                }
            } else {
                $id = $this->insert($row);
                foreach ($langIds as $langId) {
                    $label->insert(array(
                        'valueset_value_id' => $id,
                        'language_id' => $langId,
                        'label' => $values['label' . $langId]
                    ));
                }
            }
        }
        Ecart::message()->addSuccess(
            Ecart::translate('core')->__(
                'Data was saved successfully'
            )
        );
    }

    /**
     *
     * @param int $valueSetId
     * @param int $languageId
     * @return array
     */
    public function getCustomValues($valueSetId, $languageId = null)
    {
        if (null === $languageId) {
            $languageId = Ecart::getLanguageId();
        }
        $query = "SELECT cvv.id, cvvl.`label` FROM {$this->_name} cvv
            INNER JOIN " . self::$_db_prefix . "account_customer_valueset_value_label cvvl ON cvvl.valueset_value_id = cvv.id
            WHERE cvv.is_active = 1 AND cvv.customer_valueset_id = ? AND language_id = ? 
            ORDER BY cvv.sort_order";
        return $this->getAdapter()->fetchPairs($query, array(
            $valueSetId, $languageId
        ));
    }
}