<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @category    Ecart
 * @package     Ecart_Account
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 * 
 * @category    Ecart
 * @package     Ecart_Account
 * @subpackage  Controller
 * @author      Ecart Core Team <core@ecartcommerce.com>
 */
class Ecart_Account_AddressBookController extends Ecart_Account_Controller_Account
{
    /**
     * @var Ecart_Account_Model_Customer_Address
     */
    private $_table;

    /**
     * @var int
     */
    private $_customerId;

    public function init()
    {
        parent::init();
        $this->_table = Ecart::single('account/customer_address');
        $this->_customerId = Ecart::getCustomerId();
        $this->view->crumbs()->add(
            Ecart::translate('account')->__('Address Book'),
            '/account/address-book'
        );
    }
     
    public function indexAction()
    {
        $this->view->pageTitle = Ecart::translate('account')->__(
            'Address Book'
        );
        $this->view->meta()->setTitle(
            Ecart::translate('account')->__(
                'Address Book'
        ));
        $customer = Ecart::single('account/customer')
            ->find($this->_customerId)->current();
        $this->view->defaultBillingAddresId =
            $customer->default_billing_address_id;
        $this->view->defaultShippingAddresId =
            $customer->default_shipping_address_id;

        $this->view->address = $this->_table->getCustomListByCustomer(
            $this->_customerId
        );
        $this->render();
    }
     
    public function saveAction()
    {
        $this->view->pageTitle = Ecart::translate('account')->__(
            'Saving address'
        );
        $data = $this->_getAllParams();
        $form = Ecart::model('account/Form_AddressBook');
        
        if ($form->isValid($data)) {
            $data['customer_id'] = $this->_customerId;
            Ecart::single('account/customer_address')->save($data);
            if ($this->getRequest()->isXmlHttpRequest()) {
                $this->_helper->json->sendJson(true, false, false);
                exit();
            }
            $this->_redirect('account/address-book');
        } else {
            if ($this->getRequest()->isXmlHttpRequest()) {
                $this->_helper->json->sendJson(
                    $form->getMessages(), false, false
                );
                exit();
            }
            $form->populate($data);
        }
        
        $this->view->form = $form;
        $this->render('form-address');
    }
     
    public function deleteAction()
    {
        $id = $this->_getParam('id');
        $this->_table->delete(array(
            $this->db->quoteInto('id = ?', $id),
            $this->db->quoteInto('customer_id = ?', $this->_customerId)
        ));
        $this->_redirect('account/address-book');
    }
     
    public function newAction()
    {
        $this->view->pageTitle = Ecart::translate('account')->__(
            'Add new address'
        );
        $form = Ecart::single('account/Form_AddressBook');
        $form->addUseAsDefaultAddressCheckbox();
        $this->view->form = $form;
        $this->render('form-address');
    }
     
    public function editAction()
    {
        $this->view->pageTitle = Ecart::translate('account')->__(
            'Edit address'
        );
        $id = $this->_getParam('id');
        
        $data = $this->_table->fetchRow(
            array($this->db->quoteInto('id = ?', $id),
            $this->db->quoteInto('customer_id = ?', $this->_customerId)
        ));
        
        if (!$data) {
            Ecart::message()->addError(Ecart::translate('account')->__(
                'Address not found'
            ));
            if ($this->getRequest()->isXmlHttpRequest()) {
                return $this->_helper->json->sendFailure();
            }
            $this->_redirect('account/address-book');
            exit();
        }
        
        if ($this->getRequest()->isXmlHttpRequest()) {
            return $this->_helper->json->sendSuccess(array(
                'data' => $data->toArray()
            ));
        }
        
        $form = Ecart::model('account/Form_AddressBook');
        $form->addUseAsDefaultAddressCheckbox();
        
        $customer = Ecart::single('account/customer')
            ->find($this->_customerId)->current();
        
        $form->populate($data->toArray());
        
        if ($customer->default_shipping_address_id == $id) {
            $form->getDisplayGroup('address')
                ->getRow('primary_shipping')
                ->getElement('primary_shipping')
                ->setOptions(array('value' => 1));
        }
        if ($customer->default_billing_address_id == $id) {
            $form->getDisplayGroup('address')
                ->getRow('primary_billing')
                ->getElement('primary_billing')
                ->setOptions(array('value' => 1));
        }
        
        $this->view->form = $form;
        $this->render('form-address');
    }
}