<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @category    Ecart
 * @package     Ecart_Account
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 * 
 * @category    Ecart
 * @package     Ecart_Account
 * @subpackage  Controller
 * @author      Ecart Core Team <core@ecartcommerce.com>
 */
class Ecart_Account_ForgotController extends Ecart_Core_Controller_Front
{
    
    protected function _generatePassword() 
    {
        mt_srand((double)microtime(1)*1000000);
        return md5(mt_rand());
    }

    public function init()
    {
        parent::init();
        $this->view->crumbs()->add(
            Ecart::translate('account')->__('Forgot'), '/account/auth/forgot'
        );
    }
    
	public function registerAction()
    {
        $this->view->pageTitle = Ecart::translate('account')->__(
            'Forgot password'
        );
        
        $username = $this->_getParam('username', null);
        if (empty($username)) {
             $this->render();
             return;
        }
        $customerId = Ecart::single('account/customer')
            ->getIdByEmail($username);

        if ($customerId)
        {
            $hash = $this->_generatePassword();
            $link = $this->view->href('/account/forgot', true)
                  . '?hash=' . $hash;
            
            $customer = Ecart::single('account/customer')
                ->find($customerId)->current();
            
            $mail = new Ecart_Mail();               
            $mail->setConfig(array(
                'event'   => 'forgot_password',
                'subject' => 'Forgot Your Password',
                'data'    => array(
                    'link' => $link,
                    'firstname' => $customer->firstname,
                    'lastname' => $customer->lastname
                ),
                'to'   => $username,
                'from' => array('name' => Ecart::config()->main->store->owner),
                'type' => 'html'   
            ));
            if (@$mail->send()) {
                Ecart::single('account/customer_forgotPassword')->save(array(
                    'hash' => $hash,
                    'customer_id' => $customerId
                ));
                Ecart::message()->addSuccess(Ecart::translate('core')->__(
                    'Message was sended to you. Check your mailbox'
                ));
            }
        } else {
            Ecart::message()->addError(Ecart::translate('account')->__(
                "'%s' was not found in database", $username
            ));
        }
        $this->render();
    }
    
    public function indexAction()
    {
        $this->view->pageTitle = Ecart::translate('account')->__(
            'Retrieve Forgotten Password'
        );
        $this->view->hash = $this->_getParam('hash', null);
        $this->render();
    }
    
    public function confirmAction()
    {
        $data = $this->_getAllParams();
        if (empty($data['password']) || empty($data['password_confirm'])) {
            Ecart::message()->addError(Ecart::translate('account')->__(
                'Password is the required field'
            ));
            $this->_redirect($_SERVER['HTTP_REFERER']);
            exit();
        }
        if ($data['password'] != $data['password_confirm']) {
            Ecart::message()->addError(Ecart::translate('account')->__(
                'Password confirmation does not match'
            ));
        }
        $modelForgotPass = Ecart::single('account/customer_forgotPassword');
        if ($modelForgotPass->isValid($data['hash'])) {
            $isUpdatePassword = Ecart::single('account/customer')->update(array(
                'password' => md5($data['password'])), 
                $this->db->quoteInto('email = ?', 
                    $modelForgotPass->getEmailByHash($data['hash'])
                )
            );
            if ($isUpdatePassword) {
                $modelForgotPass->delete(
                    $this->db->quoteInto('hash = ?', $data['hash']) 
                );
            }
        } else {
            Ecart::message()->addError(Ecart::translate('account')->__(
                'Recieved hash is corrupted.'
            ));
        }
        
        $this->_redirect($_SERVER['HTTP_REFERER']);
    }
}