<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @category    Ecart
 * @package     Ecart_Account
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 * 
 * @category    Ecart
 * @package     Ecart_Account
 * @subpackage  Controller
 * @author      Ecart Core Team <core@ecartcommerce.com>
 */
class Ecart_Account_WishlistController extends Ecart_Account_Controller_Account
{
    public function init()
    {
        parent::init();
        $this->view->crumbs()->add(
            Ecart::translate('account')->__('My Wishlist'), '/account/wishlist'
        );
    }

    public function indexAction()
    {
        $this->view->pageTitle = Ecart::translate('account')->__('My Wishlist');
        $this->view->meta()->setTitle(
            Ecart::translate('account')->__(
                'My Wishlist'
        ));
        $this->view->wishlist = Ecart::single('account/wishlist')
            ->findByCustomer((int) Ecart::getCustomerId());
        $this->render();
    }

    public function addAction()
    {
        $customerId = Ecart::getCustomerId();
        $productId = $this->_getParam('id');
        if (!Ecart::single('account/wishlist')
            ->fetchOne('id', "customer_id = {$customerId} AND product_id = {$productId}")) {
            
            $data = array(
                'customer_id' => $customerId,
                'product_id' => $productId
            );
            Ecart::single('account/wishlist')->insert($data);
            Ecart::dispatch('account_whishlist_add_product_success', $data);
            $this->_redirect('/account/wishlist');
        }
        Ecart::message()->addError(
            Ecart::translate('account')->__(
                'Selected product is already in your wishlist'
            )
        );
        $this->_redirect($_SERVER['HTTP_REFERER']);
    }

    public function removeAction()
    {
        Ecart::single('account/wishlist')->delete(array(
            $this->db->quoteInto('id = ?', $this->_getParam('id')),
            $this->db->quoteInto('customer_id = ?',
                (int) Ecart::getCustomerId()
            )
        ));
        Ecart::dispatch('account_whishlist_remove_product_success', array(
            'customer_id' => $this->_getParam('id'),
            'product_id' => Ecart::getCustomerId()
        ));
        $this->_redirect('/account/wishlist');
    }

    public function updateAction()
    {
        Ecart::single('account/wishlist')->updateComments(
            $this->_getParam('comment', array())
        );
        $this->_redirect('/account/wishlist');
    }
}