<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @category    Ecart
 * @package     Ecart_Admin
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 * 
 * @category    Ecart
 * @package     Ecart_Admin
 * @subpackage  Model
 * @author      Ecart Core Team <core@ecartcommerce.com>
 */
class Ecart_Admin_Model_Acl extends Zend_Acl
{
    protected $_table;
    private $_rescs;
    
    private function _loadResources()
    {
        foreach ($this->getResources() as $resource) {
            if (false !== ($pos = strrpos($resource['resource_id'], '/'))) {
                $parentId = substr($resource['resource_id'], 0, $pos);
            } else {
                $parentId = null;
            }
            $this->add(new Zend_Acl_Resource($resource['resource_id']), $parentId);
        }
    }
    
    public function __construct()
    {
        $this->_table = Ecart::single('admin/acl_role');
        $this->_loadResources();
    }
    
    /**
     * Load rules of $role and all parent roles
     * 
     * @param Zend_Acl_Role_Interface|string $role
     * @return boolean
     */
    public function loadRules($role)
    {
        if ($role instanceof Zend_Acl_Role_Interface) {
            $roleId = $role->getRoleId();
        } else {
            $roleId = (string) $role;
        }
        $this->addRoleRecursive($role);
        
        $rolesForLoad = $this->_table->getAllParents($roleId);
        $rolesForLoad[] = $roleId;
        $where = $this->_table->getAdapter()->quoteInto('role_id IN(?)', $rolesForLoad);
        
        $result = $this->_table->getAdapter()->query(
            "SELECT * FROM " . $this->_table->getPrefix() . "admin_acl_rule WHERE $where"
        );
        while (($row = $result->fetch())) {
            if ($row['permission'] == 'allow') {
                $this->allow($row['role_id'], $row['resource_id']);
            } elseif ($row['permission'] == 'deny') {
                $this->deny($row['role_id'], $row['resource_id']);
            }
        }
    }
    
    /**
     * Add role with all parent roles
     * 
     * @param Zend_Acl_Role_Interface|string $role
     */
    public function addRoleRecursive($role)
    {
        if ($role instanceof Zend_Acl_Role_Interface) {
            $roleId = $role->getRoleId();
        } else {
            $roleId = (string) $role;
        }
        
        $rolesTree = $this->_table->getRolesTree();
        if (isset($rolesTree[$roleId]['parents'])) {
            foreach ($rolesTree[$roleId]['parents'] as $parentRoleId) {
                $this->addRoleRecursive($parentRoleId);
            }
        }
        if (!$this->hasRole($roleId))
            $this->addRole(
                new Zend_Acl_Role($roleId), 
                isset($rolesTree[$roleId]['parents']) ? $rolesTree[$roleId]['parents'] : null
            );
    }
    
    public function getResources()
    {
        if (null === $this->_rescs) {
            $this->_rescs = 
                Ecart::single('admin/acl_resource')->fetchAll(null, 'resource_id ASC')->toArray();
        }
        return $this->_rescs;
    }
    
    /**
     * Return allows array for gived roles as it will be parent roles
     * 
     * @param $roles array
     * @return array
     */
    public function getParentRolesAllows(array $roles)
    {
        /*
         * Load rules
         */
        foreach ($roles as $role) {
            $this->loadRules($role);
        }
        
        /*
         * Create tmp role that inherit from $roles
         */
        $this->addRole(new Zend_Acl_Role('tmp'), $roles);
        
        $allows = array();

        foreach ($this->getResources() as $resource) {
            if ($this->isAllowed('tmp', $resource['resource_id'])) {
                $allows[] = $resource['resource_id'];
            }
        }

        $this->removeRole('tmp');
        
        return $allows;
    }
}