<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @category    Ecart
 * @package     Ecart_Admin
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 * 
 * @category    Ecart
 * @package     Ecart_Admin
 * @subpackage  Model
 * @author      Ecart Core Team <core@ecartcommerce.com>
 */
class Ecart_Admin_Model_Cms_Page extends Ecart_Cms_Model_Page 
{
    protected $_rowClass = 'Ecart_Admin_Model_Cms_Page_Row';
    
    public function getCount($filterTree, $filterSearch, $langId)
    {
        $select = $this->getAdapter()->select();
        $select->distinct()
               ->from(array('cp' => $this->_name), 
                    new Zend_Db_Expr('COUNT(cp.id)'))
               ->join(array('cpc' => self::$_db_prefix . 'cms_page_content'),
                    'cp.id = cpc.cms_page_id',
                    array());
        
        if (isset($filterTree['type'])) {
            
//            $select->joinLeft(array('cptc' => self::$_db_prefix . 'cms_page_category'),
//                     'cptc.cms_page_id = cp.id',
//                     array())
//                    ->joinLeft(array('cc' => self::$_db_prefix . 'cms_category'),
//                      'cc.id = cptc.cms_category_id',
//                      array());  
                           
            switch ($filterTree['type']) {
                case 'site':
                    $select->joinLeft(array('cptc' => self::$_db_prefix . 'cms_page_category'),
						                     'cptc.cms_page_id = cp.id',
						                     array())
						                    ->joinLeft(array('cc' => self::$_db_prefix . 'cms_category'),
						                      'cc.id = cptc.cms_category_id',
						                      array());
                    $select->where('cc.site_id = ?', $filterTree['data']);
                    break;
                case 'category':
                    if ($filterTree['data'] == 'lost') {
                        $where = "cp.id <> ALL (
                                SELECT DISTINCT cptc.cms_page_id
                                FROM   " . self::$_db_prefix . "cms_page_category as cptc
                        )";
                        $select->where($where);
                    } else if ($filterTree['data'] != 'all') {
                        $select->joinLeft(array('cptc' => self::$_db_prefix . 'cms_page_category'),
							                     'cptc.cms_page_id = cp.id',
							                     array())
							                    ->joinLeft(array('cc' => self::$_db_prefix . 'cms_category'),
							                      'cc.id = cptc.cms_category_id',
							                      array());
                        $select->where("cptc.cms_category_id = ?", $filterTree['data']);
                    }
                    break;
            }
        }
        
        if ($filterSearch['query'] != '') {
            $select->where("cp.name LIKE ?", "%" . $filterSearch['query'] . "%");
        }
    
        $select->where('cpc.language_id = ?', $langId);
               
        return $this->getAdapter()->fetchOne($select->__toString());
    }
    
    public function getPages($filterTree, $filterSearch, $langId, $pagingParams)
    {
        $select = $this->getAdapter()->select();
        $select->from(array('cp' => $this->_name))
               ->joinLeft(array('cpc' => self::$_db_prefix . 'cms_page_content'),
                    'cp.id = cpc.cms_page_id AND cpc.language_id = ' . $langId,
                    'link')
               ->group('cp.id');
        
        if (isset($filterTree['type'])) {
            
            $select->joinLeft(array('cptc' => self::$_db_prefix . 'cms_page_category'),
                     'cptc.cms_page_id = cp.id',
                     array())
                    ->joinLeft(array('cc' => self::$_db_prefix . 'cms_category'),
                      'cc.id = cptc.cms_category_id',
                      array('category_name' => new Zend_Db_Expr('group_concat(`cc`.`name` separator \', \')')));  
                           
	        switch ($filterTree['type']) {
	            case 'site':
	                $select->where('cc.site_id = ?', $filterTree['data']);
	                break;
	            case 'category':
	                if ($filterTree['data'] == 'lost') {
	                    $where = "cp.id <> ALL (
	                            SELECT DISTINCT cptc.cms_page_id
	                            FROM  " . self::$_db_prefix . "cms_page_category as cptc
	                    )";
	                    $select->where($where);
	                } else if ($filterTree['data'] != 'all') {
	                    $select->where("cptc.cms_category_id = ?", $filterTree['data']);
	                }
	                break;
	        }
        }
        
        if ($filterSearch['query'] != '') {
            $select->where("cp.name LIKE ?", "%" . $filterSearch['query'] . "%");
        }
        
        if (!empty($pagingParams['sort']))
            $select->order($pagingParams['sort'] . ' ' . $pagingParams['dir']);
        if (!empty($pagingParams['limit']))
            $select->limit($pagingParams['limit'], $pagingParams['start']);
               
        return $this->getAdapter()->fetchAll($select->__toString());
    }
    
    public function getPageListByCategory($catId)
    {
        $select = $this->getAdapter()->select();
        $select->from(array('cp' => $this->_name), array('name', 'id', 'is_active'))
               ->join(array('cptc' => self::$_db_prefix . 'cms_page_category'),
                    'cp.id = cptc.cms_page_id',
                    'cms_category_id')
               ->where('cptc.cms_category_id = ?', $catId);
               
        return $this->getAdapter()->fetchAll($select->__toString());
    }
    
    public function getLostPage()
    {
        $queryPage = "SELECT    cp.name, cp.id, cp.is_active
                      FROM " . self::$_db_prefix . "cms_page as cp
                      WHERE cp.id <> ALL (
                            SELECT DISTINCT cptc.cms_page_id
                            FROM " . self::$_db_prefix . "cms_page_category as cptc
                      )";
        
        return $this->getAdapter()->fetchAll($queryPage);
    }
    
    public function getLayout() 
    {
        return Ecart_Collect_Layout::collect();
    }
}