<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 *
 * @category    Ecart
 * @package     Ecart_Admin
 * @subpackage  Ecart_Admin_Model
 * @author      Ecart Core Team <core@ecartcommerce.com>
 */
class Ecart_Admin_Model_Csv_Profile extends Ecart_Db_Table 
{
    protected $_name = 'csv_profile';
    
    protected $_dependentTables = array('Ecart_Admin_Model_Csv_Profile_Filter');
    
    public function getList()
    {
        $query = "SELECT cp.*, cpf.*
                  FROM   {$this->_name} AS cp
                  LEFT JOIN ".self::$_db_prefix."csv_profile_filter AS cpf 
                      ON cp.id = cpf.profile_id
                  ORDER BY cp.updated_at DESC, cp.created_at DESC";
        
        return $this->getAdapter()->fetchAll($query);
    }
    
    public function save(array $data, array $filters)
    {
        if ($data['id'] == '') {
            $data['created_at'] = Ecart_Date::now()->toZendDbExpr();
            $data['updated_at'] = '0000-00-00 00:00:00';
            unset($data['id']);
            $row = $this->createRow();
        } else {
            $data['updated_at'] = Ecart_Date::now()->toZendDbExpr();
            $row = $this->find($data['id'])->current();
        }
        $row->setFromArray($data);
        $row->save();
        
        if ($row->direction == 'export') {
            $filter = $row->findDependentRowset('Ecart_Admin_Model_Csv_Profile_Filter')->current();
            if (!$filter) 
            {
                $filter = Ecart::single('admin/csv_profile_filter')->createRow();
                $filter->profile_id = $row->id;
            }
            $filter->setFromArray($filters);
            $filter->language_ids = trim($filters['language_ids'], ', ');
            $filter->price_from = is_numeric($filters['price_from']) ?
                    $filters['price_from'] : new Zend_Db_Expr('NULL');
            $filter->price_to = is_numeric($filters['price_to']) ?
                    $filters['price_to'] : new Zend_Db_Expr('NULL');
            $filter->qty_from = is_numeric($filters['qty_from']) ?
                    $filters['qty_from'] : new Zend_Db_Expr('NULL');
            $filter->qty_to = is_numeric($filters['qty_to']) ?
                    $filters['qty_to'] : new Zend_Db_Expr('NULL');
            $filter->save();
        }
        Ecart::message()->addSuccess(
            Ecart::translate('admin')->__(
                'Profile was saved successfully'
            )
        );
        return true;
    }
    
    public function deleteByIds(array $ids)
    {
        if (!count($ids)) {
            return false;
        }
        $where = $this->getAdapter()->quoteInto('id IN(?)', $ids);

        if ($result = parent::delete($where)) {
           Ecart::message()->addSuccess(
               Ecart::translate('admin')->__(
                   'Profile was deleted successfully'
                )
           );
        }
        return $result;
    }
}