<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @category    Ecart
 * @package     Ecart_Admin
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 * 
 * @category    Ecart
 * @package     Ecart_Admin
 * @subpackage  Controller
 * @author      Ecart Core Team <core@ecartcommerce.com>
 */
class Ecart_Admin_Catalog_IndexController extends Ecart_Admin_Controller_Back 
{   
    public function categoryTreeAction() 
    {
        $this->view->productCategories = array();
        if ($this->_hasParam('productId')) {
            $productId = $this->_getParam('productId');
            $this->view->productCategories = Ecart::single('catalog/product')
                ->find($productId)->current()->getCategories();
        }
        $this->_helper->layout->disableLayout();
        $categories = Ecart::single('catalog/category')
            ->getFlatTree(Ecart::getLanguageId());
        asort($categories);
        $this->view->categoryTrees = $categories;
        $this->view->sites = Ecart_Collect_Site::collect();
        $this->render();
    }
    
    public function indexAction()
    {
        $this->view->pageTitle = Ecart::translate('catalog')->__(
            'Products Catalog'
        );
        $this->view->siteId = $this->_getParam('siteId', 0);
        $this->view->languages = Ecart_Collect_Language::collect();
        
        if ($this->_hasParam('productId')) {
            $this->view->productId = $this->_getParam('productId');
        }
        
        $this->view->sites = Ecart_Collect_Site::collect();
        $categories = Ecart::single('catalog/category')
            ->getFlatTree(Ecart::getLanguageId());
        asort($categories);
        $this->view->categoryTrees = $categories;

        $this->view->manufacturers = array('0' => '-none-')
            + Ecart_Collect_Manufacturer::collect();
        $this->view->taxClasses = array('0' => '-none-')
            + Ecart_Collect_TaxClass::collect();
        
        $this->view->langId = $this->_langId;

        $config = Ecart::config()->catalog->product;
        $this->view->hurldelmiter = ($config->hurldelimiter) ?
            $config->hurldelimiter : '*';
        $this->view->seodelemiter = ($config->seodelimiter) ?
            $config->seodelimiter : '_';
        $this->view->seodesclength = ($config->seodesclength) ?
            $config->seodesclength : 100;
        $this->render();
    }
    
    public function listProductsAction()
    {
        $sortMapping = array(
	        'id' => 'p.id', 
	        'name' => 'pd.name', 
	        'status' => 'p.p_status', 
	        'price' => 'p.price',
            'is_active' => 'p.is_active',
            'date_available' => 'p.date_available',
            'is_featured' => 'pf.product_id',
            'date_exp' => 'pf.date_exp'
        );
        
        $dirs = array('ASC' => 'ASC', 'DESC' => 'DESC');
        
        $start = $this->_getParam('start', 0);
        $limit = $this->_getParam('limit', 10);
        $sort  = $this->_getParam('sort', 'id');
        $dir   = $this->_getParam('dir', 'DESC');
        $catId = $this->_getParam('catId', 0);
        
        $modelProduct  = Ecart::single('catalog/product');
        /* calc count */
        if ($category = Ecart::single('catalog/category')
            ->find($catId)->current()) {

            if ($category->lvl == 0) {
                $count = $modelProduct->countBySite($category->site_id);
            } else {
                $count = $modelProduct->countByCategoryId($category->id);
            }
        } elseif ($catId = 'uncategorized') {
            $category = $catId;
            $count = $modelProduct->countByUncategorized();
        }
        return $this->_helper->json->sendSuccess(array(
            'data' => Ecart::single('catalog/category')->getListProducts(
                $category, $limit, $start, $sortMapping[$sort] . ' ' . $dirs[$dir]
            ),
            'count' => $count
        ));
    }
    
    public function listBestsellerAction()
    {
        $this->_helper->layout->disableLayout();
        $params = array (   
            'siteId' => $this->_getParam('siteId', 0),
            'limit' => $this->_getParam('limit', 20),
            'start' => $this->_getParam('start', 0)
        );
        
        $data = Ecart::single('catalog/product')->getProductBestSeller($params);
        $count  = count($data);
        $currency = Ecart::single('locale/currency')
                        ->getCurrencyObject(Ecart::config()->main->store->currency);
        foreach ($data as &$item) {
            $item['price'] = $currency->toCurrency($item['price']);
        }
        
        return $this->_helper->json->sendSuccess(array(
            'data'  => array_values($data),
            'count' => $count
        ));
    }
    
    public function listViewedAction()
    {
        $this->_helper->layout->disableLayout();
        $params = array (   
            'siteId' => $this->_getParam('siteId', 0),
            'limit' => $this->_getParam('limit', 20),
            'start' => $this->_getParam('start', 0),
            'dir' => $this->_getParam('dir', 'DESC'),
            'languageId' => $this->_langId
        );
        
        $data = Ecart::single('catalog/product')->getViewed($params);
        
        $count = count($data);
        
        $currency = Ecart::single('locale/currency')
                        ->getCurrencyObject(Ecart::config()->main->store->currency);
        foreach ($data as &$item) {
            $item['price'] = $currency->toCurrency($item['price']);
        }
        
        return $this->_helper->json->sendJson(array(
            'data'  => array_values($data),
            'count' => $count
        ));
    }

    public function getOptionsAction()
    {
        $this->layout->disableLayout();
        
        $id = $this->_getParam('node', 0); // option_id
        $items = array();
        
        $optionTable = Ecart::single('catalog/product_option');
        if (!$id) {
            // return options list
            $options = $optionTable->getList(array(
                'languageId' => $this->_langId
            ));
            
            foreach ($options as $item) {
                $items[] = array(
                   'text' => $item['name'],
                   'id'   => $item['id'],
                   'leaf' => false,
                   'type' => 'option',
                   'inputType' => $item['option_type'],
                   'languagable' => $item['languagable']
                );
            }
        } else {
            $values = $optionTable->find($id)->current()
                ->getValuesArrayByLanguage($this->_langId);
            
            foreach ($values as $value) {
                $items[] = array(
                   'id' => $id . '_' . $value['id'],
                   'value_id' => $value['id'],
                   'text' => $value['name'],
                   'leaf' => false,
                   'children' => array(),
                   'expanded' => true,
                   'type' => 'value'
                );
            }
        }
        
        $this->_helper->json->sendJson($items, false, false);
    }
    
    public function saveProductAction()
    {
        $this->_helper->layout->disableLayout();
        
        $prodId = (int)$this->_getParam('prodId', 0);
        
        /* retrieve array of sites where the product will be in */
        $assignedSites = Ecart::single('catalog/category')
            ->getSiteByCategory($this->_getParam('category'));
        
        $productRow = array();
        $productRow[$prodId] = $this->_getParam('product');
        
        /* prepare variations array */
        $variationsData = $this->_getParam('variation', array());
        $variations = Zend_Json_Decoder::decode($this->_getParam('variations'));
        foreach ($variations as $variationId => $variation) {
            if (!isset($variationsData[$variationId])) {
                $variationsData[$variationId] = array();
            }
            $variationsData[$variationId] += $variation;
        }
        
        /* prepare modifiers array */
        $modifiersData = $this->_getParam('modifier', array());
        $modifiers = Zend_Json_Decoder::decode($this->_getParam('modifiers'));
        foreach ($modifiers as $modifierId => $modifier) {
            if (!isset($modifiersData[$modifierId])) {
                $modifiersData[$modifierId] = array();
            }
            $modifiersData[$modifierId] += $modifier;
        }
        
        /* prepare properties array */
        $propertiesData = array();
        $propertyValues = $this->_getParam('property', array());
        $properties = Zend_Json_Decoder::decode($this->_getParam('properties'));
        foreach ($properties as $propertyId => $property) {
            if (!isset($propertiesData[$propertyId])) {
                $propertiesData[$propertyId] = array();
            }
            if (isset($propertyValues[$propertyId])) {
                $propertiesData[$propertyId]['values'] = $propertyValues[$propertyId];
            }
            $propertiesData[$propertyId] += $property;
        }
        
        $product = Ecart::single('catalog/product')->save($productRow);
        $product->setCategoryAssignments($this->_getParam('category'))
            ->setStock($this->_getParam('stock'))
            ->setImage($this->_getParam('images'))
            ->setFeatured(
                $this->_getParam('is_featured'),
                $assignedSites,
                $this->_getParam('featured-date-exp')
            ) //@todo date from - date to
            ->setSpecial($this->_getParam('special'))
            ->setNew($this->_getParam('new'))
            ->setDescription($this->_getParam('desc'))
            ->setVariation($variationsData)
            ->setModifier($modifiersData)
            ->setProperty($propertiesData)
            ->setUrl($this->_getParam('hurl'), $assignedSites);
            
        if (!$prodId) {
            Ecart::dispatch('catalog_product_add_success', array(
                'product' => $product
            ));
        } else {
            Ecart::dispatch('catalog_product_update_success', array(
                'product' => $product
            ));
        }
            
        $this->_helper->json->sendSuccess();
    }
    
    public function batchSaveProductAction()
    {
        $this->layout->disableLayout();
        
        $siteId = $this->_getParam('siteId', $this->_siteId);
        
        $data = Zend_Json::decode($this->_getParam('data'));
        $tableProduct = Ecart::single('catalog/product');
        
        foreach ($data as $id => $values) {
            $product = $tableProduct->find($id)->current();
            $product->setFromArray($values);
            $product->save();
            $product->setFeatured(
                $values['is_featured'], array($siteId), $values['date_exp']
            );
            Ecart::dispatch('catalog_product_update_success', array(
                'product' => $product
            ));
        }
        
        Ecart::message()->addSuccess(
            Ecart::translate('core')->__(
                '%d product(s) was updated successfully', count($data)
            )
        );
        
        $this->_helper->json->sendSuccess();
    }
    
    /**
     * Возвращает данные продукта в JSON формате 
     */
    public function getProductInfoAction()
    {
        $this->layout->disableLayout();
        if ($this->_hasParam('prodId')) {
            $productId = (int) $this->_getParam('prodId');
        } else {
            Ecart::message()->addError(
                Ecart::translate('catalog')->__(
                    'Invalid parameter recieved. ProductId is required'
                )
            );
            return $this->_helper->json->sendFailure();
        }
        $result = array();
        $result['success'] = true;
        
        $product = Ecart::single('catalog/product')->find($productId)->current();
        if (null === $product) {
            Ecart::message()->addError(
                Ecart::translate('catalog')->__(
                    'Product %s not found', $productId
                )
            );
            return $this->_helper->json->sendFailure();
        }
        $result['product'] = $product->toArray();
        
        /* get hurl */
        $tableHurl = Ecart::single('catalog/hurl');
        $result['product']['hurl'] = $tableHurl->getProductUrl($product->id);
        
        /* get description */
        foreach ($product->findDependentRowset(
                'Ecart_Catalog_Model_Product_Description') as $desc) {

            $result['description'][$desc->language_id] = $desc->toArray();
        }
        
        /* get product categories info */
        $result['categories'] = $product->getCategories();
        
        /* get featured */
        foreach ($product->findDependentRowset(
                'Ecart_Catalog_Model_Product_Featured') as $featured) {

            $result['featured'] = $featured->toArray();
        }
        /* get special  price */
        $result['special'] = Ecart::single('discount/discount')
                                ->getSpecialPrice($product->id);
                
        /* get variations */
        foreach ($product->findDependentRowset(
                'Ecart_Catalog_Model_Product_Variation') as $variation) {

            $vid = $variation->id;
            $result['variation'][$vid] = $variation->toArray();
        }
        /* get attributes */
        $optionIds = array();
        $optionValueIds = array();
        foreach ($product->findDependentRowset(
                'Ecart_Catalog_Model_Product_Attribute', 'Product') as $attr) {

            /* collect ids for future load labels */
            $optionIds[$attr->product_option_id] = $attr->product_option_id;
            if ($attr->product_option_value_id) {
                $optionValueIds[$attr->product_option_value_id] =
                    $attr->product_option_value_id;
            }
            
            $result['attributes'][$attr->id] = $attr->toArray();
            $option = $attr->findParentRow('Ecart_Catalog_Model_Product_Option', 'Option');
            $result['attributes'][$attr->id]['sortOrder'] = $option->sort_order;
            $result['attributes'][$attr->id]['inputType'] = $option->option_type;
            $result['attributes'][$attr->id]['languagable'] = $option->languagable;
            if ($option->isInputable() && !$attr->isModifier()) {
                foreach ($attr->findDependentRowset(
                        'Ecart_Catalog_Model_Product_Attribute_Value') as $value) {

                    $result['attributes'][$attr->id]['values'][intval($value->language_id)] = $value->attribute_value;
                }
            }
        }
        
        /* collect & fill labels */
        // options
        if (sizeof($optionIds)) {
            $where = array(
                $this->db->quoteInto('product_option_id IN(?)', $optionIds),
                $this->db->quoteInto('language_id = ?', $this->_langId)
            );
            $optionText = Ecart::single('catalog/product_option_text')
                ->fetchAssoc(null, $where);
        }
        // values
        if (sizeof($optionValueIds)) {
            $where = array(
                $this->db->quoteInto(
                    'product_option_value_id IN(?)', $optionValueIds
                ),
                $this->db->quoteInto('language_id = ?', $this->_langId)
            );
            $optionValueText = Ecart::single('catalog/product_option_value_text')
                ->fetchAssoc(null, $where);
        }
        if (isset($result['attributes'])) {
            uasort($result['attributes'], array($this, '_sortAttributes'));
            foreach ($result['attributes'] as &$attr) {
                $attr['optionName'] = 
                    isset($optionText[$attr['product_option_id']]['name']) ? 
                        $optionText[$attr['product_option_id']]['name'] : '';
                if ($attr['product_option_value_id']) {
                    $attr['valueName'] =
                        $optionValueText[$attr['product_option_value_id']]['name'];
                }
            }
        }
        
        // get all product  images 
        $gallery = Ecart::single('catalog/product_gallery')->getList($productId);
        $result['product']['gallery'] = $gallery; 
        $result['product']['image_base_id'] = NULL; 
        $result['product']['image_listing_id'] = NULL;
        $result['product']['image_thumbnail_id'] = NULL;
        foreach ($gallery as $image) {
            if ($image['image'] == $result['product']['image_base'])
                $result['product']['image_base_id'] = $image['id'];
            if ($image['image'] == $result['product']['image_listing'])
                $result['product']['image_listing_id'] = $image['id'];
            if ($image['image'] == $result['product']['image_thumbnail'])
                $result['product']['image_thumbnail_id'] = $image['id'];
        }
        // get stock 
        $stock = Ecart::single('catalog/product_stock')
            ->find($productId)->current();
        if (is_object($stock)) {
            $result['stock'] = $stock->toArray();
        }
        $this->_helper->json->sendSuccess($result);
    }
    
    private function _sortAttributes($a, $b)
    {
        if ($a['sortOrder'] == $b['sortOrder'])
            return 0;
        return $a['sortOrder'] < $b['sortOrder'] ? -1 : 1;
    }
    
    private function _saveImage($src, $fileName)
    {
        $fileName = str_replace(' ', '_', $fileName);
        $imagesPath = $savePath = Ecart::config()->system->path
            . '/media/product';
        if (!is_readable($savePath)) {
            mkdir($savePath, 0777);
        } elseif(!is_writable($savePath)) {
            chmod($savePath, 0777);
        }
        
        if (!is_writable($imagesPath)) {
            throw new Ecart_Exception(
                Ecart::translate('core')->__(
                    " %s is not writable", $imagesPath
                )
            );
        }
        for ($i = 0; $i < 2; $i++) {
            if (!preg_match('/[a-zA-Z0-9]{1}/', $fileName[$i])) {
                break;
            }
            
            $savePath .= '/' . strtolower($fileName[$i]);
            if (!file_exists($savePath)) {
                @mkdir($savePath, 0777);
            }
        }
        $savePath .= '/' . $fileName;
        $savePath = pathinfo($savePath);
        $ext = strtolower($savePath['extension']);
        $savePath = $savePath['dirname'] . '/' . $savePath['filename'];
        if (file_exists($savePath . '.' . $ext)) {
            $savePath .= rand(10000, 99999);
        }
        @move_uploaded_file($src, $savePath . '.' . $ext);
        return substr($savePath . '.' . $ext, strlen($imagesPath));
    }
    
    public function saveImageAction()
    {
        $this->_helper->layout->disableLayout();
        $saved = array();
        foreach (array_keys($_FILES['images']['name']) as $file) {
            if (!is_uploaded_file($_FILES['images']['tmp_name'][$file])) {
                continue;
            }
            // saving file
            $name = preg_replace(
                '/[^a-zA-Z0-9\.]/', '_', $_FILES['images']['name'][$file]
            );
            try {
                $saved[$file] = $this->_saveImage(
                    $_FILES['images']['tmp_name'][$file], $name
                );
            } catch (Exception $e) {
                Ecart::message()->addError(
                    $e->getMessage()
                );
            }
        }
        $this->getResponse()->appendBody(Zend_Json_Encoder::encode($saved));
    }
        
    public function removeProductAction()
    {
        $productIds = Zend_Json_Decoder::decode($this->_getParam('data'));
        
        Ecart::single('catalog/hurl')->delete(
            $this->db->quoteInto("key_type = 'p' AND key_id IN(?)", $productIds)
        );
        
        Ecart::dispatch('catalog_product_remove_success', array(
            'product_ids' => $productIds
        ));
        
        return $this->_helper->json->sendJson(array(
            'status' => Ecart::single('catalog/product')
                ->delete($this->db->quoteInto('id IN(?)', $productIds))
        ));
    }
    
    public function removeProductFromCategoryAction()
    {
        $productIds = Zend_Json_Decoder::decode($this->_getParam('prodIds'));
        $categoryId = $this->_getParam('catId');
        return $this->_helper->json->sendJson(array(
            'status' => Ecart::single('catalog/product_category')->delete(array(
                $this->db->quoteInto('category_id = ? ', $categoryId),
                $this->db->quoteInto('product_id IN(?)', $productIds)
            ))
        ));
    }
    
    public function removeProductFromSiteAction()
    {
        $productIds = Zend_Json_Decoder::decode($this->_getParam('prodIds'));
        $siteId = $this->_getParam('siteId');
        $categoryIds = Ecart::single('catalog/category')
            ->getSiteCategories($siteId);
        
        return $this->_helper->json->sendJson(array(
            'status' => Ecart::single('catalog/product_category')->delete(array(
                $this->db->quoteInto('category_id IN(?)', $categoryIds),
                $this->db->quoteInto('product_id IN(?)', $productIds)
            ))
        ));
        
    }
    
    public function moveProductsAction()
    {
        $data = Zend_Json_Decoder::decode($this->_getParam('data'));
        $currentCategoryId = $this->_getParam('currentCategoryId');
        $success = array();
        foreach ($data as $product) {
            foreach ($product['actions'] as $categoryId => $action ) {
                if ($action == 'cut') {
                    Ecart::single('catalog/product_category')->delete(array(
                        $this->db->quoteInto('product_id = ?', $product['product_id']),  
                        $this->db->quoteInto('category_id = ?', $categoryId)
                    ));
                }
            }
            if ($product['product_id'] && empty($success[$product['product_id']])) {

                Ecart::single('catalog/product_category')->delete(array(
                    $this->db->quoteInto('category_id = ?', $currentCategoryId),
                    $this->db->quoteInto('product_id = ?', $product['product_id'])
                ));
                Ecart::single('catalog/product_category')->insert(array(
                    'category_id' => $currentCategoryId,
                    'product_id' => $product['product_id']
                ));
            }

            $success[$product['product_id']] = true; 
        }
        //$dat = current($data);
        $this->_helper->json->sendJson(array(
            'success' => $success
        ));
    }
    
    public function updateSearchIndexAction()
    {
//        $this->_helper->layout->disableLayout();

        @require_once(
            Ecart::config()->system->path . '/scripts/searchIndexMaker.php'
        );

        Ecart::message()->addSuccess(
            Ecart::translate('catalog')->__(
                'Search indexes updated successfully'
        ));

//        return $this->_helper->json->sendSuccess();
        $this->_redirect($_SERVER['HTTP_REFERER']);
    }
}