<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @category    Ecart
 * @package     Ecart_Admin
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 * 
 * @category    Ecart
 * @package     Ecart_Admin
 * @subpackage  Controller
 * @author      Ecart Core Team <core@ecartcommerce.com>
 */
class Ecart_Admin_Catalog_ManufacturerController extends Ecart_Admin_Controller_Back
{
    public function indexAction()
    {
        $this->view->pageTitle = Ecart::translate('catalog')->__('Manufacturer');
        $this->render();
    }
    
    public function listAction()
    {
        $result = array();
        foreach (Ecart::single('catalog/product_manufacturer')
                    ->getListBackend() as $manufacturer) {
            
            if (!isset($result[$manufacturer['id']])) {
                $result[$manufacturer['id']] = $manufacturer;
            }
            $result[$manufacturer['id']]['title_' . $manufacturer['language_id']] = $manufacturer['title'];
        }
        
        return $this->_helper->json->sendSuccess(array(
            'data' => array_values($result)
        ));
    }
    
    private function _saveImage($src, $fileName)
    {
        $fileName = str_replace(' ', '_', $fileName);
        $fileName = pathinfo($fileName);
        $imagesPath = $savePath = Ecart::config()->system->path
            . '/media/manufacturer';
        if (!is_readable($savePath)) {
            mkdir($savePath, 0777);
        } elseif(!is_writable($savePath)) {
            chmod($savePath, 0777);
        }
        $savePath .= $fileName['dirname'] != '.' ?
            '/' . $fileName['dirname'] : '';
        $savePath .= '/' . $fileName['filename'];
        $ext = strtolower($fileName['extension']);
        
        if (file_exists($savePath . '.' . $ext)) {
            $savePath .= rand(10000, 99999);
        }
        $savePath .= '.' . $ext;
        @move_uploaded_file($src, $savePath);
        return substr($savePath, strlen($imagesPath));
    }
    
    public function saveImageAction()
    {
        $this->_helper->layout->disableLayout();
        if (is_uploaded_file($_FILES['manufacturer-image']['tmp_name'])) {
            $name = preg_replace(
                '/[^a-zA-Z0-9\.]/', '_', $_FILES['manufacturer-image']['name']
            );
            $saved = $this->_saveImage(
                $_FILES['manufacturer-image']['tmp_name'], $name
            );
            $this->getResponse()->appendBody(Zend_Json_Encoder::encode($saved));
        }
    }
    
    public function saveAction()
    {
        $this->_helper->layout->disableLayout();
        
        $this->_helper->json->sendJson(array(
            'success' => Ecart::single('catalog/product_manufacturer')->save(
                $this->_getParam('data')
             )
        ));
    }
    
    public function batchSaveAction()
    {
        $this->_helper->layout->disableLayout();
        
        $this->_helper->json->sendJson(array(
            'success' => Ecart::single('catalog/product_manufacturer')->save(
                Zend_Json_Decoder::decode($this->_getParam('data'))
             )
        ));
    }
   
    public function deleteAction()
    {
        $ids = Zend_Json_Decoder::decode($this->_getParam('data'));
        if (!count($ids)) {
            Ecart::message()->addError(
                Ecart::translate('catalog')->__(
                    'Invalid data recieved'
                )
            );
            return $this->_helper->json->sendFailure();
        }
        $this->_helper->json->sendJson(array(
            'success' => Ecart::single('catalog/product_manufacturer')
                ->deleteByIds($ids)
        ));
    }
}