<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @category    Ecart
 * @package     Ecart_Admin
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 * 
 * @category    Ecart
 * @package     Ecart_Admin
 * @subpackage  Controller
 * @author      Ecart Core Team <core@ecartcommerce.com>
 */
class Ecart_Admin_Catalog_ProductOptionValuesetController extends Ecart_Admin_Controller_Back
{
    public function indexAction()
    {
        $this->view->pageTitle = Ecart::translate('catalog')->__('Value Sets');
        $this->view->languages = Ecart_Collect_Language::collect();
        $this->render();
    }
    
    public function listSetsAction()
    {
        $this->_helper->layout->disableLayout();
        
        $dbField = new Ecart_Filter_DbField();
        
        $tableSet = Ecart::single('catalog/product_option_ValueSet');
        
        $count  = $tableSet->count();
        
        $order = $dbField->filter($this->_getParam('sort', 'id')) . ' '
               . $dbField->filter($this->_getParam('dir', 'ASC'));
        
        $data = $tableSet->fetchAll(
            null,
            $order,
            intval($this->_getParam('limit', 20)),
            intval($this->_getParam('start', 0))
        )->toArray();
        
        return $this->_helper->json->sendSuccess(array(
            'data' => array_values($data),
            'count'   => $count
        ));
    }
    
    public function saveSetAction()
    {
        $this->_helper->layout->disableLayout();
        
        $data = Zend_Json::decode($this->_getParam('data'));
        
        return $this->_helper->json->sendJson(array(
            'success' => Ecart::single('catalog/product_option_ValueSet')
                ->save($data)
        ));
    }
    
    public function deleteSetsAction()
    {
        $this->_helper->layout->disableLayout();
        
        $ids = Zend_Json_Decoder::decode($this->_getParam('data'));
        
        if (!count($ids)) {
            Ecart::message()->addError(
                Ecart::translate('admin')->__(
                    'No data to delete'
                )
            );
            return $this->_helper->json->sendFailure();
        }
        Ecart::single('catalog/product_option_ValueSet')->delete(
            $this->db->quoteInto('id IN(?)', $ids)
        );
        Ecart::message()->addSuccess(
            Ecart::translate('catalog')->__(
                'Value Set was deleted sucessfully'
            )
        );
        return $this->_helper->json->sendSuccess();
    }
    
    public function listValuesAction()
    {
        $this->_helper->layout->disableLayout();
        $setId = $this->_getParam('setId', 0);
        
        $rows = Ecart::single('catalog/product_option_value')
            ->fetchAll($this->db->quoteInto('valueset_id = ?', $setId));
        
        $values = array();
        foreach ($rows as $row) {
            $values[$row->id] = $row->toArray();
        }
        
        if (sizeof($values)) {
            $rows = Ecart::single('catalog/product_option_value_text')
                ->fetchAll($this->db->quoteInto('product_option_value_id IN(?)',
                    array_keys($values))
                );
            foreach ($rows as $row) {
                $values[$row->product_option_value_id]['name_' . $row->language_id]
                    = $row->name;
            }
        }
        
        return $this->_helper->json->sendSuccess(array(
            'data' => array_values($values)
        ));
    }
    
    public function saveValuesAction()
    {
        $this->_helper->layout->disableLayout();
        
        $valuesetId = $this->_getParam('setId', 0);
        $data = Zend_Json::decode($this->_getParam('data'));
        
        return $this->_helper->json->sendJson(array('success' =>
            Ecart::single('catalog/product_option_value')
                ->save($valuesetId, $data)
        ));
    }
    
    public function deleteValuesAction()
    {
        $this->_helper->layout->disableLayout();
        
        $ids = Zend_Json_Decoder::decode($this->_getParam('data'));
        
        if (!count($ids)) {
            Ecart::message()->addError(
                Ecart::translate('admin')->__(
                    'No data to delete'
                )
            );
            return $this->_helper->json->sendFailure();
        }
        
        Ecart::single('catalog/product_option_value')->delete(
            $this->db->quoteInto('id IN(?)', $ids)
        );

        Ecart::message()->addSuccess(
            Ecart::translate('catalog')->__(
                'Value was deleted sucessfully'
            )
        );
        return $this->_helper->json->sendSuccess();
    }
}