<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @category    Ecart
 * @package     Ecart_Admin
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 * 
 * @category    Ecart
 * @package     Ecart_Admin
 * @subpackage  Controller
 * @author      Ecart Core Team <core@ecartcommerce.com>
 */
class Ecart_Admin_Community_ReviewController extends Ecart_Admin_Controller_Back
{
    public function indexAction()
    {
        $this->view->pageTitle = Ecart::translate('community')->__(
            'Community reviews'
        );
        if ($this->_hasParam('review')) {
            $this->view->review = $this->_getParam('review');
        }
        $this->render();
    }
    
    public function getListAction()
    {
        $this->_helper->layout->disableLayout();
        
        $limit = $this->_hasParam('limit') ? $this->_getParam('limit') : 20;
        $page = $this->_hasParam('page') ? $this->_getParam('page') : null;
        $dir = $this->_hasParam('dir') ? $this->_getParam('dir') : 'DESC';
        $order = $this->_hasParam('sort') ? $this->_getParam('sort') : 'cr.date_created';
        
        $reviews = Ecart::single('community/review')->getList(null, $order, $dir, $limit, $page, true);
        
        $this->_helper->json->sendSuccess(array(
            'totalCount' => $reviews['count'],
            'data' => $reviews['reviews']
        ));
    }
    
    public function getProductListAction()
    {
        $this->_helper->layout->disableLayout();
        $filters = array(
            'order' => 'name',
            'dir' => 'ASC',
            'start' => $this->_hasParam('start') ? $this->_getParam('start') : 0,
            'limit' => $this->_hasParam('limit') ? $this->_getParam('limit') : 40
        );
        if ($this->_hasParam('id')) {
            $filters['product_id'] = $this->_getParam('id');
        } elseif ($this->_getParam('query') != '') {
            $filters['product_name'] = $this->_getParam('query');
        }
        $data = Ecart::single('catalog/product')->getProductsByFilter($filters);
        $count = $data['count'];
        unset($data['count']);
        $this->_helper->json->sendSuccess(array(
            'totalCount' => $count,
            'data' => array_values($data)
        ));
    }
    
    public function getCustomerListAction()
    {
        $this->_helper->layout->disableLayout();
        $filters = array(
            'sort' => 'email',
            'dir' => 'ASC',
            'start' => $this->_hasParam('start') ? $this->_getParam('start') : 0,
            'limit' => $this->_hasParam('limit') ? $this->_getParam('limit') : 40
        );
        if ($this->_hasParam('id')) {
            $filters['customer_id'] = $this->_getParam('id');
        } elseif ($this->_getParam('query') != '') {
            $filters['customer_email'] = $this->_getParam('query');
        }
        $data = Ecart::single('account/customer')->getList($filters);
        $this->_helper->json->sendSuccess(array(
            'totalCount' => $data['count'],
            'data' => array_values($data['accounts'])
        ));
    }
    
    public function saveAction()
    {
        $this->_helper->layout->disableLayout();
        
        $data = $this->_getAllParams();
        if (empty($data['customer_id'])) {
            $data['customer_id'] = new Zend_Db_Expr('NULL');
        }
        $data['ratings'] = array();
        foreach ($data['rating'] as $key => $rating) {
            $data['ratings'][$key] = $rating; 
        }
        
        $this->_helper->json->sendJson(array(
            'success' => Ecart::single('community/review')->save($data)
        ));
    }
    
    public function deleteAction()
    {
        $this->_helper->layout->disableLayout();
        
        Ecart::single('community/review')
            ->remove(Zend_Json_Decoder::decode($this->_getParam('data')));
            
        $this->_helper->json->sendSuccess();
    }
}