<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @category    Ecart
 * @package     Ecart_Admin
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 * 
 * @category    Ecart
 * @package     Ecart_Admin
 * @subpackage  Controller
 * @author      Ecart Core Team <core@ecartcommerce.com>
 */
class Ecart_Admin_ModuleController extends Ecart_Admin_Controller_Back
{
    
    /* admin module */
    public function indexAction()
    {
        $this->view->pageTitle = Ecart::translate('admin')->__(
            'Modules'
        );
        $this->render();
    }
    
    public function getListAction()
    {
        $this->_helper->layout->disableLayout();
        
        $modules = Ecart::single('core/module')->getModules();
        $installed_modules = Ecart::single('core/module')->getList();
        //print_r($modules);
        $result = array();
        $i = 0;
        foreach ($modules as $code => $values) {
            $result[$i]['code'] = $code;
            $result[$i]['name'] = $values['name'];
            $result[$i]['package'] = $values['package'];
            $result[$i]['version'] = '';
            $result[$i]['hide_install'] = !$values['has_install'];
            $result[$i]['hide_upgrade'] = $values['has_install'] ? true : !$values['has_upgrade'];
            $result[$i]['hide_uninstall'] = true;
            $result[$i]['is_active'] = 0;
            $result[$i]['install_tooltip'] = Ecart::translate('admin')->__(
                'Install %s', $values['install_tooltip']
            );
            
            if (isset($installed_modules[$code])) {
                $result[$i]['hide_install'] = true;
                $result[$i]['hide_uninstall'] = !$values['has_uninstall'];
                $result[$i]['hide_upgrade'] = !$values['has_upgrade'];
                $result[$i]['upgrade_tooltip'] = Ecart::translate('admin')->__(
                    'Upgrade to %s', $values['upgrade_tooltip']
                );
                $result[$i]['is_active'] = $installed_modules[$code]['is_active'];
                $result[$i]['version'] = $installed_modules[$code]['version'];
            }
            $i++;
        }
        
        return $this->_helper->json->sendSuccess(array(
            'data' => $result
        ));
    }
    
    public function installAction()
    {
        $this->_helper->layout->disableLayout();
        
        return $this->_helper->json->sendJson(array(
            'success' => Ecart::single('core/module')->install($this->_getParam('code'))
        ));
    }
    
    public function uninstallAction()
    {
        $this->_helper->layout->disableLayout();
        
        return $this->_helper->json->sendJson(array('success' =>
            Ecart::single('core/module')->uninstall($this->_getParam('code'))
        ));
    }
    
    public function upgradeAction()
    {
        $this->_helper->layout->disableLayout();
        
        return $this->_helper->json->sendJson(array('success' =>
            Ecart::single('core/module')->upgrade($this->_getParam('code'))
        ));
    }
    
}