<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @category    Ecart
 * @package     Ecart_Admin
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 * 
 * @category    Ecart
 * @package     Ecart_Admin
 * @subpackage  Controller
 * @author      Ecart Core Team <core@ecartcommerce.com>
 */
class Ecart_Admin_Poll_IndexController extends Ecart_Admin_Controller_Back
{
    /**
     * Question model
     *
     * @var Ecart_Poll_Model_Question
     */
    protected $_table;
    
    public function init()
    {
        parent::init();
        $this->_table = Ecart::single('poll/question');
    }
    
    public function indexAction()
    {
        $this->view->pageTitle = Ecart::translate('poll')->__('Polls');
        $this->view->languages = Ecart_Collect_Language::collect();
        $this->view->currentLanguageId = $this->_langId;
        $this->view->sitesList = Ecart::single('core/site')
            ->fetchAll()->toArray();
        $this->view->sites = Ecart_Collect_Site::collect();
        $this->render();
    }
    
    public function listAction()
    {
        $this->_helper->layout->disableLayout();
        $questions = $this->_table->getQuestions();
        $this->_helper->json->sendSuccess(array('data' => $questions));
    }
    
    public function getQuestionAction()
    {
        $questionId = $this->_getParam('questionId');
        $boolGetResult = $this->_getParam('getResult', false);
        $results = array();
        $totalCount = 0; 
        if ($boolGetResult) {
            $results = $this->_table
                ->find($questionId )->current()->getResults();
            $totalCount = $this->_table
                ->find($questionId)->current()->getTotalCount();
        }
        $params = array(
            'questionId' => $questionId
        );
        $answers = Ecart::single('poll/answer')->getAnswers($params);
        
        $question = $this->_table->getQuestionById($questionId);
        $question['questionId'] = $questionId;   
        $question['lock_status'] = $this->_table->getStatusById($questionId);
        $question['sites'] = Ecart::single('poll/question_site')
            ->getSitesIds($questionId);
        
        $data = array();
        foreach($answers as $answer){
            $data[] = array ( 
                'id' => $answer['id'],
                'answer' => $answer['answer'],
                'languageId' => $answer['language_id'],
                'count' => isset($results[$answer['id']]) ? 
                    $results[$answer['id']]['cnt'] : "0" ,
                'percent' => isset($results[$answer['id']]) ? 
                    round($results[$answer['id']]['cnt']*100/$totalCount,2) : "0"
            );
        }
        $this->_helper->json->sendSuccess(
            array('question' => $question, 'answers' => $data)
        );
    }
    
    public function saveAction()
    {
        $this->_helper->layout->disableLayout();
        $lock = $this->_getParam('lock', 0);
        $data = array(
           'changed_at' => Ecart_Date::now()->toZendDbExpr(),
           'lock_status' => $lock,
           'type' => $this->_getParam('type_choice', 0)
        );
        $languages = Ecart_Collect_Language::collect();
        $come = $this->_getAllParams();
        $questionId   = $this->_getParam('questionId');
        
        /*
         * Saving question
         */
        if (!$questionId) {
	        $data['created_at'] = Ecart_Date::now()->toZendDbExpr();
	        $questionId = $this->_table->insert($data);
        } else {
            $this->_table->update(
                $data, $this->db->quoteInto('id = ?', $questionId)
            );
        }
        $tableQuestionDescription = Ecart::single('poll/question_description');
        foreach ($languages as $languageId => $language ) {
            $dataQuestionDescription = array(
                'question' => $come['question'][$languageId],
                'language_id' => $languageId,
                'question_id' => $questionId
            );
            $tableQuestionDescription->set($dataQuestionDescription);
        }    
        if (isset($come['site_ids'])) {
            $sites = $come['site_ids'];
            Ecart::single('poll/question_site')->set($sites, $questionId);
        }
        
        /*
         * Saving answers
         */
        $tableAnswer = Ecart::single('poll/answer');
        $tableAnswerDescription = Ecart::single('poll/answer_description');
        $answers = $come['answer'];
        foreach ($answers as $answerId => $answer) {
            $tableAnswerId = $tableAnswer->set(array(
	            'question_id' => $questionId, 
	            'id' => $answerId
            ));
            foreach ($languages as $languageId => $language) {
                
                $tableAnswerDescription->set(array(
	                'answer' => $answer[$languageId], 
	                'answer_id' => $tableAnswerId, 
	                'language_id' => $languageId
                ));

            }
            
        }
        $deleteAnswersIds = Zend_Json_Decoder::decode(
            $this->_getParam('deleteAnswersIds')
        );
        if ($deleteAnswersIds) {
            $tableAnswer->delete(
                $this->db->quoteInto('id IN(?)', $deleteAnswersIds)
            );
        }
        $this->_helper->json->sendSuccess();
    }       
    
    public function deleteAction()
    {
        $this->_helper->layout->disableLayout();
        $ids = Zend_Json_Decoder::decode($this->_getParam('data'));
        if (!$ids) {
            return $this->_helper->json->sendFailure();
        }
        $this->_table->delete($this->db->quoteInto('id IN(?)', $ids));
        $this->_helper->json->sendSuccess();
    }
    
    public function quickSaveAction()
    {        
        $this->_helper->layout->disableLayout();
        $data = Zend_Json_Decoder::decode($this->_getParam('data'));
        if (!$data) 
            return;
        foreach ($data as $id => $item) {
            $this->_table->update(
                array(
		            'changed_at' => Ecart_Date::now()->toZendDbExpr(),
		            'lock_status' => $item['status'] ? 1 : 0,
                    'type' => $item['type'] ? 1 : 0
	            ), 
	            $this->db->quoteInto('id = ?', $id)
	        );
	        Ecart::single('poll/question_site')->set(
                    explode(',', $item['sites']), $id
                );
        }
        $this->_helper->json->sendSuccess();
    }
    
    public function clearAction()
    {
        $this->_helper->layout->disableLayout();
        $ids = Zend_Json_Decoder::decode($this->_getParam('data'));
        if (!$ids) {
            return $this->_helper->json->sendFailure();
        }
        $answersIds = array();
        $tableAnswer = Ecart::single('poll/answer');
        foreach ($ids as $questionId)  {
            $answersIds = array_merge(
                $tableAnswer->getAnswerIds($questionId), $answersIds
            );
        }
        Ecart::single('poll/vote')->delete(
            $this->db->quoteInto('answer_id IN(?)', $answersIds)
        );

        $this->_helper->json->sendSuccess();
    }
    
}
