<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @category    Ecart
 * @package     Ecart_Admin
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 * 
 * @category    Ecart
 * @package     Ecart_Admin
 * @subpackage  Controller
 * @author      Ecart Core Team <core@ecartcommerce.com>
 */
class Ecart_Admin_Sales_OrderController extends Ecart_Admin_Controller_Back
{
    /**
     * Orders table model
     *
     * @var Ecart_Sales_Model_Order
     */
    private  $_table;
    
    public function init()
    {
        parent::init();
        $this->_table = Ecart::single('sales/order');
    }
    
    public function indexAction()
    {
        $this->view->pageTitle = Ecart::translate('sales')->__('Orders');
        
        $this->view->orderStatuses = array_values(
            Ecart::single('sales/order_status_text')->getList()
        );
        
        if ($this->_hasParam('orderId')) {
            $this->view->orderId = $this->_getParam('orderId');
        }
        
        $this->render();
    }
    
    public function listAction()
    {
        $this->_helper->layout->disableLayout();
        
        $params = array (   
            'sort' => $this->_getParam('sort', 'id'),
            'dir' => $this->_getParam('dir', 'DESC'),
            'limit' => $this->_getParam('limit', 20),
            'start' => $this->_getParam('start', 0),
            'filter' => $this->_getParam('filter', false)
        );
        
        $count  = $this->_table->countByFilter($params);
        $data = $this->_table->getList($params);
        $currency = Ecart::single('locale/currency');
        
        foreach ($data as &$item) {
            $item['order_total'] = $item['order_total'] * $item['currency_rate']
                .  ' ' . $item['currency'];
            $item['delivery_name'] = $item['delivery_firstname']
                . ' ' . $item['delivery_lastname'];
            $item['billing_name'] = $item['billing_firstname']
                . ' ' . $item['billing_lastname'];
        }
        
        $this->_helper->json->sendSuccess(array(
            'data'  => array_values($data),
            'count' => $count
        ));
    }
    
    public function getOrderInfoAction()
    {
        $this->_helper->layout->disableLayout();
        
        $orderId = $this->_getParam('orderId');
        
        $order = $this->_table->find($orderId)->current();

        $this->view->currency = $order->currency;
        $this->view->orderProducts = $order->getProducts();
        foreach($this->view->orderProducts as &$product) {
            $product['product_price'] =
                $product['product_price'] * $order->currency_rate;
            $product['final_price'] =
                $product['final_price'] * $order->currency_rate;
        }
        
        $this->view->orderTotals = $order->getTotals();
        foreach ($this->view->orderTotals as &$total) {
           
            $total['value'] = $total['value'] * $order->currency_rate;
        }
        
        $this->view->orderStatusHistory = $order->getStatusHistory();
        $this->view->order = $order->toArray();
        $this->view->order['status_name'] =
            Ecart_Collect_OrderStatusText::getName($order->order_status_id);
        $this->view->order['site_name'] =
            Ecart_Collect_Site::getName($order->site_id);
        // convert price with rates that was available
        // during order was created (not current rates)
        $this->view->order['order_total'] =
            $order->order_total * $order->currency_rate;
        
        $this->_helper->json->sendSuccess(array(
            'info'          => $this->view->render(
                'sales-order/info.phtml'
            ),
            'products'      => $this->view->render(
                'sales-order/products.phtml'
            ),
            'statusHistory' => $this->view->render(
                'sales-order/status-history.phtml'
            )
        ));
    }
    
    public function getStatusHistoryAction()
    {
        $this->_helper->layout->disableLayout();
        
        $orderId = $this->_getParam('orderId');
        
        $order = $this->_table->find($orderId)->current();
        
        $this->view->orderStatusHistory = $order->getStatusHistory();
        
        $this->_helper->json->sendSuccess(array(
            'order_status_id' => $order->order_status_id,
            'status_name'     =>
                Ecart_Collect_OrderStatusText::getName($order->order_status_id),
            'statusHistory'   => $this->view->render(
                'sales-order/status-history.phtml'
            )
        ));
    }
    
    public function setStatusAction()
    {
        $this->_helper->layout->disableLayout();
        
        $params = $this->_getAllParams();
        
        if (empty($params['order_status_id'])) {
            Ecart::message()->addError(
                Ecart::translate('sales')->__(
                    'Order not found'
                )
            );
            return $this->_helper->json->sendFailure();
        }
        
        $order = $this->_table->find($params['orderId'])->current();
        
        if (!$order) {
            Ecart::message()->addError(
                Ecart::translate('sales')->__(
                    'Order not found'
                )
            );
            return $this->_helper->json->sendFailure();
        }
        
        $order->setStatus(
            $params['order_status_id'], 
            $params['comment'], 
            isset($params['notify_customer'])
        );

        return $this->_helper->json->sendSuccess();
    }
    
    public function deleteAction() 
    {
    	$this->_helper->layout->disableLayout();
    	
    	$ids = Zend_Json_Decoder::decode($this->_getParam('data'));
    	
        if (!sizeof($ids)) {
            Ecart::message()->addError(
                Ecart::translate('admin')->__(
                    'No data to delete'
                )
            );
            return $this->_helper->json->sendFailure();
        }
        
    	$this->_table->delete($this->db->quoteInto('id IN(?)', $ids));

        Ecart::message()->addSuccess(
            Ecart::translate('sales')->__(
                'Order was deleted successfully'
            )
        );
    	return $this->_helper->json->sendSuccess();
    }
    
    public function printAction()
    {   
        $this->_helper->layout->disableLayout();
        
        $orderIds = Zend_Json_Decoder::decode($this->_getParam('data'));
        
        if (!sizeof($orderIds)) {
            Ecart::message()->addError(
                Ecart::translate('sales')->__(
                    'No data to print'
                )
            );
            return $this->_redirect('sales_order');
        }
        asort($orderIds);
        $rows = $this->_table->fetchAssoc(
            'id', "id IN(" . implode(', ', $orderIds) .")"
        );
        
        $orders = array();
        $firstOrderId = current($orderIds);
        
        foreach ($orderIds as $id) {
            $orders[$id] = $rows[$id]->toArray();
            $orders[$id]['products'] = $rows[$id]->getProducts();
            $orders[$id]['totals'] = $rows[$id]->getTotals();
            $orders[$id]['addresses'] = $rows[$id]->getAddresses();
            $orders[$id]['shipping'] = $rows[$id]->getShipping();
            $orders[$id]['shippingTax'] = $rows[$id]->getShippingTax();
            $orders[$id]['subtotal'] = $rows[$id]->getSubtotal();
            $orders[$id]['tax'] = $rows[$id]->getTax();
            $orders[$id]['company'] = Ecart::single('core/site')
                ->getCompanyInfo($rows[$id]->site_id);
        }
        
        $this->view->label = $this->_getParam('label', 'false');
        $pdfFileName =  'order-';
        if ($this->view->label != 'true') {
            $this->view->invoice = $this->_getParam('invoice', 'true');
            $this->view->packingslip = $this->_getParam('packingslip', 'false');
            $pdfFileName .= ($this->view->invoice === 'true' ? 'invoice-' : '')
                         . ($this->view->packingslip === 'true' ? 'packingslip-' : '');
        } else {
            $this->view->addressType = $this->_getParam('addressType', 'billing');
            $pdfFileName .= $this->view->addressType . '-';
        }
        
        $this->view->orders = $orders;
        $script = $this->getViewScript('print', false);
        $content = $this->view->render($script);
        //echo $content; exit();
        $pdf = new Ecart_Pdf();
        $pdf->setContent($content);
        $pdf->getPdf($pdfFileName 
            . ($firstOrderId != end($orderIds) ?
                $firstOrderId . '-' . end($orderIds) : $firstOrderId)
            . '.pdf'
        );
    }
}