<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @category    Ecart
 * @package     Ecart_Admin
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 * 
 * @category    Ecart
 * @package     Ecart_Admin
 * @subpackage  Controller
 * @author      Ecart Core Team <core@ecartcommerce.com>
 */
class Ecart_Admin_Tag_IndexController extends Ecart_Admin_Controller_Back
{
    /**
     *
     * @var Ecart_Tag_Model_Customer
     */
    private $_table;
    
    public function init()
    {
        parent::init();
        $this->_table = Ecart::single('tag/customer');
    }
    
    public function indexAction()
    {
        $this->view->pageTitle = Ecart::translate('tag')->__('Tags');
        if ($this->_hasParam('tagId')) {
            $this->view->tagId = $this->_getParam('tagId');
        }
        $this->render();
    }
    
    public function listAction()
    {
        $field = new Ecart_Filter_DbField();
        if ($this->_hasParam('tagId')) {
            $this->view->tagId = $this->_getParam('tagId');
        }
        $params = array(
            'start' => (int) $this->_getParam('start', 0),
            'limit' => (int) $this->_getParam('limit', 20),
            'sort' => $field->filter($this->_getParam('sort', 'id')),
            'dir' => $field->filter($this->_getParam('dir', 'DESC')),
            'languageId' => $this->_langId,
            'filters' => $this->_getParam('filter', array())
        );
        
        return $this->_helper->json->sendSuccess(array(
            'data' => $this->_table->getList($params),
            'count' => $this->_table->getCount($params)
        ));
    }
    
    public function deleteAction()
    {
        $this->layout->disableLayout();
        $data = Zend_Json::decode($this->_getParam('data'));
        if (!sizeof($data)) {
            return;
        }
        
        $this->_helper->json->sendJson(array(
            'success' => (bool) $this->_table->delete(
                $this->db->quoteInto('id IN(?)', $data)
            )
        ));
    }
    
    public function saveAction()
    {
        $this->_helper->layout->disableLayout();
        $data = Zend_Json_Decoder::decode($this->_getParam('data'));
        if (!$data) {
            return $this->_helper->json->sendFailure();
        }
        $success = true;
        foreach ($data as $tagRow) {
            $tag = $this->_table->find($tagRow['id'])->current();
            $tag->status = $tagRow['status'];
            $success = $success && (bool)$tag->save();
        }    
        
        $this->_helper->json->sendJson(array('success' => $success));
    }
}