<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @category    Ecart
 * @package     Ecart_Catalog
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 * 
 * @category    Ecart
 * @package     Ecart_Catalog
 * @subpackage  Model
 * @author      Ecart Core Team <core@ecartcommerce.com>
 */
class Ecart_Catalog_Model_Hurl extends Ecart_Db_Table
{
    protected $_name = 'catalog_hurl';
    protected $_primary = array('key_word', 'site_id');
    
    public function insert(array $data)
    {
        if (!empty($data['key_word']) && !$this->hasKeyWord($data['key_word'])) {
            return parent::insert($data);
        }
        return false;
    } 
    public function saveProductUrl($data)
    {
        $data['key_type'] = 'p';
        return $this->save($data);
    }
    
    public function getProductUrl($productId)
    {
        $where = array(
            "key_type = 'p'",
            'key_id = ' . $productId
        );
        $row = $this->fetchRow($where);
        if ($row) {
            return $row->key_word;
        }
        return '';
    }
    
    public function save($data)
    {
        $where = array(
            'site_id = ' . $data['site_id'],
            'key_id = '  . $data['key_id'],
            "key_type = '{$data['key_type']}'" 
        );
        $row = $this->fetchRow($where);
        if ($row) {
            $row->key_word = $data['key_word'];
        } else {
            $row = $this->createRow();
            $row->setFromArray($data);
            $row->key_type = $data['key_type'];
        }
        return $row->save();
    }
    
    /**
     * Detects is url is already in table
     * 
     * @param string $keyWord
     * @param int|array $siteId
     * @param int $keyId - id to skip
     * @return bool
     */
    public function hasDuplicate($keyWord, $siteIds = null, $keyId = null) 
    {
        if (null === $siteIds) {
            $siteIds = Ecart::getSiteId();
        }
        $select = $this->select()
            ->where('key_word = ?', $keyWord)
            ->where('site_id IN (?)', $siteIds);
            
        if ($keyId) {
            $select->where('key_id <> ?', $keyId);
        }
        
        return !is_null($this->fetchRow($select));
    } 
}