<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @category    Ecart
 * @package     Ecart_Catalog
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 * 
 * @category    Ecart
 * @package     Ecart_Catalog
 * @subpackage  Model
 * @author      Ecart Core Team <core@ecartcommerce.com>
 */
class Ecart_Catalog_Model_Product_Attribute extends Ecart_Db_Table
{
    protected $_name = 'catalog_product_attribute';
    protected $_rowClass = 'Ecart_Catalog_Model_Product_Attribute_Row';
    protected $_dependentTables = array(
        'Ecart_Catalog_Model_Product_Attribute_Value'
    );
    protected $_referenceMap = array(
        'Product' => array(
            'columns'           => 'product_id',
            'refTableClass'     => 'Ecart_Catalog_Model_Product',
            'refColumns'        => 'id'
        ),
        'Variation' => array(
            'columns'           => 'product_variation_id',
            'refTableClass'     => 'Ecart_Catalog_Model_Product_Variation',
            'refColumns'        => 'id'
        ),
        'Option' => array(
            'columns'           => 'product_option_id',
            'refTableClass'     => 'Ecart_Catalog_Model_Product_Option',
            'refColumns'        => 'id'
        )
    );

    /**
     *
     * @param array $data
     * @return mixed
     */
    public function insert(array $data)
    {
        if (empty($data['weight']))
            $data['weight'] = '0';
        if (empty($data['price']))
            $data['price'] = '0';
        return parent::insert($data);
    }
    
    /**
     * Return options that are used in some product.
     * Each row of returned rowset is Ecart_Catalog_Model_Product_Option_Row 
     * 
     * @return Zend_Db_Table_Rowset_Abstract
     */
    public function getUsedOptions()
    {
        $select = $this->select()->from(
            $this->_name, new Zend_Db_Expr('distinct `product_option_id`')
        );
        $optionIds = $this->getAdapter()->fetchCol($select);
        return Ecart::single('catalog/product_option')->find($optionIds);
    }

    /**
     *
     * @param array $productIds
     * @return array
     */
    public function getDiscountAtrributeFiltersByProductIds(array $productIds)
    {
        $result = array();
        $rowset = $this->fetchAll($this->getAdapter()
            ->quoteInto('product_id IN(?)', $productIds));
        foreach ($rowset as $row) {
            $result[$row->product_id][$row->product_variation_id][$row->id] =
                array(
                    'optionId' => $row->product_option_id,
                    'optionValueId' => $row->product_option_value_id
                );
        }
        return $result;
    }
}