<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @category    Ecart
 * @package     Ecart_Checkout
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 * 
 * @category    Ecart
 * @package     Ecart_Checkout
 * @subpackage  Controller
 * @author      Ecart Core Team <core@ecartcommerce.com>
 */
class Ecart_Checkout_CartController extends Ecart_Checkout_Controller_Checkout
{
    /**
     * Return shopping cart instanse
     *
     * @return Ecart_Checkout_Model_Cart
     */
    public function init()
    {
        parent::init();
        $this->view->crumbs()->add(
            Ecart::translate('checkout')->__(
                'Shopping Cart'
            ),
            '/checkout/cart'
        );
        $this->view->meta()->setTitle(
            Ecart::translate('checkout')->__(
                'Shopping Cart'
        ));
    }
    
    /**
     * Shopping Cart
     * 
     * @return Ecart_Checkout_Model_Cart
     */
    private function _cart()
    {
        return Ecart::single('checkout/cart');
    }

    public function indexAction()
    {
        $this->view->pageTitle = Ecart::translate('checkout')->__(
            'Shopping Cart'
        );
        if (null !== Ecart::session()->lastUrl) {
            $lastUrl = Ecart::session()->lastUrl;
            Ecart::session()->lastUrl = null;
        } elseif (isset($_SERVER['HTTP_REFERER'])
                && $_SERVER['HTTP_REFERER'] != Ecart::getCurrentUrl()) {

            $lastUrl = $_SERVER['HTTP_REFERER'];
        } else {
            $lastUrl = $this->view->href('/');
        }
        $this->view->lastUrl = $lastUrl;
        $this->view->scProducts = $this->_cart()->getProducts();
        $this->view->scTotal = $this->_cart()->getTotalPrice();
        
        $this->render();
    }
    
    public function addAction()
    {
        $productId = $this->_getParam('productId', 0);
        $quantity = $this->_getParam('quantity', 1);
        $attributes = $this->_getParam('attribute', array());
        $modifiers = $this->_getParam('modifier', array());
        Ecart::session()->lastUrl = isset($_SERVER['HTTP_REFERER']) ? 
            $_SERVER['HTTP_REFERER'] : null;


        $result = $this->_cart()->add(
            $productId, $modifiers, $attributes, $quantity
        );

        if ($this->_hasParam('clean-wishlist')) {
            Ecart::single('account/wishlist')->delete(array(
                $this->db->quoteInto('customer_id = ?', Ecart::getCustomerId()),
                $this->db->quoteInto('product_id = ?', $productId)
            ));
        }
        if ($result) {
            $this->_redirect('/checkout/cart');
        } else {
            $keyword = Ecart::single('catalog/hurl')->getProductUrl($productId);
            $this->_redirect('/' . $this->view->catalogUrl . '/' . $keyword);
        }
    }
    
    public function updateAction()
    {
        $data = $this->_getParam('quantity');
        foreach ($data as $itemId => $quantity) {
            $this->_cart()->updateItem($itemId, $quantity);
        }
        $this->_redirect($_SERVER['HTTP_REFERER']);
    }
    
    public function removeAction()
    {
        $itemId = $this->_getParam('scItemId', 0);
        $this->_cart()->deleteItem($itemId);
        $this->_redirect($_SERVER['HTTP_REFERER']);
    }
    
    public function reOrderAction()
    {
        if ($this->_hasParam('orderId')) {
           $orderId = $this->_getParam('orderId');
        } else { 
            $this->_redirect('/account/order');
            return;
        }

        $order = Ecart::single('sales/order')->find($orderId);
        if (!sizeof($order) && $order instanceof Ecart_Db_Table_Rowset) {
            $this->_redirect('/sales/order');
            return;
        }
        $products = $order->current()->getProducts();
        $ret = array();
        $this->_cart()->clear();
        
        foreach ($products as $product) {
            $attrs = array();
            if (!empty($product['attrs']) && count($product['attrs']))
                $attrs = $product['attrs'];
            $ret[$product['product_id']] = 
            $this->_cart()->add(
                $product['product_id'],
                $attrs,
                array(),
                $product['product_quantity']
            );
        }
        // @todo Show add error for customer 
        $this->_redirect('/checkout/cart');
    }
}