<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @category    Ecart
 * @package     Ecart_Checkout
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */
 
/**
 * @var Ecart_Install_Model_Installer
 */
$installer = Ecart::single('install/installer');

$installer->startSetup();

/**
 * create: 
 *  checkout_cart,
 *  checkout_cart_product,
 *  checkout_cart_product_attribute
 * reference:
 *  account_customer,
 *  catalog_product,
 *  catalog_product_attribute
 */
$installer->run("

-- DROP TABLE IF EXISTS `{$installer->getTable('checkout_cart')}`;
CREATE TABLE IF NOT EXISTS `{$installer->getTable('checkout_cart')}` (
  `id` int(10) unsigned NOT NULL auto_increment,
  `customer_id` int(10) unsigned default NULL,
  `site_id` smallint(5) unsigned NOT NULL,
  PRIMARY KEY  (`id`),
  KEY `i_customer_id` (`customer_id`),
  KEY `i_site_id` (`site_id`),
  CONSTRAINT `FK_shopping_cart_customer_id` FOREIGN KEY (`customer_id`) REFERENCES `{$installer->getTable('account_customer')}` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 ROW_FORMAT=FIXED;

-- DROP TABLE IF EXISTS `{$installer->getTable('checkout_cart_product')}`;
CREATE TABLE IF NOT EXISTS `{$installer->getTable('checkout_cart_product')}` (
  `id` int(10) unsigned NOT NULL auto_increment,
  `shopping_cart_id` int(10) unsigned NOT NULL,
  `product_id` int(10) unsigned NOT NULL,
  `quantity` decimal(15,4) unsigned NOT NULL,
  `final_price` decimal(15,4) NOT NULL,
  `product_variation_id` int(10) unsigned default NULL,
  `final_weight` decimal(10,4) NOT NULL,
  PRIMARY KEY  (`id`),
  KEY `shopping_cart_FKIndex2` (`product_id`),
  KEY `shopping_cart_FKIndex1` USING BTREE (`shopping_cart_id`),
  CONSTRAINT `FK_shopping_cart_product_cart_id` FOREIGN KEY (`shopping_cart_id`) REFERENCES `{$installer->getTable('checkout_cart')}` (`id`) ON DELETE CASCADE,
  CONSTRAINT `FK_shopping_cart_product_id` FOREIGN KEY (`product_id`) REFERENCES `{$installer->getTable('catalog_product')}` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC;

-- DROP TABLE IF EXISTS `{$installer->getTable('checkout_cart_product_attribute')}`;
CREATE TABLE IF NOT EXISTS `{$installer->getTable('checkout_cart_product_attribute')}` (
  `id` int(10) unsigned NOT NULL auto_increment,
  `shopping_cart_product_id` int(10) unsigned NOT NULL,
  `product_attribute_value` text,
  `product_attribute_id` int(10) unsigned NOT NULL,
  PRIMARY KEY  (`id`),
  KEY `shopping_cart_attributes_FKIndex1` USING BTREE (`shopping_cart_product_id`),
  KEY `FK_shopping_cart_product_attribute_id` (`product_attribute_id`),
  CONSTRAINT `FK_shopping_cart_product_attribute_cart_product_id` FOREIGN KEY (`shopping_cart_product_id`) REFERENCES `{$installer->getTable('checkout_cart_product')}` (`id`) ON DELETE CASCADE,
  CONSTRAINT `FK_shopping_cart_product_attribute_id` FOREIGN KEY (`product_attribute_id`) REFERENCES `{$installer->getTable('catalog_product_attribute')}` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC;

");

/*@todo customers shopping carts view page
Ecart::single('admin/menu')
    ->add('Customers->Shopping cart', 'checkout_cart');
*/

Ecart::single('core/cache')
    ->add('order_total_methods', 1);
    
Ecart::single('core/page')
    ->add('checkout/*/*')
    ->add('checkout/cart/*')
    ->add('checkout/cart/index')
    ->add('checkout/onepage/*')
    ->add('checkout/wizard/*')
    ->add('checkout/index/success');

Ecart::single('core/config_field')
    ->add('orderTotal/Checkout_Subtotal/enabled', 'Order Total Modules/Shipping/Enabled', 1, 'bool')
    ->add('orderTotal/Checkout_Subtotal/sortOrder', 'Sort Order', '10')
    
    ->add('orderTotal/Checkout_Shipping/enabled', 'Order Total Modules/Subtotal/Enabled', 1, 'bool')
    ->add('orderTotal/Checkout_Shipping/sortOrder', 'Sort Order', '20')
    
    ->add('orderTotal/Checkout_Tax/enabled', 'Order Total Modules/Tax/Enabled', 1, 'bool')
    ->add('orderTotal/Checkout_Tax/sortOrder', 'Sort Order', '30')
    
    ->add('orderTotal/Checkout_ShippingTax/enabled', 'Order Total Modules/ShippingTax/Enabled', 1, 'bool')
    ->add('orderTotal/Checkout_ShippingTax/sortOrder', 'Sort Order', '40');
    
$installer->registerModule('Ecart_Checkout');

$installer->endSetup();