<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @category    Ecart
 * @package     Ecart_Cms
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 * 
 * @category    Ecart
 * @package     Ecart_Cms
 * @subpackage  Model
 * @author      Ecart Core Team <core@ecartcommerce.com>
 */
class Ecart_Cms_Model_Page_Row extends Ecart_Db_Table_Row 
{
    private function _cleanTag($blockName) 
    {
       return str_replace(array('{', '}'), '', $blockName);
    }
    
    private function _getReplaceContent($blockName)
    {
       $blockName = $this->_cleanTag($blockName);
       
       list($tagType, $tagKey) = explode('_', $blockName, 2);
       switch ($tagType) {
           case 'static':
               return Ecart::single('cms/block')->getContentByName($tagKey);
               break;
       }
       
       return '';
    }
    
    public function getContent($includeBlocks = false)
    {
        $langId = Ecart::getLanguageId();
        
        $queryPage = "SELECT cpc.title, cpc.content, cpc.meta_keyword,
                             cpc.meta_description, cpc.meta_title, cp.layout
                      FROM " . self::$_db_prefix . "cms_page_content as cpc
                      LEFT JOIN " . self::$_db_prefix . "cms_page AS cp ON cp.id = cpc.cms_page_id
                      WHERE  cpc.language_id = $langId
                      AND    cpc.cms_page_id = $this->id";
                         
        $content = $this->getAdapter()->fetchRow($queryPage);
        
        if (!$includeBlocks) {
            return $content;
        }
        
        //inserting blocks in content
        $matches = array();
        preg_match_all('/{{\w+}}/', $content['content'], $matches);
        $i = 0;
        
        foreach ($matches[0] as $block) {
           $content['content'] = str_replace($block, $this->_getReplaceContent($block), $content['content']);
        }
        
        return $content;
    }
    
    public function getComments()
    {
        $queryComment = "SELECT *
                         FROM    " . self::$_db_prefix . "cms_page_comment as cpc
                         WHERE  cpc.cms_page_id = $this->id";

        //$queryComment .= " AND cpc.status = 1"; //is approved
        $queryComment .= " AND cpc.status <> 2"; //not blocked
        
        $queryComment .= " ORDER BY cpc.created_on DESC";
        
        return $this->getAdapter()->fetchAll($queryComment);
    }
}