<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @category    Ecart
 * @package     Ecart_Contacts
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 * 
 * @category    Ecart
 * @package     Ecart_Contacts
 * @subpackage  Model
 * @author      Ecart Core Team <core@ecartcommerce.com>
 */
class Ecart_Contacts_Model_Message extends Ecart_Db_Table
{
    /**
     * The default table name 
     */
    protected $_name = 'contacts_message';
    
    public function countByFilter($params = array(), Zend_Db_Select $select = null)
    {
        $select = $this->getAdapter()->select();
        $select->from(array('o' => $this->_name), new Zend_Db_Expr('COUNT(o.id)'));

        if (!empty($params['departamentId']))
            $select->where('department_id = ?', $params['departamentId']);
        if (isset($params['filter']) && is_array($params['filter'])) {
            foreach ($params['filter'] as $filter) {
                switch ($filter['data']['type']) {
                    case 'numeric': case 'date':
                       $condition = $filter['data']['comparison'] == 'eq' ? '=' : 
                            ($filter['data']['comparison'] == 'noteq' ? '<>' :
                            ($filter['data']['comparison'] == 'lt' ? '<' : '>'));
                        $select->where("o.{$filter['field']} $condition ?", $filter['data']['value']);
                        break;
                    case 'list':
                        $select->where($this->getAdapter()->quoteInto("
                            o.$filter[field] IN (?)", explode(',', $filter['data']['value'])));
                        break;
                    default:
                        $select->where("o.$filter[field] LIKE ?", $filter['data']['value'] . "%");
                        break;
                }
            }
        }
        return $this->getAdapter()->fetchOne($select);
    }
    
    public function getList($depId = false, $params = array()) 
    {
        $select = $this->getAdapter()->select();
        $select->from(array('c' => $this->_name))
            ->join(array('d' => self::$_db_prefix . 'contacts_department'), 
                'd.id = c.department_id',
                array('department_name' => 'name'));
        if (!empty($params['sort']))
            $select->order($params['sort'] . ' ' . $params['dir']);
        if (!empty($params['limit'])) {
            $select->limit($params['limit'], $params['start']);
        }
        if ($depId) {
            $select->where('department_id = ?', $depId);
        }
        if (isset($params['filter']) && is_array($params['filter'])) {
            foreach ($params['filter'] as $filter) {
                switch ($filter['data']['type']) {
                    case 'numeric': 
                    case 'date':
                        $condition = $filter['data']['comparison'] == 'eq' ? '=' : 
                            ($filter['data']['comparison'] == 'noteq' ? '<>' :
                            ($filter['data']['comparison'] == 'lt' ? '<' : '>'));
                        $select->where("c.{$filter['field']} $condition ?", $filter['data']['value']);
                        break;
                    case 'list':
                        $select->where($this->getAdapter()->quoteInto(
                            "c.$filter[field] IN (?)", explode(',', $filter['data']['value'])
                        ));
                        break;
                    default:
                        $select->where("c.$filter[field] LIKE ?", $filter['data']['value'] . "%");
                        break;
                }
            }
        }
        return $select->query()->fetchAll();
    }
    
    /**
     * Adds message to database and send it to department email
     * 
     * @param string $from
     * @param string $subject
     * @param string $message
     * @param int $departmentId
     * @param string $extraInfo (fieldName: fieldValue,)
     * @return Ecart_Contacts_Model_Message Provides fluent interface
     */
    public function add($from, $subject, $message, $departmentId, $extraInfo)
    {
        $this->insert(array(
            'email'         => $from,
            'subject'       => $subject,
            'message'       => $message,
            'custom_info'   => $extraInfo,
            'department_id' => $departmentId,
            'site_id'       => Ecart::getSiteId(),
            'created_at'    => Ecart_Date::now()->toZendDbExpr()
        ));
        
        $department = Ecart::single('contacts/department')->find($departmentId)->current();
        if ($department) {
            $to = $department->email;
        } else {
            $to = Ecart_Collect_MailBoxes::getName(
                Ecart::config()->contact->main->email
            );
        }
        
        $mail = new Ecart_Mail();
        $mail->setConfig(array(
            'event'   => 'contact_us',
            'subject' => $subject,
            'data'    => array('text' => $message, 'custom_info' => $extraInfo),
            'to'      => $to,
            'from'    => $from,
            'type'    => 'html'   
        ));
        @$mail->send();
        
        return $this;
    }
}

