<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @category    Ecart
 * @package     Ecart_Install
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 * 
 * @category    Ecart
 * @package     Ecart_Install
 * @subpackage  Model
 * @author      Ecart Core Team <core@ecartcommerce.com>
 */
class Ecart_Install_Model_Translate
{
    /**
     * @static
     * @var Ecart_Install_Model_Translate
     */
    private static $_instance;

    /**
     *
     * @var Zend_Translate
     */
    private $_zendTranslate;

    /**
     *
     * @var string
     */
    private $_locale = 'en_US';
    
    private function __construct()
    {
        $session = Zend_Registry::get('session');
        if (isset($session->current_locale)) {
            $this->_locale = $session->current_locale;
        }
        
        $data = $this->getTranslation($this->_locale);
        $this->_zendTranslate = new Zend_Translate('array', $data, $this->_locale);
    }
    
    /**
     * @static
     * @return Ecart_Install_Model_Translate
     */
    public static function getInstance()
    {
        if (null === self::$_instance) {
            self::$_instance = new self();
        }
        return self::$_instance;
    }

    /**
     *
     * @return string
     */
    public function getLocale()
    {
        return $this->_locale;
    }

    /**
     *
     * @param string $locale
     * @return void
     */
    public function setLocale($locale)
    {
        $session = Zend_Registry::get('session');
        $session->locale = $locale;
        $this->_locale = $locale;
    }

    /**
     *
     * @param string $locale
     * @return string
     */
    public function getTranslation($locale = 'en_US')
    {
        require 'app/locale/' . $locale . '.php';
        return $langData;
    }
    
    /**
     * Return translator
     *
     * @return Zend_Translate
     */
    public function getTranslator()
    {
        return $this->_zendTranslate;
    }
    
    /**
     * Translate text
     * 
     * @param array
     * @return string
     */
    public function _(array $args)
    {
        $text = array_shift($args);
        return @vsprintf($this->getTranslator()->_($text, $this->_locale), $args);
    }
    
}

function __()
{
    return Ecart_Install_Model_Translate::getInstance()->_(func_get_args());
}