<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @category    Ecart
 * @package     Ecart_Log
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 * 
 * @category    Ecart
 * @package     Ecart_Log
 * @subpackage  Model
 * @author      Ecart Core Team <core@ecartcommerce.com>
 */
class Ecart_Log_Model_Url_Info extends Ecart_Db_Table
{
    protected $_name = 'log_url_info';
    
    public function getReferUrl($withParams = true) 
    {
        $referer = $_SERVER['HTTP_REFERER'];
        if (!$withParams && $end = strpos($referer, '?')) {
            $referer = substr($referer, 0, $end);            
        }
        return empty($referer) ? '' : $referer;
    }
       
    public function insert(array $data)
    {
        if (empty($data['refer'])) {
            $data['refer'] = isset($_SERVER['HTTP_REFERER']) ?
                $_SERVER['HTTP_REFERER'] : '';
        }
        if (empty($data['url'])) {
            $data['url'] = Ecart::getCurrentUrl();
        }
        return parent::insert($data);
    }
    
    public function getList($params = array())
    {
        $select = $this->getAdapter()->select();
        $select->from(
                   array('lu' => $this->_name),
                   array('url', 'COUNT(*) as hit')
               )
               ->joinLeft(array('u' => self::$_db_prefix . 'log_url'),
                   'u.url_id = lu.id',
                   array('pdate' => 'LEFT(visit_at, 10) ')
               )
               ->group('pdate')
               ->group('lu.url')
               ->where('LEFT(visit_at, 10) IS NOT NULL');
               
        
        if (!empty($params['sort']))
            $select->order($params['sort'] . ' ' . $params['dir']);
        if (!empty($params['limit']))
            $select->limit($params['limit'], $params['start']);
        return $select->query()->fetchAll();
    }
    
    public function countByFilter($params = array(), Zend_Db_Select $select = null)
    {
        $select = $this->getAdapter()->select();
        $select->from(
                    array('t' => $this->_name),
                    array('COUNT(distinct LEFT(visit_at, 10), url) as count')
                )
               ->joinLeft(array('u' => self::$_db_prefix . 'log_url'),
                   'u.url_id = t.id',
                   array()
               );
        return parent::countByFilter($params, $select);
    }
}