<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @category    Ecart
 * @package     Ecart_Log
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 * 
 * @category    Ecart
 * @package     Ecart_Log
 * @subpackage  Model
 * @author      Ecart Core Team <core@ecartcommerce.com>
 */
 class Ecart_Log_Model_Visitor extends Ecart_Db_Table
{
    protected $_name = 'log_visitor';
    
    public function insert(array $data)
    {
        // @todo INSERT DELAYED
        if (empty($data['session_id']))
            $data['session_id'] = Zend_Session::getId();
        if (empty($data['customer_id']))
            $data['customer_id'] = (int)Ecart::getCustomerId();
        if (empty($data['last_url_id']))
            $data['last_url_id'] = Ecart::single('log/url_info')->insert(array());
        if (empty($data['last_visit_at']))
            $data['last_visit_at'] = Ecart_Date::now()->toZendDbExpr();
        if (empty($data['site_id']))
            $data['site_id'] = Ecart::getSiteId();
        return parent::insert($data);    
    }
    
    public function update(array $data, $where)
    {
        if (empty($data['customer_id']))
            $data['customer_id'] =  (int) Ecart::getCustomerId();
        if (empty($data['last_url_id']))
            $data['last_url_id'] = Ecart::single('log/url_info')->insert(array());
        if (empty($data['last_visit_at']))
            $data['last_visit_at'] = Ecart_Date::now()->toZendDbExpr();
        return parent::update($data, $where);
    }
    
    /**
     * Return visitor id
     *
     * @static
     * @return int
     */
    public static function getId()
    {
        if (!isset(Ecart::session()->visitor)) {
            Ecart::session()->visitor = Ecart::single('log/visitor')->insert(array());
        }
        return Ecart::session()->visitor;
    }
    
    /**
     *  Core saving visitor information
     *  Used in init "Ecart_Core_Controller_Front"
     * 
     */
    public function log() 
    {
        $lastUrlId  = Ecart::single('log/url_info')->insert(array());
        if (!isset(Ecart::session()->visitor)) {
            Ecart::session()->visitor = Ecart::single('log/visitor')->insert(array(
                'last_url_id' => $lastUrlId
            ));
            Ecart::single('log/visitor_info')->insert(array(
                'visitor_id' => Ecart::session()->visitor
            ));
        } else {
            Ecart::single('log/url')->insert(array(
                'url_id' => $lastUrlId,
                'visitor_id' => Ecart::session()->visitor
            ));
            Ecart::single('log/visitor')->update(
                array('last_url_id' => $lastUrlId),
                'id = ' . Ecart::session()->visitor
            );
            Ecart::single('log/visitor_info')->update(array(), 
                'visitor_id = ' . Ecart::session()->visitor
            );
        }
        
    }
    
    /**
     * Return visitor row
     *
     * @return Zend_Db_Table_Row_Abstract
     */
    public function getVisitor()
    {
        if ($row = $this->find(self::getId())->current()) {
            return $row;
        } else {
            unset(Ecart::session()->visitor);
        }
        return $this->find(self::getId())->current();
    }

    /**
     *
     * @return Zend_Db_Table_Row_Abstract
     */
    public function getVisitorInfo()
    {
        return Ecart::single('log/visitor_info')
            ->getVisitorInfo(self::getId());
    }

    /**
     *
     * @param int $visitorId
     * @return int
     */
    public function getLastUrlId($visitorId = null)
    {
        if (null === $visitorId) {
            $visitorId = self::getId();
        }
        if (null === $this->find($visitorId)->current()) {
           $visitorId = self::insert(array());
        }
        return $this->find($visitorId)->current()->last_url_id;
    }

    /**
     *
     * @param  int $period
     * @param  mixed $where
     * @return array
     */
    public function getCountList($period = 10, $where = null)
    {
        $select = $this->getAdapter()->select();
        $select->from(
                array('o' => $this->_name),
                array("LEFT(last_visit_at, {$period}) AS pdate" ,'COUNT(*) as hit')
            )
               ->group('pdate')
               ->order('pdate ASC');
        if (is_string($where) && $where) {
            $select->where($where);
        } elseif (is_array($where)) {
            foreach ($where as $condition) {
                if ($condition)
                    $select->where($condition);
            }
        }
        return $this->getAdapter()->fetchPairs($select->__toString());
    }

    /**
     * Return start logging date
     * 
     * @param int $siteId
     * @return string
     */
    public function getFirstDate($siteId = null)
    {
        // abstract min && max 
//        $select = $this->getAdapter()->select();
//        $select->from(array('t' => $this->_name),
//            new Zend_Db_Expr("MIN({$filed})"));
//
//        if (is_string($where) && $where) {
//            $select->where($where);
//        } elseif (is_array($where)) {
//            foreach ($where as $condition) {
//                if ($condition) {
//                    $select->where($condition);
//                }
//            }
//        } elseif ($where instanceof Zend_Db_Select) {
//        }
//        return $this->getAdapter()->fetchOne($select->__toString());

        $select = "SELECT MIN(last_visit_at) FROM `{$this->_name}`";
        if (null != $siteId) {
            $select .= " WHERE (site_id = '{$siteId}')";
        }
        return $this->getAdapter()->fetchOne($select);

    }

    /**
     * Return logging logging date
     *
     * @param int $siteId
     * @return string
     */
    public function getLastDate($siteId = null)
    {
        $select = "SELECT MAX(last_visit_at) FROM `{$this->_name}`";
        if (null != $siteId) {
            $select .= " WHERE (site_id = '{$siteId}')";
        }
        return $this->getAdapter()->fetchOne($select);

    }
    
}