<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @category    Ecart
 * @package     Ecart_PaymentPaypal
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 * 
 * @category    Ecart
 * @package     Ecart_PaymentPaypal
 * @subpackage  Model
 * @author      Ecart Core Team <core@ecartcommerce.com>
 */
class Ecart_PaymentPaypal_Model_Standart extends Ecart_Method_Payment_Model_Abstract
{
    protected $_code = 'Paypal_Standart';
    protected $_title = 'Paypal Standart';

    public function pending(Ecart_Sales_Model_Order_Row $order)
    {
        $helper = new Ecart_View_Helper_Href();
        $delivery = $order->getDelivery();
        $formFields = array(
            'business'          => $this->_config->email,
            'return'            => $helper->href('/paymentpaypal/standart/success'),
            'cancel_return'     => $helper->href('/paymentpaypal/standart/cancel/invoice') . '/' . $order->id,
            'notify_url'        => $helper->href('/paymentpaypal/standart/ipn'),
            'invoice'           => $order->id,
            'address_override'  => 1,
            'first_name'        => $delivery->getFirstname(),
            'last_name'         => $delivery->getLastname(),
            'address1'          => $delivery->getStreet(),
            'address2'          => $delivery->getStreet2(),
            'city'              => $delivery->getCity(),
            'state'             => $delivery->getStateCode(),
            'country'           => $delivery->getCountryCode(),
            'zip'               => $delivery->getZip(),
        );
        if ($this->_config->logo) {
            $formFields['cpp_header_image'] = $this->_config->logo; 
        }
        
        if ($this->_config->paymentAction) {
            $formFields['paymentaction'] = strtolower($this->_config->paymentAction); 
        }
        
        $transaciton_type = $this->_config->transactionType;
        /*
        O=aggregate cart amount to paypal
        I=individual items to paypal
        */
        if ($transaciton_type == 'Aggregate Cart') {
            $businessName = $this->_config->name;
            $formFields = array_merge($formFields, array(
                    'cmd'           => '_ext-enter',
                    'redirect_cmd'  => '_xclick',
                    'item_name'     => $businessName ? 
                        $businessName :  Ecart::config()->main->store->name,
                    'currency_code' => $this->getBaseCurrencyCode(),
                    'amount'        => sprintf('%.2f', $this->getAmountInBaseCurrency(
                        $order->getSubTotal(), $order->currency
                    )),
                ));
             
            $tax = $order->getTax();
            $shippingTax = $order->getShippingTax();
            $tax = sprintf('%.2f', $tax + $shippingTax);
            if ($tax > 0) {
                $formFields['tax'] = $tax; 
            }

        } else {
            $formFields = array_merge($formFields, array(
                'cmd'       => '_cart',
                'upload'       => '1',
            ));
            $items = $order->getProducts();
            
            if ($items) {
                $i = 1;
                foreach($items as $item) {
                    $formFields = array_merge($formFields, array(
                        'item_name_' . $i   => $item['product_name'],
                        'item_number_' . $i => $item['product_sku'],
                        'quantity_' . $i    => intval($item['product_quantity']),
                        'amount_' . $i      => sprintf('%.2f', $item['final_price']),
                    ));
                    if($item['product_tax'] > 0) {
                        $formFields = array_merge($formFields, array(
                            'tax_' . $i      => sprintf('%.2f', $item['product_tax']/*/$item['product_quantity']*/),
                        ));
                    }
                    $i++;
                }
           }
        }
        $totals = $order->getTotals();
        
        $shipping = sprintf('%.2f', $totals['Shipping']['value']);
        if ($shipping > 0) {
          if ($transaciton_type == 'Aggregate Cart') {
              $formFields['shipping'] = $shipping;
          } else {
              $shippingTax = $totals['Shipping Tax']['value'];
              $formFields = array_merge($formFields, array(
                    'item_name_' . $i   => $order->shipping_method,
                    'quantity_' . $i    => 1,
                    'amount_' . $i      => $shipping,
                    'tax_' . $i         => sprintf('%.2f', $shippingTax),
              ));
              $i++;
          }
        }
        $sReq = '';
        $rArr = array();
        foreach ($formFields as $k => $v) {
            /*
            replacing & char with and. otherwise it will break the post
            */
            $value =  str_replace("&", "and", $v);
            $rArr[$k] =  $value;
            $sReq .= '&' . $k . '=' . $value;
        }
        
        $this->getStorage()->formFields = $rArr;

        return true;
    }

    /**
     * "processing" actually
     *
     * @param array $post
     * @return null
     */
    public function ipnSubmit($post) 
    {
        if (isset($post['module'])) { unset($post['module']);}
        if (isset($post['controller'])) { unset($post['controller']);}
        if (isset($post['action'])) { unset($post['action']);}
        if (isset($post['locale'])) { unset($post['locale']);}
        
        $request = '';
        foreach($post as $key => $value) {
            $request .= '&' . $key . '=' . urlencode(stripslashes($value));
        }
        //append ipn commdn
        $request .= "&cmd=_notify-validate";
        $request = substr($request, 1);
        
        $httpClient = new Zend_Http_Client();
        
        $uri = $this->_config->url. '?' . $request;
        
        $httpClient->setUri($uri);
        $response = $httpClient->request('POST')->getBody();
        
        $order = Ecart::single('sales/order')->find($post['invoice'])->current();
        if (!$order) {
            return;
        }
        if ($response != 'VERIFIED') {
             /* Canceled_Reversal, Completed, Denied, Expired, Failed
                 Pending, Processed, Refunded, Reversed, Voided*/
            $comment = $post['payment_status'];
            if ($post['payment_status'] == 'Pending') {
                $comment .= ' - ' . $post['pending_reason'];
            } elseif ( ($post['payment_status'] == 'Reversed') || ($post['payment_status'] == 'Refunded') ) {
                $comment .= ' - ' . $post['reason_code'];
            }
            $order->addComment(
                Ecart::translate('checkout')->__(
                    "Paypal IPN Invalid %s.", $comment
                )
            );
            return;
        }

        if ($post['mc_gross'] != $order->order_total) {
            $order->addComment(
                Ecart::translate('checkout')->__(
                    'Order total amount does not match paypal gross total amount'
                )
            );
            return;
        }

        Ecart::single('paymentPaypal/standart_order')->insert(array(
           'order_id' => $order->id,
           'trans_id' => $post['txn_id'],
           'status' => $post['payment_status']
        ));
    
        $message = Ecart::translate('checkout')->__(
            "Received IPN verification"
        );
        if ($post['payment_status'] == 'Completed') {
           $message = Ecart::translate('checkout')->__(
               "Transaction in sale mode"
           );
        }

        $order->setStatus('processing'/* or int 2*/, $message, true);
        
        return;
    }
}