<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @category    Ecart
 * @package     Ecart_Poll
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 * 
 * @category    Ecart
 * @package     Ecart_Poll
 * @subpackage  Model
 * @author      Ecart Core Team <core@ecartcommerce.com>
 */
class Ecart_Poll_Model_Answer extends Ecart_Db_Table
{
    protected $_name = 'poll_answer';
    
    public function set($rowArray)
    {
       if (!$rowArray['id'] || $rowArray['id'] < 0 ) {
           unset($rowArray['id']);
           $row = $this->createRow($rowArray);
       } else {
           $row = $this->fetchRow(array(
               'id = ' . (int) $rowArray['id'],
               'question_id = ' . (int) $rowArray['question_id']
           ));
           if (null === $row)
               return false;
           $row->setFromArray($rowArray);
        }
        return $row->save();
    }
    
    public function getAnswers($params = array())
    {
        $select = $this->getAdapter()->select();
        $select->from(array('a' => $this->_name),array('id','question_id'));
        
        if (!empty($params['limit']))
            $select->limit($params['limit'], $params['start']);
        if (!empty($params['sort']))
            $select->order($params['sort'] . ' ' . $params['dir']);
        
        $select->joinLeft(array('ad' => self::$_db_prefix . 'poll_answer_description'),
                          'ad.answer_id = a.id',
                          array('answer','language_id'))
               ->joinLeft(array('q' => self::$_db_prefix . 'poll_question'),
                          'a.question_id = q.id',
                          array());
	        
	    if (isset($params['questionId']))
	        $select->where('q.id = ?', $params['questionId']);
	    if (isset($params['languageId']))           
	        $select->where('ad.language_id = ? ', $params['languageId']);
        return $select->query()->fetchAll();
    }
    
    public function getAnswerIds($questionId)
    {
        return $this->getAdapter()->fetchCol(
            "SELECT id FROM {$this->_name} WHERE question_id = ? ", $questionId
        );
    }
    
    /*
     * @TODO rename
     */
    public function getAttitude($questionId, $answerId)
    {
        return $this->getAdapter()->fetchOne(
            "SELECT COUNT(id) FROM {$this->_name} WHERE question_id = ? AND id = ?", 
            array($questionId, $answerId)
        );
    }
}