<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @category    Ecart
 * @package     Ecart_Poll
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 * 
 * @category    Ecart
 * @package     Ecart_Poll
 * @subpackage  Controller
 * @author      Ecart Core Team <core@ecartcommerce.com>
 */
class Ecart_Poll_IndexController extends Ecart_Core_Controller_Front 
{
    public function indexAction()
    {
        $questionModel = Ecart::single('poll/question');
        
        if ($this->_hasParam('questionId'))  {
            $questionIds[] = array('id' => $this->_getParam('questionId'));
        } else {
            $questionIds = $questionModel->getAllActiveQuestion($this->_siteId);
        }
        $tableVote = Ecart::single('poll/vote');
        $tableAnswer = Ecart::single('poll/answer');
       
        $questions =  $questionModel->getQuestionByIds(
            $questionIds, $this->_langId
        );
        $this->view->pageTitle = Ecart::translate('poll')->__('Polls');
       
        foreach ($questions as &$question) {
            $params = array(
                'languageId' => $this->_langId,
                'questionId' => $question['id'],
            );
            $question['answer'] = $tableAnswer->getAnswers($params);

            $inCookie = isset($_COOKIE["polls"]) && in_array(
                $question['id'], explode(',', $_COOKIE["polls"])
            );

            $inTable = $tableVote->isVoted(
                $question['id'], ip2long($_SERVER['REMOTE_ADDR'])
            );

            if ($inCookie || $inTable) {
                $question['results'] = $questionModel
                    ->find($question['id'])
                    ->current()
                    ->getResults();
                $question['totalCount'] = $questionModel
                    ->find($question['id'])
                    ->current()
                    ->getTotalCount();
                $question['status'] = true;
            } else {
                $question['status'] = false;
            }
        }

        $this->view->questions = $questions; 
        $this->render('all');
    }
    
    public function saveAction()
    {
        $this->getHelper('layout')->disableLayout();
        
        $this->_questionId = current($this->_getParam('questionId'));
        
        $tableVote = Ecart::single('poll/vote');
        /* check is already voted */
        if (isset($_COOKIE['polls']) 
            && in_array($this->_questionId, explode(',', $_COOKIE['polls']))) {
            
            $this->_redirect($_SERVER['HTTP_REFERER']);
        }

        $isVoted = $tableVote->isVoted(
            $this->_questionId, ip2long($_SERVER['REMOTE_ADDR'])
        );

        if ($isVoted) {
            $this->_redirect($_SERVER['HTTP_REFERER']);
        }

        $data = array(
           'ip' => ip2long($_SERVER['REMOTE_ADDR']),
           'created_at' => Ecart_Date::now()->toZendDbExpr(),
           'visitor_id' => Ecart_Log_Model_Visitor::getId(),
           'customer_id' => (int) Ecart::getCustomerId()         
        );
        
        $votes = $this->_getParam('vote');
        $isMulti = Ecart::single('poll/question')
            ->find($this->_questionId)
            ->current()
            ->isMultiQuestion();
        
        $tableAnswer = Ecart::single('poll/answer');
        if (!empty($votes)) {
            foreach ($votes as $voteId) {
                //  checking answer depend.. question
    	        if ($tableAnswer->getAttitude($this->_questionId, $voteId)) {
    		        $data['answer_id'] = $voteId  ;
    		        $tableVote->insert($data);
    	        }
    	        if (!$isMulti) {
    	        	break;
    	        }
            }
        }
        $path = $this->view->href('/');
        if (!empty($_COOKIE['polls'])) {

            setcookie(
                'polls',
                $_COOKIE['polls'] . ',' . $this->_questionId,
                time() + 2592000,
                $path
            );
        } else { 
            setcookie('polls',  $this->_questionId, time() + 2592000, $path);
        }
        if ($this->_request->isXmlHttpRequest()) {
            $this->_helper->layout->disableLayout();
            $content = $this->view->box('poll/poll', array(
                'questionId' => $this->_questionId,
                'disableWrapper' => true
            ))->toHtml();
            
            return $this->_helper->json->sendSuccess(
                array('content' => $content)
            );
        }

        $this->_redirect('/poll/index/index/questionId/' . $this->_questionId);
    }
}
