<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @category    Ecart
 * @package     Ecart_Sales
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 * 
 * @category    Ecart
 * @package     Ecart_Sales
 * @subpackage  Model
 * @author      Ecart Core Team <core@ecartcommerce.com>
 */
class Ecart_Sales_Model_Order_Creditcard extends Ecart_Db_Table
{
    protected $_name = 'sales_order_creditcard';
    
    /**
     * Insert or update creditcard order row
     * 
     * @param Ecart_CreditCard            $card
     * @param Ecart_Sales_Model_Order_Row $order
     * @return boolean
     */
    public function save(Ecart_CreditCard $card, Ecart_Sales_Model_Order_Row $order)
    {
        $full_number = $card->getCcNumber();
        $ret = true;
        
        switch (Ecart::config()->payment->{$order->payment_method_code}->saveCCAction) {
            case 'last_four':
            	$number = str_repeat('X', (strlen($full_number) - 4)) . 
                    substr($full_number, -4);
            	break;
            case 'first_last_four':
                $number = substr($full_number, 0, 4) . 
                    str_repeat('X', (strlen($full_number) - 8)) . 
                    substr($full_number, -4);
                break;
            case 'partial_email':
            	$number = substr($full_number, 0, 4) . 
                    str_repeat('X', (strlen($full_number) - 8)) . 
                    substr($full_number, -4);
                    
            	$message = Ecart::translate('sales')->__(
                    'Please direct this email to the Accounting department so that it may'
                    . ' be filed along with the online order it relates to: '
                    . "\n\n" . 'OrderId: %s' . "\n\n" . 'Middle Digits: %s' . "\n\n", 
                    $order->id,
                    substr($full_number, 4, (strlen($full_number) - 8))
                );
                $mail = new Ecart_Mail();
                $mail->setConfig(array(
                    'subject' => 'Credit card number. Order ' . $order->id,
                    'data'    => array('text' => $message),
                    'to'      => Ecart_Collect_MailBoxes::getName(
                        Ecart::config()->orders->main->email
                    ),
                    'from'    => array(
                        'email' => $order->customer_email,
                        'name' => $order->payment_method
                    ),
                    'type' => 'txt'   
                ));
                $ret = $mail->send();
            	break;
            case 'complete':
            	$number = $full_number;
            	break;
            default:
                return true;
        }
        
        $crypt = Ecart_Crypt::factory();
        $data = array(
            'cc_type'   => $crypt->encrypt($card->getCcType()),
            'cc_owner'  => $crypt->encrypt($card->getCcOwner()),
            'cc_number' => $crypt->encrypt($number),
            'cc_expires_year' => $crypt->encrypt($card->getCcExpiresYear()),
            'cc_expires_month' => $crypt->encrypt($card->getCcExpiresMonth()),
            'cc_cvv'    => Ecart::config()->payment->{$order->payment_method_code}->saveCvv ? 
                $crypt->encrypt($card->getCcCvv()) : '',
            'cc_issue_year'  => $crypt->encrypt($card->getCcIssueYear()),
            'cc_issue_month'  => $crypt->encrypt($card->getCcIssueMonth())
        );
        
        if (!$row = $this->find($order->id)->current()) {
            $row = $this->createRow();
            $row->order_id = $order->id;
        }
        $row->setFromArray($data);
        
        return $ret && $row->save();
    }
}