<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @category    Ecart
 * @package     Ecart_Sitemap
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 * 
 * @category    Ecart
 * @package     Ecart_Sitemap
 * @subpackage  Controller
 * @author      Ecart Core Team <core@ecartcommerce.com>
 */
class Ecart_Sitemap_IndexController extends Ecart_Core_Controller_Front
{
    public function init()
    {
        parent::init();
        $this->view->crumbs()->add(
            Ecart::translate('sitemap')->__(
                'Sitemap'
            ),
            '/sitemap'
        );
        $this->view->meta()->setTitle(
            Ecart::translate('sitemap')->__(
                'Sitemap'
        ));
    }
     
    public function getAllCategoriesAction()
    {
        $this->view->pageTitle = Ecart::translate('sitemap')->__(
            'Site Map Categories'
        );
        $items = Ecart::single('catalog/category')
            ->getFlatTree($this->_langId, $this->_siteId, true);
        $this->view->items = current($items);
        $this->view->items['siteId'] = $this->_siteId;
        $this->render();
    }
    
    public function getAllProductsAction()
    {
        $this->view->crumbs()->add(
            Ecart::translate('sitemap')->__('Products'), '/get-all-products'
        );
        $this->view->pageTitle = Ecart::translate('sitemap')->__(
            'Site Map All Products'
        );
        $items = array();
        $productRowset = Ecart::single('catalog/product')
            ->getAllActiveProducts($this->_langId, array($this->_siteId));
        foreach ($productRowset as $item) {
            $item['lvl'] = 1 ;
            $items[] = $item;
        }
        
        $this->view->items = $items;
        $this->view->items['siteId'] = $this->_siteId;
        $this->render();
    }
    
    public function getAllPagesAction() 
    {
        $this->view->pageTitle = Ecart::translate('sitemap')->__(
            'Site Map All Pages'
        );
        $result = array();
        $categories = Ecart::single('cms/category')->getActiveCategory();
        
        $catsIds = array ();
        foreach ($categories as $category) {
             $catsIds[] = $category['id'];
        }
        
        $pages = array();
        $countPages = 0;
        if (Ecart::config()->sitemap->cms->showPages) {
            $pagesRowset = Ecart::single('cms/page')
                ->getPageListByActiveCategory($catsIds, Ecart::getLanguageId());
            foreach ($pagesRowset as $page) {
                $pages[$page['cms_category_id']][] = $page;
                $countPages++;
            }
        }
        foreach ($categories as $category) {
            $result[intval($category['parent_id'])][$category['id']] = array(
                'id' => $category['id'],
                'title' => $category['title'],
                'link' => $category['link'],
                'pages' => isset($pages[$category['id']])
                    ? $pages[$category['id']] : null
            );
        }
        $this->view->treeCount = $countPages;
        $this->view->tree = $result;
        $this->render('pages');
    }
}