<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @category    Ecart
 * @package     Ecart_Tag
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 * 
 * @category    Ecart
 * @package     Ecart_Tag
 * @subpackage  Model
 * @author      Ecart Core Team <core@ecartcommerce.com>
 */
class Ecart_Tag_Model_Customer extends Ecart_Db_Table
{
    protected $_name = 'tag_customer';
    protected $_dependentTables = array('Ecart_Tag_Model_Product');

    public function findMyByTag($tag)
    {
        return $this->fetchAll(array(
            $this->getAdapter()->quoteInto('name = ?', $tag),
            $this->getAdapter()->quoteInto(
                'customer_id = ?', (int) Ecart::getCustomerId()
            ),
            $this->getAdapter()->quoteInto('site_id = ?', Ecart::getSiteId())
        ));
    }

    /**
     * Returns all rows with some `tag`
     * @param $tag
     * @return mixed|array
     */
    public function findByTag($tag)
    {
        return $this->fetchAll(array(
            $this->getAdapter()->quoteInto('name = ?', $tag),
            $this->getAdapter()->quoteInto('status = ?', 1),
            $this->getAdapter()->quoteInto('site_id = ?', Ecart::getSiteId())
        ));
    }

    /**
     * Return tags set for current logged customer
     *
     * @return Zend_Db_Table_Rowset_Abstract
     */
    public function findMy()
    {
        return $this->fetchAll(array(
            $this->getAdapter()->quoteInto('status = ?', 1), // see self::getStatuses()
            $this->getAdapter()->quoteInto(
                'customer_id = ?', (int) Ecart::getCustomerId()
            ),
            $this->getAdapter()->quoteInto('site_id = ?', Ecart::getSiteId())
        ));
    }

    /**
     * Return customer tags with count of products for each
     * @return array
     */
    public function getMyWithWeight($params = array())
    {
        $customerId = Ecart::getCustomerId();
        if (isset($params['customerId'])) {
            $customerId = $params['customerId'];
        }
        if (!$customerId) {
            return false;
        }
        $select = $this->getAdapter()->select();
        $select->from(
                array('ct' => $this->_name),
                array('ct.*', new Zend_Db_Expr('COUNT(*) weight'))
            )
            ->joinLeft(array('ctp' => self::$_db_prefix . 'tag_product'), 
                'ctp.customer_tag_id = ct.id', 'product_id')
            ->where(
                $this->getAdapter()->quoteInto('customer_id = ?',$customerId )
            )
            ->where($this->getAdapter()->quoteInto(
                'site_id = ?', Ecart::getSiteId()
            ))
            ->where($this->getAdapter()->quoteInto('status = ?', 1)/* see self::getStatuses()*/)
            ->group('ct.id');
        
        if (isset($params['getProductNames'])) {
            $select->joinLeft(
                array('pd' => self::$_db_prefix . 'catalog_product_description'),
                'pd.product_id = ctp.product_id AND pd.language_id = ' . $params['languageId'],
                array('product_name' => 'name')
            );
        }
        
        return $select->query()->fetchAll();
    }

    /**
     * Return products set for current logged customer
     *
     * @return Zend_Db_Table_Rowset_Abstract
     */
    public function findMyProductsByTagId($tagId)
    {
        $rowset = $this->find($tagId);
        if (!sizeof($rowset))
                return array();
        $row = $rowset->current();
        return $row->findDependentRowset('Ecart_Tag_Model_Product');
    }

    public function findProductsByTagId($tagId)
    {
        $rowset = $this->find($tagId);
        if (!sizeof($rowset))
            return array();
        $row = $rowset->current();
        return $row->findDependentRowset('Ecart_Tag_Model_Product');
    }

    public function getByProductId($productId)
    {
        $select = $this->getAdapter()->select();
        $select->from(array('tp' => self::$_db_prefix . 'tag_product'),
            array ('tp.*', new Zend_Db_Expr('COUNT(*) weight') )
        );
        $select->joinLeft(
            array('ct' => $this->_name),
            'tp.customer_tag_id = ct.id',
            array('ct.*')
        );
        $select->group('ct.id');
        $select->where($this->getAdapter()->quoteInto('status = ?', 1));
        $weights = array();
        foreach ($select->query()->fetchAll() as $weight) {
            $weights[$weight['name']] = $weight['weight'];
        }
        // return $weights;
        $select->where($this->getAdapter()->quoteInto(
            'tp.product_id = ? ', intval($productId)
        ));
            $tags = array();
        foreach ($select->query()->fetchAll() as $tag) {
            $tags[$tag['name']] = $tag;
            $tags[$tag['name']]['weight'] = $weights[$tag['name']];
        }

        return $tags;
    }

    public function getAllWithWeight($limit = false)
    {
        $select = $this->getAdapter()->select();
        $select->from(array('ct' => $this->_name),
                array('ct.*', new Zend_Db_Expr('COUNT(*) weight')))
            ->joinLeft(array('tp' => self::$_db_prefix . 'tag_product'),
                'tp.customer_tag_id = ct.id',
                'product_id')
            ->where($this->getAdapter()->quoteInto(
                'site_id = ?', Ecart::getSiteId()
            ))
            ->where($this->getAdapter()->quoteInto('status = ?', 1))
            ->group('ct.name')
            //->order('RAND()');
            ->order('weight DESC');
        if ($limit) {
            
            $select->limit($limit);
        }

        $tags = array();
        foreach ($select->query()->fetchAll() as $tag) {
            $tags[$tag['name']] = $tag;
            //$tags[$tag['name']]['weight'] = $weights[$tag['name']];
        }
        ksort($tags);
        return $tags;
    }

   /**
    * Return list tag on backend
    * @param array $params
    * @return mixed|array
    */
    public function getList($params = array())
    {
        $select = $this->getAdapter()->select();
        $select->from(
            array('tc' => $this->_name), array('id', 'tag' => 'name', 'status')
        );
        $select->joinLeft(
            array('c' => self::$_db_prefix . 'account_customer'),
            'tc.customer_id = c.id',
            array('customer_email' => 'email', 'customer_id' => 'id')
        );
        $select->joinLeft(
            array('tp' => self::$_db_prefix . 'tag_product'),
            'tp.customer_tag_id = tc.id',
            'product_id'
        );
        $select->joinLeft(
            array('pd' => self::$_db_prefix . 'catalog_product_description'),
            'pd.product_id = tp.product_id AND pd.language_id = ' 
            . $params['languageId'],
            array('product_name' => 'name')
        );

        if (!empty($params['limit'])) {
            $select->limit($params['limit'], $params['start']);
        }
        if (!empty($params['sort'])) {
            $select->order($params['sort'] . ' ' . $params['dir']);
        }
        if (isset($params['filters'])) {
            $this->_setFilter($select, $params['filters']);
        }

        return $select->query()->fetchAll();
    }

    /**
    * Return count tag on backend
    * @param array $params
    * @return int
    */
    public function getCount($params = array())
    {
        $select = $this->getAdapter()->select();
        $select->from(
            array('tc' => $this->_name), new Zend_Db_Expr('COUNT(*)')
        );
        $select->joinLeft(
            array('c' => self::$_db_prefix . 'account_customer'),
            'tc.customer_id = c.id',
            array()
        );
        $select->joinLeft(
            array('tp' => self::$_db_prefix . 'tag_product'),
            'tp.customer_tag_id = tc.id',
            array()
        );
        $select->joinLeft(
            array('pd' => self::$_db_prefix . 'catalog_product_description'),
            'pd.product_id = tp.product_id AND pd.language_id = ' 
                . $params['languageId'],
            array()
        );

        if (isset($params['filters'])) {
            $this->_setFilter($select, $params['filters']);
        }
        return $this->getAdapter()->fetchOne($select);
    }

    /**
    * @param (Zend_Db_Select|Zend_Db_Table_Select) $select
    * @param array $filters
    * @return mixed (Zend_Db_Select|Zend_Db_Table_Select)
    */
    private function _setFilter(&$select, array $filters)
    {
        foreach ($filters as $filter) {
            switch ($filter['data']['type']) {
                case 'numeric': case 'date':
                    $condition = $filter['data']['comparison'] == 'eq' ? '=' :
                                     ($filter['data']['comparison'] == 'lt' ? '<' : '>');
                    $select->where("cw.$filter[field] $condition ?", $filter['data']['value']);
                    break;
                default:
                    if (($filter['field'] == 'customer_email')) {
                        $select->where("c.email LIKE ?", $filter['data']['value'] . "%");
                    } else if ($filter['field'] == 'product_name') {
                        $select->where("pd.name LIKE ?", $filter['data']['value'] . "%");
                    } else if ($filter['field'] == 'tag') {
                        $select->where("tc.name LIKE ?", $filter['data']['value'] . "%");
                    } else {
                        $select->where("tc.$filter[field] LIKE ?", $filter['data']['value'] . "%");
                    }
                    break;
            }
        }
        return $select;
    }

    /**
    * Returns array of tags status
    *
    * @static
    * @return const array
    */
    public static function getStatuses()
    {
        return array(
            '1' => Ecart::translate('core')->__('Approved'),
            '2' => Ecart::translate('core')->__('Pending'),
            '3' => Ecart::translate('core')->__('Disapproved')
        );
    }

    /**
    * Links recieved tags to product.
    * Split tags by spaces and link each to productId
    *
    * @param string $tags
    * @param int $productId
    * @return bool
    */
    public function save($tags, $productId)
    {
        $tags = explode(',', $tags);

        foreach ($tags as $tag) {
            $tag = trim($tag);
            if (empty($tag)) {
                continue;
            }
            $customerTags = $this->findMyByTag($tag);
            if (count($customerTags)) {
                $rowsWithProductId = $customerTags->current()
                    ->findDependentRowset(Ecart::single('tag/product'));
                $exists = false;
                foreach ($rowsWithProductId as $row) {
                    if ($row->product_id == $productId) {
                        $exists = true;
                        break;
                    }
                }
                if (!$exists) {
                    Ecart::single('tag/product')->insert(array(
                        'customer_tag_id' => $customerTags->current()->id,
                        'product_id' => $productId
                    ));
                    Ecart::dispatch('tag_product_add_success', array(
                        'tag' => $tag,
                        'product_id' => $productId
                    ));
                    Ecart::message()->addSuccess(
                        Ecart::translate('tag')->__(
                            "Tag '%s' was successfully added to product", $tag
                        )
                    );
                } else {
                    Ecart::message()->addError(
                        Ecart::translate('tag')->__(
                            "Your tag '%s' is already added to this product", $tag
                        )
                    );
                }
            } else {
                $tagId = $this->insert(array(
                    'customer_id' => (int)Ecart::getCustomerId(),
                    'site_id' => Ecart::getSiteId(),
                    'name' => $tag,
                    'status' => $this->getDefaultStatus()
                ));
                Ecart::single('tag/product')->insert(array(
                    'customer_tag_id' => $tagId,
                    'product_id' => $productId
                ));
                Ecart::dispatch('tag_product_add_success', array(
                    'tag' => $tag,
                    'product_id' => $productId
                ));
                Ecart::message()->addSuccess(
                    Ecart::translate('tag')->__(
                        "Tag '%s' was successfully added to product", $tag
                    )
                );
            }
        }
        return true;
    }
    
    /**
     * Retrieve the default tag status
     * @return int
     */
    public function getDefaultStatus()
    {
        if (Ecart::getCustomerId()) {
            return Ecart::config('tag/general/customer_status', 1);
        } else {
            return Ecart::config('tag/general/guest_status', 2);
        }
    }
}