<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @category    Ecart
 * @package     Ecart_Tag
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 * 
 * @category    Ecart
 * @package     Ecart_Tag
 * @subpackage  Controller
 * @author      Ecart Core Team <core@ecartcommerce.com>
 */
class Ecart_Tag_IndexController extends Ecart_Core_Controller_Front
{
    /**
     *
     * @var Ecart_Tag_Model_Customer
     */
    private $_table;
    
    public function init()
    {
        parent::init();
        $this->_table = Ecart::single('tag/customer');
        $this->view->crumbs()->add(
            Ecart::translate('tag')->__('Tags'), '/tag'
        );
    }
    
    public function indexAction()
    {
        $this->view->pageTitle = Ecart::translate('tag')->__(
            'Customer tags'
        );
        $this->view->tags = $this->_table->getAllWithWeight();
        $this->render();
    }

    public function showProductsAction()
    {
        $integer = new Zend_Filter_Int();
        $tagIds = array();
        $productIds = array();
        $tagItems = array();
        $tagName = '';
        if ($this->_hasParam('tag')) {
            $tagName = $this->_getParam('tag');
            foreach ($this->_table->findByTag($tagName)->toArray() as $tag) { //@todo findMyByTag 
                $tagIds[] = $tag['id'];
            }
            $this->view->skipRemove = false;
        } else {
            $tagId = $integer->filter($this->_getParam('tagId', 0));
            if (!$tagId) {
                $this->_redirect('/tag');
                return;
            }
            $tagIds[] = $tagId;
            $this->view->skipRemove = true;
            if ($row = $this->_table->find(current($tagIds))->current()) {
                $tagName = $row->name;
            }
        }
        
        $this->view->pageTitle = Ecart::translate('tag')->__(
            "Products associated with tag '%s'", $tagName
        );
        
        foreach ($tagIds as $tagId) {
            $rowset = $this->_table->findProductsByTagId($tagId);
            $items = array();
           
            foreach ($rowset->toArray() as $item) {
                $productIds[] = $item['product_id'];
                $items[$item['product_id']] = $item;
            }
            $tagItems = $items + $tagItems; 
        }
        $this->view->tagItems = $tagItems;
        if (count($productIds)) {
            $this->view->products = Ecart::single('catalog/product')
                ->getProductListByIds($productIds);
        }
        $this->render();
    }
}