<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @category    Ecart
 * @package     Ecart_Tag
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 * @var Ecart_Install_Model_Installer
 */
$installer = Ecart::single('install/installer');

$installer->startSetup();

/**
 * created tables: 
 *  tag_customer,
 *  tag_product
 * use tables (FOREIGN KEY):
 *  account_customer,
 *  core_site,
 *  catalog_product
 */
$installer->run("

-- DROP TABLE IF EXISTS `{$installer->getTable('tag_customer')}`;
CREATE TABLE IF NOT EXISTS `{$installer->getTable('tag_customer')}` (
    `id` int(10) unsigned NOT NULL auto_increment,
    `customer_id` int(10) unsigned default NULL,
    `site_id` smallint(5) unsigned NOT NULL,
    `name` varchar(128) NOT NULL,
    `status` TINYINT(1) NOT NULL default '1',
    PRIMARY KEY  (`id`),
    KEY `i_site_id` USING BTREE (`site_id`),
    KEY `i_customer_id` USING BTREE (`customer_id`),
    CONSTRAINT `FK_customer_tag_customer` FOREIGN KEY (`customer_id`) REFERENCES `{$installer->getTable('account_customer')}` (`id`) ON DELETE SET NULL,
    CONSTRAINT `FK_customer_tag_site` FOREIGN KEY (`site_id`) REFERENCES `{$installer->getTable('core_site')}` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC AUTO_INCREMENT=1 ;

-- DROP TABLE IF EXISTS `{$installer->getTable('tag_product')}`;
CREATE TABLE IF NOT EXISTS `{$installer->getTable('tag_product')}` (
    `id` int(10) unsigned NOT NULL auto_increment,
    `customer_tag_id` int(10) unsigned NOT NULL,
    `product_id` int(10) unsigned NOT NULL,
    PRIMARY KEY  (`id`),
    KEY `customer_tag_products_FKIndex1` (`customer_tag_id`),
    KEY `customer_tag_products_FKIndex2` (`product_id`),
    CONSTRAINT `FK_customer_tag_product_id` FOREIGN KEY (`product_id`) REFERENCES `{$installer->getTable('catalog_product')}` (`id`) ON DELETE CASCADE ON UPDATE CASCADE,
    CONSTRAINT `FK_customer_tag_product_customer` FOREIGN KEY (`customer_tag_id`) REFERENCES `{$installer->getTable('tag_customer')}` (`id`) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

");

Ecart::single('core/config_field')
    ->add('tag/general/customer_status', 'Default customer tag status', 1, 'select', 'Default tag status added by registered customer', array('config_options' => '{"1":"approved","2":"pending","3":"disapproved"}'))
    ->add('tag/general/guest_status', 'Default guest tag status', 2, 'select', 'Default tag status added by guest', array('config_options' => '{"1":"approved","2":"pending","3":"disapproved"}'));

Ecart::single('admin/menu')
    ->add('Catalog', '#', 20)
    ->add('Catalog->Tags', 'tag_index', 50);
    
Ecart::single('admin/acl_resource')
    ->add('admin/tag', 'Tags All')
    ->add('admin/tag_index', 'Tags')
    ->add("admin/tag_index/delete")
    ->add("admin/tag_index/index")
    ->add("admin/tag_index/list")
    ->add("admin/tag_index/save");

Ecart::single('core/page')
    ->add('tag/*/*')
    ->add('tag/index/*')
    ->add('tag/index/show-products');

$installer->registerModule('Ecart_Tag');

$installer->endSetup();