<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @category    Ecart
 * @package     Ecart_Tax
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 * TaxRateModel
 *
 * @category    Ecart
 * @package     Ecart_Tax
 * @subpackage  Model
 * @author      Ecart Core Team <core@ecartcommerce.com>
 */
 class Ecart_Tax_Model_Rate extends Ecart_Db_Table
{
	/**
	 * The default table name 
	 */
	protected $_name = 'tax_rate';
	
    public function update(array $data, $where)
    {
        if (empty($data['modified_on'])) {
            $data['modified_on'] = Ecart_Date::now()->toZendDbExpr();
        }
        return parent::update($data, $where);
    }
    
    public function insert(array $data)
    {
        if (empty($data['created_on'])) {
            $data['created_on'] = Ecart_Date::now()->toZendDbExpr();
        }
        return parent::insert($data);
    }
    
    /**
     * Multi rows save  
     * @param array rows
     * @return bool
     */
    public function save($rows)
    {
        // Saving exists values
        foreach ($rows as $id => $row) {
            
            if (isset($row['id'])) {// update
                $this->update(
                    array(
                        'tax_class_id' => $row['tax_class_id'],
                        'geozone_id'  => $row['geozone_id'],
                        'customer_group_id' => $row['customer_group_id'],
                        'rate'         => $row['rate'],
                        'description'  => $row['description']
                    ), 
                    'id = ' . intval($id)
                );
            } else { // insert
                if ($this->fetchOne('id', 'tax_class_id = '. $row['tax_class_id'] 
                    . ' AND ' . 'geozone_id = ' . $row['geozone_id'] 
                    . ' AND ' . 'customer_group_id = ' . $row['customer_group_id'])) {
                        
                    Ecart::message()->addError(
                        Ecart::translate('checkout')->__(
                            'Duplicate entry (must be unique set taxclass, geozone, customer group)'
                    ));
                    return false;
                }
                $this->insert(array(
                    'tax_class_id' => $row['tax_class_id'],
                    'geozone_id'  => $row['geozone_id'],
                    'customer_group_id' => $row['customer_group_id'],
                    'rate'         => $row['rate'],
                    'description'  => $row['description']
                ));
            }
        }
        return true;
    }
    
    /**
     * Calculate Tax 
     * @param int $shoppingCartId
     * @param array $geozoneIds
     * @return float
     */
    public function calculate($shoppingCartId, $geozoneIds)
    {
        $customerId = Ecart::getCustomerId();
        $customerGroupId = Ecart::single('account/customer')->getGroupId($customerId);

        $geozoneIds = implode(',', $geozoneIds);
        $rawRows = $this->getAdapter()->fetchAll(
            "SELECT cp.id, cp.tax_class_id, scp.final_price, scp.quantity, tr.rate, tr.geozone_id, lg.priority
            FROM " . self::$_db_prefix . "checkout_cart_product scp
            INNER JOIN " . self::$_db_prefix . "catalog_product cp ON cp.id = scp.product_id
            INNER JOIN " . self::$_db_prefix . "tax_rate tr ON tr.tax_class_id = cp.tax_class_id
            INNER JOIN " . self::$_db_prefix . "location_geozone lg ON lg.id = tr.geozone_id
            WHERE scp.shopping_cart_id = {$shoppingCartId} 
            AND tr.geozone_id IN ({$geozoneIds}) AND tr.customer_group_id = {$customerGroupId}"
        );
        $rows = array();
        foreach ($rawRows as $row) {
            if (!isset($rows[$row['id']]) 
                || $rows[$row['id']]['priority'] < $row['priority']) 
            {
                $rows[$row['id']] = $row;
            }
        }
       
        $tax = 0;
        foreach ($rows as $row) {
            $tax += $row['quantity'] * $row['final_price'] * $row['rate'] / 100;
        }
        return round($tax, 2);
    }
    
    /**
     * Calculate tax by one price 
     *  
     * @param int price 
     * @param int $taxClassId
     * @param array $geozoneIds
     * @param int $customerGroupId
     * @return int
     */
    public function calculateByPrice(
            $price, $taxClassId, array $geozoneIds, $customerGroupId)
    {
        if (null == $taxClassId) {
            return 0;
        }
        $geozoneIds = implode(',', $geozoneIds);

        $rate = $this->getAdapter()->fetchOne(
            "SELECT tr.rate 
            FROM {$this->_name} tr 
            INNER JOIN " . self::$_db_prefix . "location_geozone lg ON lg.id = tr.geozone_id
            WHERE tr.geozone_id IN ($geozoneIds) 
            AND tr.customer_group_id = {$customerGroupId}
            AND tr.tax_class_id = {$taxClassId}
            ORDER BY lg.priority DESC LIMIT 1 "
        );
        
        //exit();
        return round(($price * $rate) / 100, 2);
    }
}
