/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

Ext.onReady(function(){
    Ext.QuickTips.init();
    
    var cacheTag = new Ext.data.Record.create([
        'name',
        'is_active',
        'lifetime'
    ])
    
    var ds = new Ext.data.Store({
        url: Ecart.baseUrl + Ecart.adminUrl + '/cache/get-list',
        reader: new Ext.data.JsonReader({
            root: 'data',
            id: 'id'
        }, cacheTag),
        autoLoad: true
    })
    
    var sm = new Ext.grid.CheckboxSelectionModel();
    
    var status = new Ext.grid.CheckColumn({
        header: "Status".l(),
        dataIndex: 'is_active',
        width: 100
    });
    
    var cm = new Ext.grid.ColumnModel([
        sm, {
            header: 'Name'.l(),
            dataIndex: 'name',
            menuDisabled: true
        }, status, {
            header: 'Lifetime'.l(),
            dataIndex: 'lifetime',
            menuDisabled: true,
            editor: new Ext.form.TextField(),
            renderer: function(value) {
                if (!value) {
                    return 'default';
                }
                return value;
            }
        }
    ])
    cm.defaultSortable = true;
    
    var grid = new Ext.grid.EditorGridPanel({
        id: 'grid',
        cm: cm,
        ds: ds,
        sm: sm,
        renderTo: 'grid',
        height: 550,
        autoScroll: true,
        plugins: status,
        clicksToEdit: 1,
        viewConfig: {
            forceFit: true,
            emptyText: 'No records found'.l()
        },
        id: 'grid',
        tbar: [{
            text: 'Save'.l(),
            iconCls: 'x-btn-text',
            icon: Ecart.skinUrl + '/images/icons/save_multiple.png',
            handler: save
        }, {
            text: 'Clear'.l(),
            iconCls: 'x-btn-text',
            icon: Ecart.skinUrl + '/images/icons/bin.png',
            handler: clear
        }, '->', {
            text: 'Reload'.l(),
            iconCls: 'x-btn-text',
            icon: Ecart.skinUrl + '/images/icons/refresh.png',
            handler: reload
        }],
        listeners: {
            'beforerender': function(cmp) {
                cmp.width = $('#ext-cmp-layout').width() - $('#ext-cmp-layout .sidebox').width();
            }
        }
    })
    
    function reload() {
        ds.reload();
    }
})

function save(flag) {
    if (!flag) {
        var modified = Ext.getCmp('grid').getStore().getModifiedRecords();
        if (!modified.length) {
            return false;
        }
    }
    var data = {};
    Ext.getCmp('grid').getStore().each(function(record) {
        if (flag == 'disable') {
            data[record.id] = 0;
        } else if (flag == 'enable') {
            data[record.id] = 1;
        } else {
            data[record.id] = record['data'];
        }
    })
    
    var jsonData = Ext.encode(data);
    Ext.Ajax.request({
        url: Ecart.baseUrl + Ecart.adminUrl + '/cache/save',
        params: {data: jsonData},
        callback: function() {
            Ext.getCmp('grid').getStore().commitChanges();
            Ext.getCmp('grid').getStore().reload();
        }
    })
}

function clear() {
    if (!Ext.getCmp('grid').getSelectionModel().getSelections().length) {
        return false;
    }
    
    var data = {};
    Ext.getCmp('grid').getSelectionModel().each(function(record) {
        data[record.id] = record.id;
    });
    
    var jsonData = Ext.encode(data);
    Ext.Ajax.request({
        url: Ecart.baseUrl + Ecart.adminUrl + '/cache/clean',
        params: {data: jsonData}
    })
}

function clearAll() {
    Ext.Ajax.request({
        url: Ecart.baseUrl + Ecart.adminUrl + '/cache/clean-all'
    })
}

/*checkbox column*/
Ext.grid.CheckColumn = function(config){
    Ext.apply(this, config);
    if(!this.id){
        this.id = Ext.id();
    }
    this.renderer = this.renderer.createDelegate(this);
};

Ext.grid.CheckColumn.prototype = {
    init : function(grid){
        this.grid = grid;
        this.grid.on('render', function(){
            var view = this.grid.getView();
            view.mainBody.on('mousedown', this.onMouseDown, this);
        }, this);
    },

    onMouseDown : function(e, t){
        if(t.className && t.className.indexOf('x-grid3-cc-'+this.id) != -1){
            e.stopEvent();
            var index = this.grid.getView().findRowIndex(t);
            var record = this.grid.store.getAt(index);
            record.set(this.dataIndex, (record.data[this.dataIndex] == 1 ? 0 : 1));
        }
    },

    renderer : function(v, p, record){
        p.css += ' x-grid3-check-col-td'; 
        return '<div class="x-grid3-check-col'+( v == 1 ? '-on' : '')+' x-grid3-cc-'+this.id+'">&#160;</div>';
    }
};
/*end of checkbox column*/