/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

Ext.onReady(function(){
    Set = {
        activeId: 0,
        
        record: Ext.data.Record.create([
            {name: 'id'},
            {name: 'name', type: 'string'}
        ]),
        
        create: function (){
            gridSet.stopEditing();
            var record = new Set.record({
                name: '',
                type: 'new'
            });
            dsSet.insert(0, record);
            gridSet.startEditing(0, 1);
        },
        
        getSelectedId: function() {
            var selModel = gridSet.getSelectionModel();
            var selectedItems = gridSet.getSelectionModel().selections.items;
            if (!selectedItems.length) {
                return false;
            }
            if (selectedItems[0]['data']['id'])
                return selectedItems[0].id;
            return false;
        },
        
        save: function() {
            var modified = dsSet.getModifiedRecords();
            if (!modified.length)
                return;
                
            var data = {};
            
            for (var i = 0; i < modified.length; i++) {
                data[modified[i]['id']] = modified[i]['data'];
            }
            
            Ext.Ajax.request({
                url: Ecart.baseUrl + Ecart.adminUrl + '/catalog_product-option-valueset/save-set',
                params: {
                    data: Ext.encode(data)
                },
                callback: function() {
                    dsSet.commitChanges();
                    dsSet.reload();
                }
            });
        },
        
        editValues: function() {
            var id = Set.getSelectedId();
            if (!id) {
                return;
            }
            Set.activeId = id;
            dsValue.proxy.conn.url = Ecart.baseUrl + Ecart.adminUrl + '/catalog_product-option-valueset/list-values/setId/' + id;
            dsValue.load();
        },
        
        remove: function() {
            var selectedItems = gridSet.getSelectionModel().selections.items;
            
            if (!selectedItems.length)
                return;
            
            if (!confirm('Are you sure?'))
                return;
                
            var data = {};
            
            for (var i = 0; i < selectedItems.length; i++) {
                if (!selectedItems[i]['data']['id']) continue;
                data[i] = selectedItems[i]['data']['id'];
            }
                
            Ext.Ajax.request({
                url: Ecart.baseUrl + Ecart.adminUrl + '/catalog_product-option-valueset/delete-sets',
                params: {data: Ext.encode(data)},
                callback: function() {
                    dsSet.reload();
                }
            });
        },
        grid: {}
    };
    
    var dsSet = new Ext.data.Store({
        proxy: new Ext.data.HttpProxy({
            url: Ecart.baseUrl + Ecart.adminUrl + '/catalog_product-option-valueset/list-sets'
        }),
        reader: new Ext.data.JsonReader({
            root: 'data',
            totalProperty: 'count',
            id: 'id'
        }, Set.record),
        sortInfo: {field: 'id', direction: 'ASC'},
        remoteSort: true
    });
    
    var sm = new Ext.grid.CheckboxSelectionModel(); 
    
    var cmSet = new Ext.grid.ColumnModel([
    sm, {
        header: "Name".l(),
        dataIndex: 'name',
        width: 210,
        editor: new Ext.form.TextField({
            allowBlank: false
        })
    }]);
    
    var gridSet = new Ext.grid.EditorGridPanel({
        store: dsSet,
        cm: cmSet,
        sm: sm,
        height: 550,
        width: 250,
        viewConfig: {
            forceFit: true,
            emptyText: 'No records found'.l()
        },
        clicksToEdit: 1,
        renderTo: 'grid-sets',
        tbar: [{
            text: 'Add'.l(),
            icon: Ecart.skinUrl + '/images/icons/add.png',
            cls: 'x-btn-text-icon',
            handler: Set.create
        }, {
            text: 'Save'.l(),
            icon: Ecart.skinUrl + '/images/icons/accept.png',
            cls: 'x-btn-text-icon',
            handler: Set.save
        }, {
            text: 'Delete'.l(),
            icon: Ecart.skinUrl + '/images/icons/delete.png',
            cls: 'x-btn-text-icon',
            handler: Set.remove
        }, {
            text: 'Values'.l(),
            icon: Ecart.skinUrl + '/images/icons/details.png',
            cls: 'x-btn-text-icon',
            handler: Set.editValues
        }],
        bbar: new Ext.PagingToolbar({
            store: dsSet,
            pageSize: 21,
            displayInfo: true,
            displayMsg: 'Displaying records {0} - {1} of {2}'.l(),
            emptyMsg: 'No records found'.l()
        })
    })
    
    dsSet.load({params:{start:0, limit:21}});
    
    gridValue = new Ext.grid.EditorGridPanel({
        store: dsValue,
        cm: cmValue,
        sm: checkboxColumn,
        renderTo: 'grid-values',
        height: 550,
        clicksToEdit: 1,
        viewConfig: {
            forceFit: true,
            emptyText: 'No records found'.l()
        },
        tbar: [{
            text: 'Add'.l(),
            icon: Ecart.skinUrl + '/images/icons/add.png',
            cls: 'x-btn-text-icon',
            handler : Value.create
        },{
            text: 'Save'.l(),
            icon: Ecart.skinUrl + '/images/icons/accept.png',
            cls: 'x-btn-text-icon',
            handler : Value.save
        }, {
            text: 'Delete'.l(),
            icon: Ecart.skinUrl + '/images/icons/delete.png',
            cls: 'x-btn-text-icon',
            handler : function(){
                var selectedItems = gridValue.getSelectionModel().selections.items;
                
                if (!selectedItems.length)
                    return;
                
                if (!confirm('Are you sure?'.l()))
                    return;
                        
                var data = {};
                
                for (var i = 0; i < selectedItems.length; i++) {
                    data[i] = selectedItems[i].id;
                }
                Ext.Ajax.request({
                    url: Ecart.baseUrl + Ecart.adminUrl + '/catalog_product-option-valueset/delete-values',
                    params: {data: Ext.encode(data)},
                    callback: function() {
                        dsValue.commitChanges();
                        dsValue.reload();
                    }
                });
            }
        }, '->', {
            text: 'Reload'.l(),
            icon: Ecart.skinUrl + '/images/icons/refresh.png',
            cls: 'x-btn-text-icon',
            handler: function(){
                gridValue.getStore().reload();
            }
        }],
        listeners: {
            'beforerender': function(cmp) {
                cmp.width = $('#ext-cmp-layout').width() - $('#ext-cmp-layout .sidebox').width();
            }
        }
    });
});