/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

Ecart.Variations = {
    tree: {},
    _variations: {},
    _newId: 0,
    _getNewId: function () {
        this._newId = this._newId + 1;
        return this._newId;
    },
    create: function() {
        var id = '_' + this._getNewId();
        var variation = new Ecart.Variation({
            id: id,
            status: 'new'
        });
        this.add(variation);
        this.get(id).addOptions();
    },
    
    add: function(variation) {
        this._variations[variation.id] = variation;
        variation.render();
    },
    
    remove: function(variationId) {
        var variation = this._variations[variationId];
        $('#variation-' + variationId).remove();
        if (variation.status == 'new') {
            delete this._variations[variationId];
        } else {
            variation.status = 'removed';
        }
    },
    
    get: function(variationId) {
        return this._variations[variationId];
    },
    
    clear: function() {
        this._variations = {};
        this._newId = 0;
        $('#variations').empty();
    },
    
    toSaveArray: function() {
        var result = {};
        for (var i in this._variations) {
            var variation = this._variations[i];
            result[variation.id] = variation.toSaveArray();
        }
        return result;
    }
};


Ecart.Variation = function (config) {
    for (var i in config) {
        this[i] = config[i];
    }
    this._options = {};
};

Ecart.Variation.prototype = {
    toSaveArray: function() {
        var result = {
            id: this.id,
            status: this.status,
            options: {}
        };
        for (var i in this._options) {
            var option = this._options[i];
            result.options[option.product_option_id] = option.toSaveArray();
        }
        return result;
    },
    addOption: function (option) {
        this._options[option.product_option_id] = option;
        option.renderTo = 'variation-' + this.id + '-options';
        if (this.rendered)
            option.render();
    },
    
    addOptions: function() {
        var options = Ecart.Variations.tree.getSelectionModel().getSelectedNodes();
        for (var i = 0, n = options.length; i < n; i++) {
            var node = options[i];
            
            var config = {
                status: 'new',
                product_variation_id: this.id
            };
            if (node.attributes.type == 'option') {
                config.product_option_id = node.id;
                config.optionName = node.text;
            } else if(node.attributes.type == 'value') {
                config.product_option_value_id = node.attributes.value_id;
                config.valueName = node.text;
                config.product_option_id = node.parentNode.id;
                config.optionName = node.parentNode.text;
            } else continue;
            
            if (this._options[config.product_option_id]) {
                if (!this._options[config.product_option_id].isRemoved())
                    continue;
                config.status = 'update';
            }
            
            var option = new Ecart.Option(config);
            this.addOption(option);
        }
    },
    
    removeOption: function(optionId) {
        var option = this._options[optionId];
        $('#v-option-' + this.id + '-' + option.product_option_id).remove();
        if (option.status == 'new') {
            delete this._options[option.product_option_id];
        } else option.status = 'removed';
    },
    
    render: function() {
        var tpl = Ext.Template.from('variation-tpl');
        var config = {
            id: this.id,
            sku: this.sku,
            price: this.price,
            price_type: this.price_type,
            weight: this.weight,
            weight_type: this.weight_type,
            quantity: this.quantity
        };
        config['price_' + this.price_type] = 'selected="1"';
        config['weight_' + this.weight_type] = 'selected="1"';
        tpl.insertFirst('variations', config);
        this.rendered = true;
    }
};

Ecart.Option = function (config) {
    for (var i in config) {
        this[i] = config[i];
    }
    this.rendered = false;
};

Ecart.Option.prototype = {
    toSaveArray: function() {
        return {
            id: this.id,
            product_option_id: this.product_option_id,
            product_option_value_id: this.product_option_value_id,
            status: this.status
        };
    },
    
    render: function() {
        var tpl = Ext.Template.from('v-option-tpl');
        tpl.insertFirst(this.renderTo, {
            variationId: this.product_variation_id,
            id: this.product_option_id,
            optionName: this.optionName,
            valueName: this.valueName
        })
        this.rendered = true;
    },
    
    isRemoved: function() {
        return this.status == 'removed';
    }
};