/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

Ext.onReady(function(){
    
     Ext.QuickTips.init();
    
     
     var ds = new Ext.data.Store({
        url: Ecart.baseUrl + Ecart.adminUrl + '/customer_group/list',
        reader: new Ext.data.JsonReader({
            root: 'data',
            id: 'id'
        }, [
            {name: 'name', mapping: 'name'},
            {name: 'description', mapping: 'description'}
        ]),
        pruneModifiedRecords: true
    });
    
    var cm = new Ext.grid.ColumnModel([{
        id: 'topic', // id assigned so we can apply custom css
        header: "Group Name".l(),
        dataIndex: 'name',
         width: 320,
         sortable: true,
         editor: new Ext.form.TextField({
           allowBlank: false
        })
     },{
          header: "Description".l(),
          dataIndex: 'description',
          width: 130,
          sortable: true,
          editor: new Ext.form.TextField({
           allowBlank: true
        })
     }]);
     
    var grid = new Ext.grid.EditorGridPanel({
         renderTo: 'editor-grid',
        ds: ds,
        cm: cm,
        viewConfig: {
            forceFit: true,
            emptyText: 'No records found'.l()
        },
        height: 550,
        clicksToEdit: 1,
        selModel: new Ext.grid.RowSelectionModel({singleSelect:true}),
        tbar: [{
             text: 'Add'.l(),
             icon: Ecart.skinUrl + '/images/icons/add.png',
             cls: 'x-btn-text-icon',
             handler : function(){
                 var p = new Group({
                     name: 'New Group',
                     description: ''
                 });
                 grid.stopEditing();
                 ds.insert(0, p);
                 grid.startEditing(0, 0);
             }
         },{
              text: 'Save'.l(),
              icon: Ecart.skinUrl + '/images/icons/accept.png',
             cls: 'x-btn-text-icon',
             handler : function(){
                  var data = {};
                 var modified = ds.getModifiedRecords();
                 for (var i = 0; i < modified.length; i++) {
                      data[modified[i]['id']] = modified[i]['data'];
                 }
                 var jsonData = Ext.encode(data);
                 Ext.Ajax.request({
                      url: Ecart.baseUrl + Ecart.adminUrl + '/customer_group/save',
                      params: {data: jsonData},
                      callback: function() {
                           ds.reload();
                      }
                 });
             }
         },{
             text: 'Delete'.l(),
             icon: Ecart.skinUrl + '/images/icons/delete.png',
             cls: 'x-btn-text-icon',
             handler : function(){
                  if (!confirm('Delete group?'))
                       return;
                  var data = {};
                 var selectedItems = grid.getSelectionModel().selections.items;
                 for (var i = 0; i < selectedItems.length; i++) {
                      data[i] = selectedItems[i].id;
                 }
                 var jsonData = Ext.encode(data);
                 Ext.Ajax.request({
                      url: Ecart.baseUrl + Ecart.adminUrl + '/customer_group/delete',
                      params: {data: jsonData},
                      callback: function() {
                           ds.reload();
                      }
                 });
             }
         }, '->', {
            text: 'Reload'.l(),
            icon: Ecart.skinUrl + '/images/icons/refresh.png',
            cls: 'x-btn-text-icon',
            handler: function(){
                grid.getStore().reload();
            }
        }],
        listeners: {
            'beforerender': function(cmp) {
                cmp.width = $('#ext-cmp-layout').width() - $('#ext-cmp-layout .sidebox').width();
            }
        }
    });
    
     var Group = Ext.data.Record.create([
           {name: 'name', type: 'string'},
           {name: 'description'}
      ]);

    ds.load();
    
}, this);