/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

Ext.onReady(function(){
    
    var countryTip = new Ext.ToolTip({
        title: 'Attention',
        html: 'Be sure that selected country accept selected language & currency',
        target: 'gCountry',
        trackMouse: true,
        dismissDelay: 0
    });
    var langTip = new Ext.ToolTip({
        title: 'Attention',
        html: 'Be sure that selected language is accepted by Google',
        target: 'language',
        trackMouse: true,
        dismissDelay: 0 
    });
    var curTip = new Ext.ToolTip({
        title: 'Attention',
        html: 'Be sure that selected currency is accepted by Google',
        target: 'currency',
        trackMouse: true,
        dismissDelay: 0 
    });
    
    var localStore = new Ext.data.Store({
        url: Ecart.baseUrl + Ecart.adminUrl + '/catalog_index/list-products/',
        reader: new Ext.data.JsonReader({
               root: 'data',
               totalProperty: 'count',
               id: 'id'
            }, [
                {name: 'id'},
                {name: 'is_active'}, 
                {name: 'name'}, 
                {name: 'date_available', type: 'date', dateFormat: 'Y-m-d'},
                {name: 'price', type: 'float'}
            ]
        ),
        remoteSort: true
    });
    
    localStore.setDefaultSort('name', 'asc');
    
    var sm = new Ext.grid.CheckboxSelectionModel();
    
    var cm = new Ext.grid.ColumnModel([
        sm, {
            header: "Id".l(),
            dataIndex: 'id',
            width: 30
        }, {
            header: "Name".l(), 
            dataIndex: 'name', 
            width: 200, 
            css: 'white-space:normal;' 
        }, {
            header: "Price".l(),
            dataIndex: 'price',
            width: 80
        }
    ]);
    cm.defaultSortable = true;
    
    localGrid = new Ext.grid.GridPanel({
        renderTo: 'localGrid', /* tab panel */
        id: 'extLocalGrid',
        trackMouseOver: false,
        border: false,
        ds: localStore,
        stripeRows: true,
        cm: cm,
        sm: sm,
        height: 474,
        viewConfig: {
            forceFit: true,
            emptyText: 'No records found'.l()
        },
        loadMask: false,
        autoScroll: true,
        bbar: new Ext.PagingToolbar({
            pageSize: 25,
            store: localStore,
            displayInfo: true,
            displayMsg: 'Displaying records {0} - {1} of {2}'.l(),
            emptyMsg: 'No records found'.l()
        }),
        tbar: [
            new Ext.Toolbar.TextItem('Target country  '.l()),
            new Ext.Toolbar.Item('gCountry'),
            new Ext.Toolbar.Separator(),
            new Ext.Toolbar.TextItem('Import language  '.l()),
            new Ext.Toolbar.Item('language'),
            new Ext.Toolbar.Separator(),
            new Ext.Toolbar.TextItem('Currency  '.l()),
            new Ext.Toolbar.Item('currency'),
            new Ext.Toolbar.Separator(),
            new Ext.Toolbar.Button({
                iconCls: 'x-btn-text-icon',
                icon: Ecart.skinUrl + '/images/icons/move.png',
                text: 'Export'.l(),
                handler: exportSelectedItems
            }),
            new Ext.Toolbar.Fill(),
            new Ext.Toolbar.Button({
                iconCls: 'x-btn-icon',
                icon: Ecart.skinUrl + '/images/icons/refresh.png',
                handler: function(){
                    localGrid.getStore().reload();
                }
            })
        ],
        listeners: {
            'beforerender': function(cmp) {
                cmp.width = $('#ext-cmp-layout').width() - $('#ext-cmp-layout .sidebox').width();
            }
        }
    });
    
})

function exportSelectedItems(){
    var selected = localGrid.getSelectionModel().getSelections();
    
    if (!selected.length) return;
    
    if (isNaN(siteId)) {
        alert('Site is undefined');
        return false;
    }
    
    var data = {};
    var params = {};
    
    for (var i = 0; i < selected.length; i++){
        data[i] = selected[i].id;
    }
    
    params['items'] = Ext.encode(data);
    params['site'] = siteId;
    params['language'] = Ext.getDom('language').value;
    params['country']  = Ext.getDom('gCountry').value;
    params['currency'] = Ext.getDom('currency').value;
    
    ajaxExportItems(params, 1);
}

function ajaxExportItems(params, clearSession){
    if (clearSession) {
        Ext.getCmp('extProgressBar').reset();
        Ext.getCmp('extProgressBar').updateText('Initializing...');
        Ext.get('lightbox-info').show();
    }
    
    Ext.Ajax.request({
        url: Ecart.baseUrl + Ecart.adminUrl + '/gbase_index/export',
        method: 'post',
        params: {
            items:    params['items'],
            language: params['language'],
            country : params['country'],
            currency: params['currency'],
            site    : params['site'],
            clearSession: clearSession
        },
        callback: function(options, success, response){
            if (success) {
                var obj = Ext.util.JSON.decode(response.responseText);
                Ext.getCmp('extProgressBar').updateProgress(obj.processed/obj.count, 'Exported ' + obj.processed + ' of ' + obj.count);
                if (!obj.finalize) {
                    ajaxExportItems(params, 0);
                } else {
                    Ext.get('lightbox-info').hide();
                }
            } else {
                Ext.getCmp('extProgressBar').updateText('An error has been occured. Connecting...');
                ajaxExportItems(params, 0);
            }
        }
    })
}