/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

Ext.onReady(function() {
    Ext.QuickTips.init();
    
    var module = new Ext.data.Record.create([
        'code',
        'name',
        'package',
        'is_active',
        'version',
        'hide_install',
        'hide_upgrade',
        'hide_uninstall',
        'upgrade_tooltip',
        'install_tooltip'
    ])
    
    var ds = new Ext.data.Store({
        url: Ecart.baseUrl + Ecart.adminUrl + '/module/get-list',
        reader: new Ext.data.JsonReader({
            root: 'data',
            id: 'name'
        }, module),
        autoLoad: true
    })
    
    var sm = new Ext.grid.CheckboxSelectionModel();
    
    var status = new Ext.grid.CheckColumn({
        header: "Status".l(),
        dataIndex: 'is_active',
        menuDisabled: true,
        fixed: true,
        width: 60
    });
    
    var actions = new Ext.ux.grid.RowActions({
        header: 'Actions'.l(),
        actions: [{
            iconCls: 'icon icon-box-green',
            tooltip: 'Install'.l(),
            qtipIndex: 'install_tooltip',
            hideIndex: 'hide_install',
            callback: function(grid, record, action, row, col) {
                Ext.Ajax.request({
                    url: Ecart.baseUrl + Ecart.adminUrl + '/module/install/code/' + record.get('code'),
                    callback: callback
                })
            }
        }, {
            iconCls: 'icon icon-light',
            tooltip: 'Upgrade'.l(),
            qtipIndex: 'upgrade_tooltip',
            hideIndex: 'hide_upgrade',
            callback: function(grid, record, action, row, col) {
                Ext.Ajax.request({
                    url: Ecart.baseUrl + Ecart.adminUrl + '/module/upgrade/code/' + record.get('code'),
                    callback: callback
                })
            }
        }, {
            iconCls: 'icon icon-bin',
            tooltip: 'Uninstall'.l(),
            hideIndex: 'hide_uninstall',
            callback: function(grid, record, action, row, col) {
                Ext.Ajax.request({
                    url: Ecart.baseUrl + Ecart.adminUrl + '/module/uninstall/code/' + record.get('code'),
                    callback: callback
                })
            }
        }]
    });
    
    var cm = new Ext.grid.ColumnModel([
        sm, {
            header: 'Package'.l(),
            id: 'package',
            dataIndex: 'package'
        }, {
            header: 'Name'.l(),
            id: 'name',
            dataIndex: 'name',
            menuDisabled: true
        }, {
            header: 'Version'.l(),
            dataIndex: 'version',
            width: 70,
            fixed: true,
            menuDisabled: true
        }, status, actions
    ])
    cm.defaultSortable = true;
    
    var grid = new Ext.grid.EditorGridPanel({
        id: 'grid',
        cm: cm,
        ds: ds,
        sm: sm,
        renderTo: 'grid',
        height: 550,
        autoScroll: true,
        clicksToEdit: 1,
        stripeRows: true,
        trackMouseOver: true,
        autoExpandColumn: 'name',
        viewConfig: {
            forceFit: true,
            emptyText: 'No records found'.l()
        },
        plugins: [
            status,
            actions,
            new Ext.ux.grid.Search({
                mode: 'local',
                align: 'left',
                iconCls: false,
                dateFormat: 'Y-m-d',
                width: 200,
                minLength: 2
            })
        ],
        bbar: [],
        tbar: ['->', {
            text: 'Reload'.l(),
            iconCls: 'x-btn-text',
            icon: Ecart.skinUrl + '/images/icons/refresh.png',
            handler: reload
        }],
        listeners: {
            'beforerender': function(cmp) {
                cmp.width = $('#ext-cmp-layout').width() - $('#ext-cmp-layout .sidebox').width();
            }
        }
    })
    
    function reload() {
        ds.reload();
    }
    
    function callback(request, success, response) {
        if (response.responseText == '') {
            window.location.reload();
        } else {
            var response = Ext.decode(response.responseText);
            if (response.success == true) { //@todo if reloadRequired == true
                window.location.reload()
            }
        }
    }
})

/*checkbox column*/
Ext.grid.CheckColumn = function(config){
    Ext.apply(this, config);
    if(!this.id){
        this.id = Ext.id();
    }
    this.renderer = this.renderer.createDelegate(this);
};

Ext.grid.CheckColumn.prototype = {
    init : function(grid){
        this.grid = grid;
        this.grid.on('render', function(){
            var view = this.grid.getView();
            view.mainBody.on('mousedown', this.onMouseDown, this);
        }, this);
    },

    onMouseDown : function(e, t){
        if(t.className && t.className.indexOf('x-grid3-cc-'+this.id) != -1){
            e.stopEvent();
            var index = this.grid.getView().findRowIndex(t);
            var record = this.grid.store.getAt(index);
            record.set(this.dataIndex, (record.data[this.dataIndex] == 1 ? 0 : 1));
        }
    },

    renderer : function(v, p, record){
        p.css += ' x-grid3-check-col-td'; 
        return '<div class="x-grid3-check-col'+( v == 1 ? '-on' : '')+' x-grid3-cc-'+this.id+'">&#160;</div>';
    }
};
/*end of checkbox column*/