/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

var Order;
Ext.onReady(function(){

    Order = {
        activeId: 0,
        record: Ext.data.Record.create([
            {name: 'id'},
            {name: 'site_id'},
            {name: 'date_purchased_on'},
            {name: 'billing_name'},
            {name: 'delivery_name'},
            {name: 'customer_email'},
            {name: 'customer_id'},
            {name: 'order_status_id'},
            {name: 'order_total'}
        ]),
        
        getSelectedId: function() {
            var selected = Ext.getCmp('grid-order').getSelectionModel().getSelected();
            if (!selected) {
                return false;
            }
            return selected.id;
        },
        
        window: {},
        
        load: function(id) {
            if (typeof(id) == 'undefined')
            id = this.getSelectedId();
            if (!id) {
                alert('Select order to edit'.l());
                return false;
            }
            Order.activeId = id;

            Ext.Ajax.request({
                url: Ecart.baseUrl + Ecart.adminUrl + '/sales_order/get-order-info' + '/orderId/' + id,
                method: 'get',
                success: function(response, options) {
                    var data = Ext.decode(response.responseText);
                    Order.window.show();
                    $('#tab-order-info').empty().append(data['info'] + data['products']);
                    $('#status-history-list').empty().append(data['statusHistory']);
                    Ext.ux.Table.colorize();
                    var orderStatusId = Ext.getCmp('grid-order').getStore().getById(Order.activeId).data.order_status_id;
                    orderStatusChild.baseParams = {
                        'parentId': orderStatusId
                    };
                    orderStatusChild.load();
                    Ext.getCmp('next_order_status_id').render();
                    Order.window.doLayout();
                }
            });
        },
        
        updateStatusHistory: function(orderId) {
             Ext.Ajax.request({
                 url: Ecart.baseUrl + Ecart.adminUrl + '/sales_order/get-status-history/orderId/' + orderId,
                 method: 'GET',
                 success: function(response, options) {
                     var data = Ext.decode(response.responseText);
                    $('#status-history-list').empty().append(data['statusHistory']);
                    $('#order-status-name').html(data['status_name']);
                     Ext.ux.Table.colorize();
                     Order.window.doLayout();
                }
            });
        },
        //@todo change status many order
        save: function() {
            var data = {};
            var modified = ds.getModifiedRecords();
            if (!modified.length)
                return;
            
            for (var i = 0; i < modified.length; i++) {
                data[modified[i]['id']] = modified[i]['data'];
            }
            
            Ext.Ajax.request({
                url: Ecart.baseUrl + Ecart.adminUrl + '/sales_order-status/batch-save',
                params: {
                    data: Ext.encode(data)
                },
                callback: function() {
                    ds.commitChanges();
                    ds.reload();
                }
            });
            
        },
        
        saveStatus: function() {
            var statusId = $('#order_status_id').val();
             Order.formComment.getForm().submit({
                url: Ecart.baseUrl + Ecart.adminUrl + '/sales_order/set-status/orderId/' + Order.activeId,
                clientValidation: true,
                success: function() {
                    Order.formComment.getForm().reset();
                    Order.updateStatusHistory(Order.activeId);
                    
                    orderStatusChild.baseParams = {
                        'parentId': statusId
                    };
                    orderStatusChild.load();
                    Ext.getCmp('next_order_status_id').render();
                    ds.reload();
                }
            })
        },
        
        remove: function() {
            var selectedItems = grid.getSelectionModel().selections.items;
            
            if (!selectedItems.length || !confirm('Are you sure?'.l())) {
                return false;
            }
            
            var data = {};
            for (var i = 0; i < selectedItems.length; i++) {
                if (!selectedItems[i]['data']['id']) {
                    continue;
                }
                data[i] = selectedItems[i]['data']['id'];
            }
            Ext.Ajax.request({
                url: Ecart.baseUrl + Ecart.adminUrl + '/sales_order/delete',
                params: {data: Ext.encode(data)},
                callback: function() {
                    ds.reload();
                }
            });
        },
        _beforePrint: function()
        {
            $('#print-label-address-type').val('billing');
            $('#print-invoice').val(false);
            $('#print-packingslip').val(false);
            $('#print-label').val(false);
            var selectedItems = Ext.getCmp('grid-order').getSelectionModel().selections.items;
            if (!selectedItems.length) {
                return false;
            }
            var data = {};
            for (var i = 0; i < selectedItems.length; i++) {
                data[i] = selectedItems[i]['data']['id'];
            }
            $('#print-form-data').val(Ext.encode(data));
            return true;
        },
        formStatusHide: function() {
            $('#form-change-status').hide();
        },
        formStatusShow: function() {
            $('#form-change-status').removeClass('x-hidden').show();
             Order.tabPanel.activate(1);
             Order.formComment.doLayout();
        }
    };
    
    Ext.QuickTips.init();
    
    Ext.menu.RangeMenu.prototype.icons = {
        gt: Ecart.skinUrl + '/images/icons/greater_then.png', 
        lt: Ecart.skinUrl + '/images/icons/less_then.png',
        eq: Ecart.skinUrl + '/images/icons/equals.png'
    };
    Ext.grid.filter.StringFilter.prototype.icon = Ecart.skinUrl + '/images/icons/find.png';
    
    var filters = new Ext.grid.GridFilters({
        filters: [
            {type: 'numeric', dataIndex: 'id'},
            {type: 'string',  dataIndex: 'billing_name'},
            {type: 'string',  dataIndex: 'delivery_name'},
            {type: 'string',  dataIndex: 'customer_email'},
            {type: 'string',  dataIndex: 'billing_name'},
            {type: 'numeric', dataIndex: 'order_total'},
            {type: 'numeric', dataIndex: 'customer_id'},
            {type: 'date',    dataIndex: 'date_purchased_on', dateFormat: 'Y-m-d'},
            {
                type: 'list', 
                dataIndex: 'order_status_id',
                options: statusOrder,
                phpMode: true
            },{
                type: 'list', 
                dataIndex: 'site_id',
                options: statusSites,
                phpMode: true
            }
        ]
    });
    
    var orderStatusChild = new Ext.data.Store({
        url:  Ecart.baseUrl + Ecart.adminUrl + '/sales_order-status/get-childs',
        reader: new Ext.data.JsonReader({
            root: 'data',
            id: 'id'
        }, ['id', 'name'])
    });
    
    Order.formComment = new Ext.form.FormPanel({
        renderTo: 'form-change-status',
        frame: true,
        bodyStyle: 'padding:5px 5px 0',
        autoHeight: true,
        items: [{
            layout:'column',
            items:[{
                columnWidth: .5,
                layout: 'form',
                items: [new Ext.form.ComboBox({
                    id : 'next_order_status_id',
                    hiddenName: 'order_status_id',
                    name: 'order_status_id',
                    fieldLabel: 'Order Status'.l(),
                    triggerAction: 'all',
                    store: orderStatusChild,
                    displayField: 'name',
                    valueField: 'id',
                    mode: 'local'
                })]
            }, {
                columnWidth: .5,
                layout: 'form',
                items: [{
                    xtype:'checkbox',
                    fieldLabel: 'Notify Customer'.l(),
                    name: 'notify_customer',
                    anchor:'98%'
                }]
            }/*, {
                 columnWidth:.25,
                layout: 'form',
                items: [{
                     xtype:'checkbox',
                    fieldLabel: 'Append Comment'.l(),
                    name: 'append_comment',
                    anchor:'98%'
                }]
            }*/]
        }, {
            xtype:'textarea',
            fieldLabel: 'Comment'.l(),
            name: 'comment',
            anchor:'98%'
        }],
        buttonAlign: 'right',
        buttons: [{
            text: 'Save'.l(),
            handler: Order.saveStatus
        }, {
            text: 'Cancel'.l(),
            handler: Order.formStatusHide
        }]
    });
    
    Order.tabPanel = new Ext.TabPanel({
        activeTab: 0,
        border: false,
        region: 'center',
        deferredRender: true,
        plain: true,
        autoScroll:true,
        layoutOnTabChange: true,
        items: [
            {contentEl: 'tab-order-info', title: 'Order Info', layout:'fit', autoScroll:true},
            {contentEl: 'tab-order-status-history', title: 'Status history', layout: 'fit', autoScroll: true}
        ]
    });
    
    /* Window */
    Order.window = new Ext.Window({
        layout: 'border',
        title: 'Order'.l(),
        constrainHeader:true,
        width: 800,
        height: 600,
        //autoHeight: true,
        closeAction: 'hide',
        plain: true,
        maximizable: true,
        autoScroll:true,
        items: [Order.tabPanel],
        tbar: [{
            text: 'Change Status'.l(),
            icon: Ecart.skinUrl + '/images/icons/details.png',
            cls: 'x-btn-text-icon',
            handler : Order.formStatusShow
        }],

        buttons: [{
            text: 'Close'.l(),
            handler: function(){
                Order.window.hide();
            }
        }]
    });
    
    var ds = new Ext.data.Store({
        proxy: new Ext.data.HttpProxy({
            url: Ecart.baseUrl + Ecart.adminUrl + '/sales_order/list'
        }),
        
        reader: new Ext.data.JsonReader({
            root: 'data',
            totalProperty: 'count',
            id: 'id'
        }, Order.record),

        remoteSort: true,
        pruneModifiedRecords: true
    });
    
    var selectModel = new Ext.grid.CheckboxSelectionModel();
    
    var cm = new Ext.grid.ColumnModel([
        selectModel, {
            header: "Id".l(),
            dataIndex: 'id',
            width: 40,
            sortable: true
        },{
            header: "Site".l(),
            dataIndex: 'site_id',
            width: 100,
            renderer: function(id) {
                if (typeof(sites[id]) == undefined) {
                    return 'Undefined'.l();
                }
                return sites[id];
            }
        },{
            header: "Order Total".l(),
            dataIndex: 'order_total',
            width: 130
        },{
            header: "Purchased On".l(),
            dataIndex: 'date_purchased_on',
            width: 130
        },{
            header: "Customer".l(),
            width: 170,
            sortable: true,
            dataIndex: 'customer_email',
            renderer: 	function (value, meta, record) {
                meta.attr = 'ext:qtip="Open in new window ' + value + '"';
                var customerId = record.data.customer_id;
                if ("0" === customerId) {
                    return value;
                }
                var customerAction =  Ecart.baseUrl + Ecart.adminUrl + '/customer_index/edit/customerId/.customerId.';
                return String.format(
                        '<a href="{1}" class="grid-link-icon user" target="_blank" >{0}</a>',
                        value, customerAction.replace(/\.customerId\./, record.data.customer_id));
           }
        },{
            header: "Billing".l(),
            dataIndex: 'billing_name',
            width: 130
        },{
            header: "Delivery".l(),
            dataIndex: 'delivery_name',
            width: 130
        },{
            header: "Status".l(),
            dataIndex: 'order_status_id',
            width: 130,
            renderer: function (statusId) {
                 for (var i in orderStatuses) {
                     if (orderStatuses[i]['status_id'] == statusId) {
                         return orderStatuses[i]['status_name'];
                     }
                 }

                 return 'unknown';
            }
        }
    ]);
    
    var grid = new Ext.grid.EditorGridPanel({
        sm: selectModel,
        ds: ds,
        cm: cm,
        id:'grid-order',
        height: 550,
        renderTo: 'grid-order',
        clicksToEdit: 1,
        viewConfig: {
            forceFit: true,
            emptyText: 'No records found'.l()
        },
        bbar: new Ext.PagingToolbar({
            pageSize: 21,
            store: ds,
            displayInfo: true,
            displayMsg: 'Displaying records {0} - {1} of {2}'.l(),
            emptyMsg: "No records found".l()
        }),
        plugins:[
            filters,
            new Ext.ux.grid.Search({
                mode:'local',
                iconCls:false,
                dateFormat:'Y-m-d',
                width: 150,
                minLength:2
            })
        ],
        tbar: [/*{
            text: 'Add'.l(),
            icon: Ecart.skinUrl + '/images/icons/add.png',
            cls: 'x-btn-text-icon',
            handler : function(){}
        },{
            text: 'Save'.l(),
            icon: Ecart.skinUrl + '/images/icons/save_multiple.png',
            cls: 'x-btn-text-icon',
            handler : Order.save
        },*/{
            text: 'Edit'.l(),
            icon: Ecart.skinUrl + '/images/icons/page_edit.png',
            cls: 'x-btn-text-icon',
            handler: function(){
                Order.load();
            }
        }, {
            text: 'Print'.l(),
            icon: Ecart.skinUrl + '/images/icons/printer_add.png',
            cls: 'x-btn-text-icon',
            menu : {items: [{
                    text: 'Print Invoces'.l(),
                    handler: function(menuItem, cheked) {
                        if (Order._beforePrint()) {
                            $('#print-invoice').val(true);
                            $('#print-form').submit();
                        }
                    }
                }, {
                    text: 'Print Packingslips'.l(),
                    handler: function(menuItem, cheked) {
                        if (Order._beforePrint()) {
                            $('#print-packingslip').val(true);
                            $('#print-form').submit();
                        }
                    }
                }, {
                    text: 'Print Invoces & Packingslips'.l(),
                    handler: function(menuItem, cheked) {
                        if (Order._beforePrint()) {
                            $('#print-invoice').val(true);
                            $('#print-packingslip').val(true);
                            $('#print-form').submit();
                        }
                    }
                }, {
                    text: 'Print Label Billing'.l(),
                    handler: function(menuItem, cheked) { 
                        if (Order._beforePrint()) {
                            $('#print-label').val(true);
                            $('#print-form').submit();
                        }
                    }
                }, {
                    text: 'Print Label Shipping'.l(),
                    handler: function(menuItem, cheked) {
                        if (Order._beforePrint()) {
                            $('#print-label').val(true);
                            $('#print-label-address-type').val('shipping');
                            $('#print-form').submit();
                        }
                    }
                }
            ]}}, '-', {
                text: 'Delete'.l(),
                icon: Ecart.skinUrl + '/images/icons/delete.png',
                cls: 'x-btn-text-icon',
                handler : Order.remove
            },'->', {
                text: 'Reload'.l(),
                handler: reload,
                iconCls: 'btn-text-icon',
                icon: Ecart.skinUrl + '/images/icons/refresh.png'
            }
        ],
        listeners: {
            'beforerender': function(cmp) {
                cmp.width = $('#ext-cmp-layout').width() - $('#ext-cmp-layout .sidebox').width();
            }
        }
    });
    
    function reload(){
        Ext.getCmp('grid-order').store.reload();
    }
    
    grid.on('rowdblclick', function(grid, index) {
        Order.load(grid.getStore().getAt(index).id);
    });
    
    if (typeof(orderId) !== "undefined")
        Order.load(orderId); 
           
    ds.load({params:{start:0, limit:21}});
    
}, this);