<?php
/**
 * Ecart
 *
 * This file is part of Ecart.
 *
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @category    Ecart
 * @package     Ecart_Core
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 *
 * @category    Ecart
 * @package     Ecart_Core
 * @author      Ecart Core Team <core@ecartcommerce.com>
 */
class Ecart_Bootstrap extends Zend_Application_Bootstrap_Bootstrap
{
    protected function _initEnviroment()
    {
        date_default_timezone_set('UTC');
        error_reporting(E_ALL | E_STRICT);
        /**
         * Custom error handler E_ALL to Exception
         *
         * @param integer $errno
         * @param string $errstr
         * @param string $errfile
         * @param integer $errline
         */
        function EcartErrorHandler($errno, $errstr, $errfile, $errline)
        {
            $errno = $errno & error_reporting();
            if ($errno == 0) {
                return false;
            }
            if (!defined('E_STRICT')) {
                define('E_STRICT', 2048);
            }
            if (!defined('E_RECOVERABLE_ERROR')) {
                define('E_RECOVERABLE_ERROR', 4096);
            }

            $errorMessage = '';

            switch($errno){
                case E_ERROR:
                    $errorMessage .= "Error";
                    break;
                case E_WARNING:
                    $errorMessage .= "Warning";
                    break;
                case E_PARSE:
                    $errorMessage .= "Parse Error";
                    break;
                case E_NOTICE:
                    $errorMessage .= "Notice";
                    break;
                case E_CORE_ERROR:
                    $errorMessage .= "Core Error";
                    break;
                case E_CORE_WARNING:
                    $errorMessage .= "Core Warning";
                    break;
                case E_COMPILE_ERROR:
                    $errorMessage .= "Compile Error";
                    break;
                case E_COMPILE_WARNING:
                    $errorMessage .= "Compile Warning";
                    break;
                case E_USER_ERROR:
                    $errorMessage .= "User Error";
                    break;
                case E_USER_WARNING:
                    $errorMessage .= "User Warning";
                    break;
                case E_USER_NOTICE:
                    $errorMessage .= "User Notice";
                    break;
                case E_STRICT:
                    $errorMessage .= "Strict Notice";
                    break;
                case E_RECOVERABLE_ERROR:
                    $errorMessage .= "Recoverable Error";
                    break;
                default:
                    $errorMessage .= "Unknown error ($errno)";
                    break;
            }

            $errorMessage .= ": {$errstr}  in {$errfile} on line {$errline}";

            throw new Exception($errorMessage);
        }
        set_error_handler('EcartErrorHandler');
    }

    protected function _initLoader()
    {
        $this->bootstrap('Enviroment');
        require_once 'Zend/Loader/Autoloader.php';
        $autoloader = Zend_Loader_Autoloader::getInstance();
        $autoloader->registerNamespace(array(
            'Ecart'
        ));
        return $autoloader;
    }

    protected function _initConfig()
    {
        $this->bootstrap('Loader');
        require_once ECART_ROOT . '/app/etc/config.php';
        Zend_Registry::set('config', new Ecart_Config($config, true));
        return Ecart::config();
    }

    protected function _initSession()
    {
        $cacheDir = ECART_ROOT . '/var/sessions';
        if (!is_readable($cacheDir)) {
            mkdir($cacheDir, 0777);
        } elseif(!is_writable($cacheDir)) {
            chmod($cacheDir, 0777);
        }
        Zend_Session::start();
        Zend_Session::setOptions(array(
            'cookie_lifetime' => 864000, // 10 days
            'name' => 'ecartid',
            'strict' => 'off',
            'save_path' => $cacheDir
        ));
        Zend_Registry::set('nsMain', new Zend_Session_Namespace());
        return Ecart::session();
    }

    protected function _initView()
    {
        $this->bootstrap('Session');
        /**
         * Init Layouts
         */
        return Ecart_Layout::startMvc();
        // see Ecart_Controller_Action method initView && initLayout
        //(have params can access only after dispatch)
    }

    protected function _initDbAdapter()
    {
        $this->bootstrap('Config');
        $db = Zend_Db::factory('Pdo_Mysql', array(
            'host'      => Ecart::config()->db->host,
            'username'  => Ecart::config()->db->username,
            'password'  => Ecart::config()->db->password,
            'dbname'    => Ecart::config()->db->dbname,
            'driver_options'=> array(
                PDO::MYSQL_ATTR_INIT_COMMAND => 'SET NAMES UTF8'
            )
        ));

//        //set query profiler
        $profiler = new Zend_Db_Profiler_Firebug('All DB Queries');
        $profiler->setEnabled(true);
        $db->setProfiler($profiler);

        //Set default adapter for childrens Zend_Db_Table_Abstract
        Zend_Db_Table_Abstract::setDefaultAdapter($db);
        //Ecart_Config::setDefaultDbAdapter($db);

        Zend_Registry::set('db', $db);
        return Ecart::db();
    }

    protected function _initCache()
    {
        if (null === Ecart::db()) {
            $this->bootstrap('DbAdapter');
        }
        //create default cache
        $cache = Ecart_Core_Model_Cache::getCache();
        //create database metacache
        Zend_Db_Table_Abstract::setDefaultMetadataCache($cache);

//        /**
//         * Zend_View acceleration
//         * http://www.web-blog.org.ua/articles/uskoryaem-zend-view
//         */
//        $cacheDir = Ecart::config()->system->path . '/var/PluginLoader/';
//        if (!is_readable($cacheDir)) {
//            mkdir($cacheDir, 0777);
//        } elseif(!is_writable($cacheDir)) {
//            chmod($cacheDir, 0777);
//        }
//        require_once 'Zend/Loader/PluginLoader.php';
//        $classFileIncCache = $cacheDir . 'cache.php';
//        if (file_exists($classFileIncCache))  {
//            include_once $classFileIncCache;
//        } else {
//            file_put_contents($classFileIncCache, "<?php\n");
//        }
//        Zend_Loader_PluginLoader::setIncludeFileCache($classFileIncCache);
  
        return Ecart::cache();
    }

    protected function _initLocale()
    {
        $this->bootstrap('Cache');
        $defaultLocale = Ecart_Locale::getDefaultLocale();
        $locales = Ecart_Locale::getLocaleList();

        //set default timezone affect on date() and Ecart_Date
        Ecart_Locale::setTimezone(Ecart_Locale::getDefaultTimezone());
        // pre router config
        Ecart_Controller_Router_Route::setDefaultLocale($defaultLocale);
        Ecart_Controller_Router_Route::setLocales($locales);

        Ecart_Controller_Router_Route_Module::setDefaultLocale($defaultLocale);
        Ecart_Controller_Router_Route_Module::setLocales($locales);
    }

    protected function _initRouter()
    {
        $this->bootstrap('Cache');
        $router = new Ecart_Controller_Router_Rewrite();
        // include routes files
        $routes = Ecart::getRoutes();
        foreach ($routes as $route) {
            include_once($route);
        }

        $router->removeDefaultRoutes();

        if (!($router instanceof Ecart_Controller_Router_Rewrite)) {
            throw new Ecart_Exception('Incorrect routes');
        }
        Zend_Controller_Front::getInstance()->setRouter($router);
        return $router;
    }

    protected function _initFrontController()
    {
        $this->bootstrap('Router');
        $front = Zend_Controller_Front::getInstance();
        //$front->setDispatcher(new Ecart_Controller_Dispatcher_Standart());
        // Настройка front контроллера, указание
        // базового директорий контролеров, правил маршрутизации
        //$front->throwExceptions(false);
        $front->setDefaultModule('Ecart_Core');
        $front->setControllerDirectory(Ecart::getControllers());
        //$front->setRouter($router);
        $front->setParam('noViewRenderer', true);
        $front->registerPlugin(
            new Ecart_Controller_Plugin_ErrorHandler_Override()
        );

        return $front; // this is *VERY* important
    }

    protected function _initZFDebug()
    {
        return;
        if (APPLICATION_ENV !== 'development') {
            return;
        }
        $autoloader = Zend_Loader_Autoloader::getInstance();
        $autoloader->registerNamespace('ZFDebug');

        $options = array(
            'plugins' => array(
                'Variables',
                'File' => array('base_path' => realpath('..')),
                'Memory',
                'Time',
                'Registry',
                'Exception',
                'Html',
            )
        );

        // Настройка плагина для адаптера базы данных
        if ($this->hasResource('DbAdapter')) {
            $this->bootstrap('DbAdapter');
            $db = $this->getResource('DbAdapter');//->getDbAdapter();
            $options['plugins']['Database']['adapter'] = $db;


            //set query profiler
            $profiler = new Zend_Db_Profiler_Firebug('All DB Queries');
            $profiler->setEnabled(true);
            $db->setProfiler($profiler);
        }

        // Настройка плагина для кеша
        if ($this->hasResource('Cache')) {
            $this->bootstrap('Cache');
            $cache = $this->getResource('Cache');//->getDbAdapter();
            $options['plugins']['Cache']['backend'] = $cache->getBackend();
        }

        $debug = new ZFDebug_Controller_Plugin_Debug($options);

        $this->bootstrap('FrontController');
        $frontController = $this->getResource('FrontController');
        $frontController->registerPlugin($debug);
    }
}