<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @category    Ecart
 * @package     Ecart_ShippingTable
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 * 
 * @category    Ecart
 * @package     Ecart_ShippingTable
 * @subpackage  Handler
 * @author      Ecart Core Team <core@ecartcommerce.com>
 */
class Ecart_Collect_Handler_ShippingTableRateExport implements Ecart_Collect_Handler_Interface
{
    /**
     *
     * @static
     * @param array $value
     * @return mixed
     */
    public static function getSaveValue($value)
    {
        if (!is_array($value)) {
           return $value;
        }
        
        $filename = Ecart::config()->system->path
            . '/var/export/' . current($value);

        if (@!$fp = fopen($filename, 'w')) {
            Ecart::message()->addError(
                Ecart::translate('core')->__(
                    "Can't write in file: %s", $filename
                )
            );
            return current($value);
        }
        
        $titles = explode(',', 'Country,Region/State,Zip,Value,Price');
        fputcsv($fp, $titles, ',', "'");
        foreach (Ecart::table('shippingtable_rate')->fetchAll() as $row) {
            fputcsv($fp, array(
                Ecart::single('location/country')
                    ->getIsoCode3ById($row->country_id),
                Ecart::single('location/zone')
                    ->getCodeById($row->zone_id),
                $row->zip,
                $row->value,
                $row->price
            ), ',', "'");
        }

        return current($value);
    }

    /**
     *
     * @static
     * @param array $value
     * @param Zend_View_Interface $view
     * @return string
     */
    public static function getHtml($value, Zend_View_Interface $view = null)
    {
        return $view->formText('confValue', $value);
    }

    /**
     *
     * @static
     * @param string $value
     * @return string
     */
    public static function getConfig($value)
    {
        return $value;
    }
}
