<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @category    Ecart
 * @package     Ecart_ShippingFlat
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 * 
 * @category    Ecart
 * @package     Ecart_ShippingFlat
 * @subpackage  Handler
 * @author      Ecart Core Team <core@ecartcommerce.com>
 */
class Ecart_Collect_Handler_ShippingTableRateImport implements Ecart_Collect_Handler_Interface
{
    /**
     *
     * @param mixed $value
     * @return mixed
     */
    public static function getSaveValue($value)
    {
        if (!is_array($value)) {
           return $value;
        }
        
        function remove_quotes(&$str)
        {
             $str = str_replace(array('"', "'"), '', $str);
        }
        
        $filename = Ecart::config()->system->path . '/var/export/' . current($value);

        if (@!$fp = fopen($filename, 'r')) {
            Ecart::message()->addError(
                Ecart::translate('core')->__(
                    "Can't open file : %s", $filename
            ));
            return current($value);
        }

        $titles = fgetcsv($fp, 2048, ',', "'");
        array_walk($titles, 'remove_quotes');
        $rowSize = count($titles);

        Ecart::table('shippingtable_rate')->delete(
            "site_id = " . $value['siteId']
        );
        while (!feof($fp)) {
            $data = fgetcsv($fp, 2048, ',', "'");
            if (!is_array($data)) {
                continue;
            }
            $data = array_pad($data, $rowSize, '');
            array_walk($data, 'remove_quotes');
            $data = array_combine($titles, $data);
            
            Ecart::table('shippingtable_rate')->insert(array(
                'site_id' => $value['siteId'],
                'country_id' => Ecart::single('location/country')
                    ->getIdByIsoCode3($data['Country']),
                'zone_id' => Ecart::single('location/zone')
                    ->getIdByCode($data['Region/State']),
                'zip' => $data['Zip'],
                'value' => $data['Value'],
                'price' => $data['Price']

           ));
        }
        return current($value);
    }

    /**
     *
     * @static
     * @param array $value
     * @param Zend_View_Interface $view
     * @return string
     */
    public static function getHtml($value, Zend_View_Interface $view = null)
    {
        $html = $view->formText('confValue', $value);
        return $html;
    }

    /**
     *
     * @static
     * @param mixed $value
     * @return mixed
     */
    public static function getConfig($value)
    {
        return $value;
    }
}
