<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @category    Ecart
 * @package     Ecart_Core
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 * 
 * @category    Ecart
 * @package     Ecart_Core
 * @author      Ecart Core Team <core@ecartcommerce.com>
 * @abstract
 */
abstract class Ecart_Controller_Action extends Zend_Controller_Action
{
    protected $_lang;
    protected $_langId;
    protected $_siteId;
    protected $_nsMain;

    /**
     *
     * @param  string $app
     * @return string
     */
    private function _getScriptsPath($app)
    {
        if ('front' === $app) {
            list($category, $module) = explode(
                '_', strtolower($this->getRequest()->getModuleName()), 2
            );
        } else {
            $controller = $this->getRequest()->getControllerName();
            $module = false === strpos($controller, '_') ?
                'core' : current(explode('_', $controller));
        }
        return $module;
    }
    
    /**
     * Initialize View object
     * 
     * @return Zend_View_Interface
     * @see Zend_Controller_Action initView() 
     */
    public function initView($app = null, array $template = null)
    {
        if (null === $app) {
            $app = Zend_Registry::get('app');
        }
        if (null === $template) {
            $template = Ecart::getTemplate($app);
        }        
        //$view = parent::initView();
        require_once 'Zend/View/Interface.php';
        if (!$this->getInvokeArg('noViewRenderer') 
            && $this->_helper->hasHelper('viewRenderer')) {

            $view = $this->view;
        } elseif (isset($this->view)
            && ($this->view instanceof Zend_View_Interface)) {

            $view = $this->view;
        } else {
            require_once 'Zend/View.php';
            $view = new Zend_View();
        }
        
        $this->view = $view;

        $systemPath = Ecart::config()->system->path;

        $view->templateName = $template['name'];
        $view->applicationName = $app;
        $module = $this->getRequest()->getModuleName();
        list($category, $module) = explode('_', $module, 2);
        $view->moduleCategory = $category;
        $view->moduleName = $module;

        $view->path = $systemPath;
        $view->skinPath = $systemPath 
                        . '/skin/'
                        . $app . '/'
                        . $template['name'];

        $dbBaseUrl = Ecart::single('core/site')->getBaseUrlByUrl(
            Ecart::getCurrentUrl()
        );
        $view->baseUrl = $dbBaseUrl ?
            $dbBaseUrl : Zend_Controller_Front::getInstance()->getBaseUrl();
        $view->catalogUrl = Ecart::config()->catalog->main->catalogRoute;
        $view->skinUrl = $view->baseUrl . '/skin/'
            . $app . '/' . $template['name'];
        //@todo every template shoud have own defaults
        $view->defaultTemplate = 'default'; 
        
        /* for use in ->render('../[script.php]')  */
        $view->setLfiProtection(false);
        
        //Initialize Zend_View stack 
        $module = $this->_getScriptsPath($app);

        $view->addFilterPath(
            $systemPath . '/library/Ecart/View/Filter', 'Ecart_View_Filter'
        );
        $view->addHelperPath(
            $systemPath . '/library/Ecart/View/Helper', 'Ecart_View_Helper'
        );

        $templatePath = $systemPath
                      . '/app/design/'
                      . $app . '/'
                      . $template['name'];

        $view->addHelperPath($templatePath . '/helpers', 'Ecart_View_Helper');
        $view->addScriptPath($templatePath . '/templates');
        $view->addScriptPath($templatePath . '/templates/' . $module);

        if ($template['name'] !== $view->defaultTemplate) {

            $templatePath = $systemPath
                          . '/app/design/'
                          . $app . '/'
                          . $view->defaultTemplate;

            $view->addHelperPath(
                $templatePath . '/helpers', 'Ecart_View_Helper'
            );
            $view->addScriptPath($templatePath . '/templates');
            $view->addScriptPath($templatePath . '/templates/' . $module);
            $view->addScriptPath($templatePath . '/layouts');
        }

        //for compatibility
        $viewRenderer = Zend_Controller_Action_HelperBroker::getStaticHelper(
            'viewRenderer'
        );
        $viewRenderer->setView($view);

        return $view;
    }
    
    /**
     * Init layout
     */
    public function initLayout(
        $view = null, $app = null, array $template = null)
    {
        if (null === $view) {
            $view = $this->view;
        }
        if (null === $app) {
            $app = Zend_Registry::get('app');
        }
        if (null === $template) {
            $template = Ecart::getTemplate($app);
        }
        
        $this->layout = Ecart_Layout::getMvcInstance();
        
        $this->layout->setView($view)->setOptions(array('layoutPath' =>
                Ecart::config()->system->path
                . '/app/design/'
                . $app . '/'
                . $template['name']
                . '/layouts'
        ));
        
        return $this->layout;
    }
    
    /**
     *  Main init
     */
    public function init()
    {
        parent::init();
        
        $this->_nsMain = Ecart::session();
        $this->config = Ecart::config();
        $this->c = Ecart::config();
        $this->db = Ecart::db();
        
        $module = $this->getRequest()->getParam('module');
        $app = ($module === 'Ecart_Admin') ? 'admin' : 'front';
        Zend_Registry::set('app', $app);
        $template = Ecart::getTemplate($app);

        $this->initView($app, $template);
        $this->initLayout($this->view, $app, $template);
        $this->_siteId = Ecart::getSiteId();
        
        if ($app == 'front') {
            if ($this->_hasParam('locale') 
                && Ecart_Controller_Router_Route::hasLocaleInUrl()) {
                
                Ecart_Locale::setLocale($this->_getParam('locale'));
            }
        } else {
            $locale = isset(Ecart::session()->locale) ? 
                Ecart::session()->locale : Ecart_Locale::getDefaultLocale();
            Ecart_Locale::setLocale($locale);
        }
        $this->_langId = Ecart_Locale::getLanguageId();

        Ecart_Translate::getInstance();

        // setting default meta tags 
        $this->view->meta()->setDefaults();
        
        $this->view->doctype('XHTML1_STRICT');

        $this->view->setEncoding('UTF-8');

        //$this->_helper->removeHelper('json');
        $this->_helper->addHelper(new Ecart_Controller_Action_Helper_Json());
    }
    
    /**
     * Write a snapshot to session
     * 
     * @param string $snapshot
     * @return void
     */
    protected function _setSnapshot($snapshot)
    {
        Ecart::session()->snapshot = $snapshot;
    }
    
    /**
     * Retrieve snapshot from session
     * 
     * @return string
     */
    protected function _getSnapshot()
    {
        $snapshot = Ecart::session()->snapshot;
        unset(Ecart::session()->snapshot);
        return $snapshot;
    }
    
    /**
     * @return bool
     */
    protected function _hasSnapshot()
    {
        return isset(Ecart::session()->snapshot)
            && !empty(Ecart::session()->snapshot);
    }

    /**
     * Return module name
     *
     * @return string
     */
    public function getModule()
    {
        list($category, $module) =  explode('_', get_class($this));
        return $category . '_' . $module;
    }

    /**
     *
     * @return Ecart_Translate
     */
    public function translate($module = null)
    {
        if (null === $module) {
            $module = $this->getModule();
        }
        return Ecart_Translate::getInstance($module);
    }

    /**
     * Translate 
     *
     * @return string
     */
    public function __()
    {
        return Ecart_Translate::getInstance(
            $this->getModule()
        )->translate(func_get_args());
    }
}