<?php
/**
 * Ecart
 *
 * This file is part of Ecart.
 *
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * @category    Ecart
 * @package     Ecart_Checkout
 * @copyright   Copyright 2003-2007 Zen Cart Development Team
 * @copyright   Portions Copyright 2003 osCommerce
 * @license     http://www.zen-cart.com/license/2_0.txt GNU Public License V2.0
 * @version     $Id: cc_validation.php 7379 2007-11-08 03:58:07Z drbyte $
 */

/**
 * cc_validation Class.
 * Class to validate credit card numbers etc

 * @category    Ecart
 * @package     Ecart_Checkout
 * @author      Ecart Core Team <core@ecartcommerce.com>
 */
class Ecart_CreditCard_Validator
{
    public $cc_type, $cc_number, $cc_expiry_month, $cc_expiry_year;

    /**
     *
     * @param <type> $number
     * @param <type> $expiryMonth
     * @param <type> $expiryYear
     * @param <type> $startMonth
     * @param <type> $startYear
     * @param <type> $ccType
     * @param <type> $allowedCcTypes
     * @return <type>
     */
    public function validate(
        $number,
        $expiryMonth,
        $expiryYear,
        $startMonth = null,
        $startYear = null,
        $ccType = null,
        $allowedCcTypes = array())
    {
        $this->cc_number = ereg_replace('[^0-9]', '', $number);
        if (!$this->isValidNumber()) {
            Ecart::message()->addError(
                Ecart::translate('checkout')->__('Invalid Credit Card Number'));
            return false;
        }
        
        // Check specific card-types based on first 6 digits:
        $NumberLeft6 = substr($this->cc_number, 0, 6);

        /***** SWITCH *****/
        if (( (($NumberLeft6 >= 490302) && ($NumberLeft6 <= 490309))
               || (($NumberLeft6 >= 490335) && ($NumberLeft6 <= 490339))
               || (($NumberLeft6 >= 491101) && ($NumberLeft6 <= 491102))
               || (($NumberLeft6 >= 491174) && ($NumberLeft6 <= 491182))
               || (($NumberLeft6 >= 493600) && ($NumberLeft6 <= 493699))
               ||  ($NumberLeft6 == 564182)
               || (($NumberLeft6 >= 633300) && ($NumberLeft6 <= 633349))
               || (($NumberLeft6 >= 675900) && ($NumberLeft6 <= 675999))
           ) && (ereg('[0-9]{16}|[0-9]{18}|[0-9]{19}', $this->cc_number))
             && in_array('Switch', $allowedCcTypes) )
        {
            $this->cc_type = "Switch";
        }

        /***** SOLO *****/
        elseif (( (($NumberLeft6 >= 633450) && ($NumberLeft6 <= 633460))
                || (($NumberLeft6 >= 633462) && ($NumberLeft6 <= 633472))
                || (($NumberLeft6 >= 633474) && ($NumberLeft6 <= 633475))
                ||  ($NumberLeft6 == 633477)
                || (($NumberLeft6 >= 633479) && ($NumberLeft6 <= 633480))
                || (($NumberLeft6 >= 633482) && ($NumberLeft6 <= 633489))
                ||  ($NumberLeft6 == 633498)
                || (($NumberLeft6 >= 676700) && ($NumberLeft6 <= 676799))
            ) && (ereg('[0-9]{16}|[0-9]{18}|[0-9]{19}', $this->cc_number))
                && in_array('Solo', $allowedCcTypes))
        {
            $this->cc_type = "Solo";
        }

        /***** JCB *****/
        elseif (( (($NumberLeft6 >= 352800) && ($NumberLeft6 <= 358999))
        //              ||  ($NumberLeft6 == 411111)
        )
        && (ereg('[0-9]{16}', $this->cc_number))  && in_array('JCB', $allowedCcTypes)) {
            $this->cc_type = "JCB";
        }

        /***** MAESTRO *****/
        elseif (( (($NumberLeft6 >= 493698) && ($NumberLeft6 <= 493699))
                ||  ($NumberLeft6 == 490303)
                || (($NumberLeft6 >= 633302) && ($NumberLeft6 <= 633349))
                || (($NumberLeft6 >= 675900) && ($NumberLeft6 <= 675999))
                || (($NumberLeft6 >= 500000) && ($NumberLeft6 <= 509999))
                || (($NumberLeft6 >= 560000) && ($NumberLeft6 <= 589999))
                || (($NumberLeft6 >= 600000) && ($NumberLeft6 <= 699999))
            ) && (ereg('[0-9]{16}([0-9]{3})', $this->cc_number))
                && in_array('Maestro', $allowedCcTypes))
        {
            $this->cc_type = "Maestro";
        }

        /***** VISA *****/
        elseif (( (($NumberLeft6 >= 400000) && ($NumberLeft6 <= 499999))
        // ensure we exclude AMT only cards
                && !( (($NumberLeft6 >= 490300) && ($NumberLeft6 <= 490301))
                   || (($NumberLeft6 >= 490310) && ($NumberLeft6 <= 490334))
                   || (($NumberLeft6 >= 490340) && ($NumberLeft6 <= 490399))
                   || (($NumberLeft6 >= 490400) && ($NumberLeft6 <= 490409))
                   ||  ($NumberLeft6 == 490419)
                   ||  ($NumberLeft6 == 490451)
                   ||  ($NumberLeft6 == 490459)
                   ||  ($NumberLeft6 == 490467)
                   || (($NumberLeft6 >= 490475) && ($NumberLeft6 <= 490478))
                   || (($NumberLeft6 >= 490500) && ($NumberLeft6 <= 490599))
                   || (($NumberLeft6 >= 491103) && ($NumberLeft6 <= 491173))
                   || (($NumberLeft6 >= 491183) && ($NumberLeft6 <= 491199))
                   || (($NumberLeft6 >= 492800) && ($NumberLeft6 <= 492899))
                   || (($NumberLeft6 >= 498700) && ($NumberLeft6 <= 498799))
                )
            ) && (ereg('[0-9]{16}|[0-9]{13}', $this->cc_number))
                && in_array('Visa', $allowedCcTypes))
        {
            $this->cc_type = 'Visa';

            // traditional CC hash checks:
        } elseif (ereg('^4[0-9]{12}([0-9]{3})?$', $this->cc_number) 
                && in_array('Visa', $allowedCcTypes)) {
            $this->cc_type = 'Visa';
        } elseif (ereg('^5[1-5][0-9]{14}$', $this->cc_number)
                && in_array('MasterCard', $allowedCcTypes)) {
            $this->cc_type = 'MasterCard';
        } elseif (ereg('^3[47][0-9]{13}$', $this->cc_number)
                && in_array('American Express', $allowedCcTypes)) {
            $this->cc_type = 'American Express';
        } elseif (ereg('^3(0[0-5]|[68][0-9])[0-9]{11}$', $this->cc_number)
                && in_array('Diners Club', $allowedCcTypes)) {
            $this->cc_type = 'Diners Club';
        } elseif (ereg('^6011[0-9]{12}$', $this->cc_number)
                && in_array('Discover', $allowedCcTypes)) {
            $this->cc_type = 'Discover';
        } elseif (ereg('^(3[0-9]{4}|2131|1800)[0-9]{11}$', $this->cc_number)
                && in_array('JCB', $allowedCcTypes)) {
            $this->cc_type = 'JCB';
        } elseif (ereg('^5610[0-9]{12}$', $this->cc_number)
                && in_array('Australian BankCard', $allowedCcTypes)) {
            $this->cc_type = 'Australian BankCard';
        } else {
            Ecart::message()->addError(
                Ecart::translate('checkout')->__(
                    "Unknown card %s", substr($this->cc_number, 0, 4)
            ));
            return false;
        }

        if (is_numeric($expiryMonth) && ($expiryMonth > 0) && ($expiryMonth < 13)) {
            $this->cc_expiry_month = $expiryMonth;
        } else {
            Ecart::message()->addError(
                Ecart::translate('checkout')->__(
                    'Invalid Expires Date'
            ));
            return false;
        }

        $currentYear = Ecart_Date::now()->toString('Y');
        if (strlen($expiryYear) == 2) {
            $expiryYear = intval(substr($currentYear, 0, 2) . $expiryYear);
        }
        
        if (is_numeric($expiryYear) && ($expiryYear >= $currentYear)
                && ($expiryYear <= ($currentYear + 10))) {

            $this->cc_expiry_year = $expiryYear;
        } else {
            Ecart::message()->addError(
                Ecart::translate('checkout')->__(
                    'Invalid Expires Date'
            ));
            return false;
        }

        if ($expiryYear == $currentYear) {
            if ($expiryMonth < Ecart_Date::now()->toPhpFormat()->toString('n')) {
                Ecart::message()->addError(
                    Ecart::translate('checkout')->__(
                        'Invalid Expires Date'
                ));
                return false;
            }
        }

        /* check the issue month & year but only for Switch/Solo cards */
        if (($startMonth || $startYear) 
            && in_array($this->cc_type, array('Switch', 'Solo'))) {
            
            if (!(is_numeric($startMonth) && ($startMonth > 0) && ($startMonth < 13))) {
                Ecart::message()->addError(
                    Ecart::translate('checkout')->__(
                        'Invalid Expires Date'
                ));
                return false;
            }

            if (strlen($startYear) == 2) {
                if ($startYear > 80) {
                    $startYear = intval('19' . $startYear);
                } else {
                    $startYear = intval('20' . $startYear);
                }
            }

            if (!is_numeric($startYear) || ($startYear > $currentYear)) {
                
                Ecart::message()->addError(
                    Ecart::translate('checkout')->__(
                        'Invalid Expires Date'
                ));
                return false;
            }
            if (!($startYear >= ($currentYear - 10))) {
                Ecart::message()->addError(
                    Ecart::translate('checkout')->__(
                        'Invalid Expires Date'
                ));
                return false;
            }
        }
        if (!empty($ccType) && $ccType !=  $this->cc_type) {
            Ecart::message()->addError(
                Ecart::translate('checkout')->__(
                    'Invalid Credit Card Type set'
            ));
            return false;
        }
        
        return true;
    }

    public function isValidNumber()
    {
        $cardNumber = strrev($this->cc_number);
        $numSum = 0;

        for ($i = 0; $i < strlen($cardNumber); $i++) {
            $currentNum = substr($cardNumber, $i, 1);

            // Double every second digit
            if ($i % 2 == 1) {
                $currentNum *= 2;
            }

            // Add digits of 2-digit numbers together
            if ($currentNum > 9) {
                $firstNum   = $currentNum % 10;
                $secondNum  = ($currentNum - $firstNum) / 10;
                $currentNum = $firstNum + $secondNum;
            }

            $numSum += $currentNum;
        }

        // If the total has no remainder it's OK
        return ($numSum % 10 == 0);
    }
}