<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @category    Ecart
 * @package     Ecart_Mail
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 * 
 * @category    Ecart
 * @package     Ecart_Mail
 * @author      Ecart Core Team <core@ecartcommerce.com>
 */
class Ecart_Mail extends Zend_Mail
{
    /**
     * Template renderer
     *
     * @var Zend_View
     */
    public $view;
    
    /**
     *
     * @param string $charset
     */
    public function __construct($charset = 'UTF-8')
    {
        parent::__construct($charset);
        $this->view = new Zend_View();
        
        /* for use in ->render('../[script.php]')  */
        $this->view->setLfiProtection(false);
        
        $this->view->addScriptPath(
            Ecart::config()->system->path . '/app/design/mail'
        );
        $this->view->addHelperPath(
            Ecart::config()->system->path . '/library/Ecart/View/Helper',
            'Ecart_View_Helper'
        );

        $this->view->applicationName = Zend_Registry::get('app');
        $this->view->path = Ecart::config()->system->path;
        $this->view->baseUrl = Ecart::config()->system->baseurl;
        $template = Ecart::getTemplate();
        $this->view->templateName = $template['name'];
        $sites = Ecart_Collect_Site::collect();
        $this->view->site = $sites[Ecart::getSiteId()];
        $this->view->company = Ecart::single('core/site')->getCompanyInfo(); 
        
        $this->view->path = Ecart::config()->system->path;
        $this->view->addScriptPath(Ecart::config()->system->path . 
            '/app/design/front/' . $template['name'] . '/templates'
        );
        $this->view->addScriptPath(Ecart::config()->system->path . 
            '/app/design/admin/' . $template['name'] . '/templates'
        );
        if ($template['name'] != 'default') {
            $view->addHelperPath(
                $this->view->path . '/app/design/front/default/helpers',
                'Ecart_View_Helper'
            );
            $view->addScriptPath(
                $this->view->path . '/app/design/front/default/templates'
            );
            $view->addHelperPath(
                $this->view->path . '/app/design/admin/default/helpers',
                'Ecart_View_Helper'
            );
            $view->addScriptPath(
                $this->view->path . '/app/design/admin/default/templates'
            );
        }
    }

   /**
    *  @param array(
    *      ['event' => string] 
    *      'subject' => string,    
    *      'data' => array(    
    *          'text' =>
    *          'blabla' => 
    *          ....
    *      ), 
    *      'to' => email, 
    *      ['from' => mixed (string(email) or array('email', 'name'))],
    *      ['type' => enum('txt', 'html')],
    *      ['charset' =>   ],
    *      'report' => true|false
    *  )
    *  @return bool
    */
    public function setConfig(array $config)
    {
        if (isset($config['event'])) {
            $mailTemplateId = Ecart::single('core/template_mail')
                ->getIdByEvent($config['event']);
            if (false === $mailTemplateId) {
                return false;
            }
            $mailTemplate = Ecart::single('core/template_mail')
                ->find($mailTemplateId)->current()->toArray();
            if (!is_array($mailTemplate)
                || !count($mailTemplate)
                || !$mailTemplate['status']) {

                return false;
            }
            $type = $mailTemplate['type'];
            if (isset($config['type'])) { 
                $type = $config['type'];
            }
            $from = array('email' => Ecart_Collect_MailBoxes::getName(
                    $mailTemplate['from']), 'name' => $mailTemplate['name']
            );
            
            $siteIds = explode(',', $mailTemplate['site']); 
            
            if (isset($config['siteId']) 
                && !in_array(Ecart::getSiteId(), $siteIds)) {

                return false;
            }
        }
        if (isset($config['from']['email'])) { 
            $from['email'] = $config['from']['email'];
        }
        if (isset($config['from']['name'])) {
            $from['name'] = $config['from']['name'];
        }
        if (isset($config['from']) && is_string($config['from'])) {
            $from = $config['from'];
        }
        
        $this->setSubject($config['subject']);
        $this->view->subject = $config['subject']; 
        $this->addTo($config['to']);
        if (is_array($from)){
            $this->setFrom($from['email'], $from['name']);
            $this->view->from = $from['email']; 
        } else {
           $this->setFrom($from);
           $this->view->from = $from;
        }
        if (isset($config['event'])) {
            if ($type == 'html') {
                $this->renderHtml($mailTemplate['template'], $config['data']);
            } else {
                $this->renderText($mailTemplate['template'], $config['data']);
            }
        } else {
            $this->setBodyText($config['data']['text']);
        }
        return true;             
    }

    /**
     *
     * @param string $template
     * @param array $data
     * @return Ecart_Mail
     */
    public function renderText($template, array $data)
    {
        $this->view->assign($data);
        $this->setBodyText(
            $this->view->render(strval($template) . '_txt.phtml')
        );
        return $this;
    }

    /**
     * Fluent interface
     * @param string $template
     * @param array $data
     * @return Ecart_Mail
     */
    public function renderHtml($template, array $data)
    {
        $this->view->assign($data);
        $this->setBodyHtml(
            $this->view->render(strval($template) . '_html.phtml')
        );
        return $this;
    }

    /**
     *
     * @return Zend_Mail_Transport_Abstract
     */
    public function getTransport()
    {
        if (null === self::$_defaultTransport) {
            $config = Ecart::config();
            switch ($config->mail->main->transport) {
                case 'smtp':
                    $options = array(
                        'port' => intval($config->mail->smtp->port)
                    );
                    if ($config->mail->smtp->auth) {
                        $options['auth']     = 'login';
                        $options['username'] = $config->mail->smtp->user;
                        $options['password'] = $config->mail->smtp->password;
                        if ('none' != $config->mail->smtp->secure) {
                            $options['ssl'] = $config->mail->smtp->secure;
                        }
                    }
                    
                    $transport = new Zend_Mail_Transport_Smtp(
                        $config->mail->smtp->host, $options
                    );
                    //$transport->EOL = "\r\n";    // gmail is fussy about this
            		break;
                
                case 'sendmail':
                default:
                    $transport = new Zend_Mail_Transport_Sendmail();
                    break;
            }
            self::setDefaultTransport($transport);
        }
        return self::$_defaultTransport;
    }

    /**
     *
     * @param Zend_Mail_Transport_Abstract $transport
     * @param bool $report
     * @return bool
     */
    public function send($transport = null, $report = true)
    {
        if (null === $transport) {
            $transport = $this->getTransport();
        }

        try {
            @parent::send($transport);
            if ($report) {
                Ecart::message()->addSuccess(
                    Ecart::translate('core')->__(
                        'Mail was sended successfully'
                    )
                );
            }
        } catch (Zend_Mail_Transport_Exception $e) {
            if ($report) {
                Ecart::message()->addError(
                    Ecart::translate('core')->__(
                        'Mail sending was failed.'
                    ) . ' ' . $e->getMessage()
                );
            }
            error_log($e->getMessage());
            return false;
        }
        return true;
    }
}