<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @category    Ecart
 * @package     Ecart_View
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 * 
 * @category    Ecart
 * @package     Ecart_View
 * @subpackage  Helper
 * @author      Ecart Core Team <core@ecartcommerce.com>
 */
class Ecart_View_Helper_Box
{
    /**
     * Return the singleton instance of box object
     * 
     * @param string $boxClass locale/currency|Ecart_Locale_Box_Currency
     * @param array $config [optional]
     * @return Ecart_Core_Box_Abstract
     * @throws Ecart_Exception
     */
    public function box($boxClass, $config = array())
    {
        if (strstr($boxClass, '/')) {
            list($config['boxModule'], $config['boxName']) =
                explode('/', $boxClass);
            $config['boxCategory'] = 'Ecart';
            $config['boxModule'] = ucfirst($config['boxModule']);
            $config['boxName'] = ucfirst($config['boxName']);
            $boxClass = $config['boxCategory']. '_' . $config['boxModule']
                . '_Box_' . $config['boxName'];
        } else {
            list($config['boxCategory'], 
                $config['boxModule'], ,
                $config['boxName']) = explode('_', $boxClass);
        }
        
        if (@!class_exists($boxClass)) {
            $response = Zend_Controller_Front::getInstance()->getResponse();
            if (!count($response->getException())) {
                $exception = new Ecart_Exception(
                    Ecart::translate('core')->__(
                        'Class %s not found', $boxClass
                    )
                );
                $response->setException($exception);
                
                throw $exception;
            } else {
                return;
            }
        }
        
        if (Zend_Registry::isRegistered($boxClass)) {
            return Zend_Registry::get($boxClass)->updateData($config, true);
        }
        return Ecart::single($boxClass, $config);
    }
}