<?php
/**
 * Ecart
 * 
 * This file is part of Ecart.
 * 
 * Ecart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Ecart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Ecart.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @category    Ecart
 * @package     Ecart_Core
 * @copyright   Copyright 2008-2009 E-Cart LLC
 * @license     GNU Public License V3.0
 */

/**
 * JavaScript localization search
 * This script will find all language sensitive statements, that are thanslated via js function l() and output them to $output
 */
require_once '_init.php';
set_time_limit(2 * 60);
$prefix = $config->db->prefix; 
$sites = $db->fetchAll("SELECT * FROM {$prefix}core_site");
$languages = $db->fetchAll("SELECT * FROM {$prefix}locale_language");

/* indexing products */
$indexPath = $root . '/var/index';
foreach ($sites as $site) {
    $siteName = str_replace(
        array('http://', 'https://'), '',
        urlencode($site['name'] . '_'. $site['id'])
    );
    $indexDir = $indexPath . '/' . $siteName;
    @removeDir($indexDir);
    /* create index dirs if not exists */
    if (!is_dir($indexDir)) {
        mkdir($indexDir, 0777);
    }
    foreach ($languages as $language) {
        
        $indexLocale = $indexDir . '/' . $language['locale'];
        if (!is_dir($indexLocale)) {
            mkdir($indexLocale, 0777);
        }
        
        $log = new Zend_Log(new Zend_Log_Writer_Stream($root . '/var/logs/indexing.log'));
        $log->info('Starting up');
        
        if (@preg_match('/\pL/u', 'a') != 1) {
            $log->error("PCRE unicode support is turned off.\n");
            echo "PCRE unicode support is turned off.\n";
            exit(1);
        }
        Zend_Search_Lucene_Search_QueryParser::setDefaultEncoding('utf-8');
        Zend_Search_Lucene_Analysis_Analyzer::setDefault(
            new Zend_Search_Lucene_Analysis_Analyzer_Common_Utf8_CaseInsensitive());

        try {
            $index = Zend_Search_Lucene::open($indexLocale);
            $log->info("Opened existing index in $indexLocale");
        } catch (Zend_Search_Lucene_Exception $e) {
            try {
                $index = Zend_Search_Lucene::create($indexLocale);
                $log->info("Created new index in $indexLocale");
            } catch(Zend_Search_Lucene_Exception $e) {
                $log->error("Failed opening or creating index in $indexLocale");
                $log->error($e->getMessage());
                echo "Unable to open or create index: {$e->getMessage()}";
                exit(1);
            }
        }
        
        /* Indexing products */
        $queryCount = "SELECT COUNT(*) FROM {$prefix}catalog_product p
            INNER JOIN {$prefix}catalog_product_category ptc ON p.id = ptc.product_id
            INNER JOIN {$prefix}catalog_category c ON c.id = ptc.category_id
            WHERE site_id = ?";
        $cnt = $db->fetchOne($queryCount, $site['id']);
        
        $query = "SELECT DISTINCT p.id, p.sku, p.image_thumbnail, pd.*, hu.key_word FROM {$prefix}catalog_product p
            INNER JOIN {$prefix}catalog_product_description pd ON p.id = pd.product_id
            INNER JOIN {$prefix}catalog_product_category ptc ON p.id = ptc.product_id
            INNER JOIN {$prefix}catalog_category c ON c.id = ptc.category_id
            LEFT  JOIN {$prefix}catalog_hurl hu ON hu.key_id = p.id AND hu.key_type='p'
            WHERE pd.language_id = ? AND c.site_id = ?";
        
        $step = 30;
        $offset = 0;
        while ($offset < $cnt) {
            $products = $db->fetchAssoc(
                $query . " LIMIT $offset, $step",  
                array($language['id'], $site['id'])
            );
           
                
            foreach ($products as $product) {
                /* INDEXING HERE */
                $docUrl = $product['key_word'];
                
                $doc = new Zend_Search_Lucene_Document();
                $doc->addField(Zend_Search_Lucene_Field::UnIndexed('productId', $product['id'], 'utf-8'));
                $doc->addField(Zend_Search_Lucene_Field::UnIndexed('url', $docUrl, 'utf-8'));
                $doc->addField(Zend_Search_Lucene_Field::UnIndexed('image', $product['image_thumbnail'], 'utf-8'));
                $doc->addField(Zend_Search_Lucene_Field::Text('name', $product['name'], 'utf-8'));
                $doc->addField(Zend_Search_Lucene_Field::Text('contents', $product['description'], 'utf-8'));
                $index->addDocument($doc);
                
                $log->info('Added document ' . $docUrl);
            }
            
            $offset += $step;
        }
        
        $log->info("Optimizing index...");
        $index->optimize();
        $index->commit();
        $log->info("Done. Index now contains " . $index->numDocs() . " documents");
    }
}
$log->info("Index Maker shutting down");

function removeDir($path) {
    $index_path = rtrim(
        str_replace(
            array('\\', 'scripts'), 
            array('/', ''), 
            dirname(realpath(__FILE__))
        ), '/') . '/var/index';
    
    /* check are we in 'ROOT/var/index' */
    if (false === strpos($path, $index_path))
        return false;
        
    if (is_dir($path)) {
        $path = rtrim($path, '/');
        $dir = dir($path);
        while (false !== ($file = $dir->read())) {
            if ($file != '.' && $file != '..') {
                (!is_link("$path/$file") && is_dir("$path/$file")) ? 
                    RemoveDir("$path/$file") : unlink("$path/$file");
            }
        }
        $dir->close();
        rmdir($path);
        return true;
    }
    return false;
}

